# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bakplane/bakplane.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import (
    timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="bakplane/bakplane.proto",
    package="io.openaristos",
    syntax="proto3",
    serialized_options=b"\n\016io.openaristosB\rBakplaneProtoP\001Z\016proto/bakplane\242\002\002BP",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x17\x62\x61kplane/bakplane.proto\x12\x0eio.openaristos\x1a\x1fgoogle/protobuf/timestamp.proto"j\n\x0eTimestampRange\x12,\n\x08start_dt\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_dt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"E\n\x11PaginationOptions\x12\x10\n\x08per_page\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x10\n\x08order_by\x18\x03 \x03(\t"@\n\x11PaginationDetails\x12\x13\n\x0btotal_pages\x18\x01 \x01(\r\x12\x16\n\x0etotal_elements\x18\x02 \x01(\x04"?\n\x08Universe\x12\x12\n\ndefinition\x18\x01 \x01(\t\x12\x0f\n\x07\x64ialect\x18\x02 \x01(\t\x12\x0e\n\x06\x65ngine\x18\x03 \x01(\t"\x9b\x01\n\x0bPerspective\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\r\x12K\n\x14permanent_attributes\x18\x05 \x03(\x0b\x32-.io.openaristos.PerspectivePermanentAttribute"Q\n\x1dPerspectivePermanentAttribute\x12\x18\n\x10\x65ntity_type_code\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x02 \x01(\t"\x83\x02\n\x16MigrateResourceRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x02 \x01(\t\x12\x43\n\tdirection\x18\x03 \x01(\x0e\x32\x30.io.openaristos.MigrateResourceRequest.Direction\x12;\n\x05\x66orce\x18\x04 \x01(\x0b\x32,.io.openaristos.MigrateResourceRequest.Force\x1a\x18\n\x05\x46orce\x12\x0f\n\x07version\x18\x01 \x01(\r"\'\n\tDirection\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04\x44ROP\x10\x02"\x97\x02\n\x1aMigrateAllResourcesRequest\x12\x14\n\x0c\x61\x64\x61pter_code\x18\x01 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x02 \x01(\t\x12G\n\tdirection\x18\x03 \x01(\x0e\x32\x34.io.openaristos.MigrateAllResourcesRequest.Direction\x12?\n\x05\x66orce\x18\x04 \x01(\x0b\x32\x30.io.openaristos.MigrateAllResourcesRequest.Force\x1a\x18\n\x05\x46orce\x12\x0f\n\x07version\x18\x01 \x01(\r"\'\n\tDirection\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04\x44ROP\x10\x02"I\n\x10MigrationDetails\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x16\n\x0ewarehouse_code\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t"S\n\x1bMigrateAllResourcesResponse\x12\x34\n\nmigrations\x18\x01 \x03(\x0b\x32 .io.openaristos.MigrationDetails">\n\x16MigrationStatusRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x02 \x01(\t"N\n\x17MigrateResourceResponse\x12\x33\n\tmigration\x18\x01 \x01(\x0b\x32 .io.openaristos.MigrationDetails"\x98\x02\n\x16ResolveResourceRequest\x12*\n\x08universe\x18\x01 \x01(\x0b\x32\x18.io.openaristos.Universe\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\twarehouse\x18\x03 \x01(\t\x12\x38\n\x10\x65\x66\x66\x65\x63tive_dating\x18\x04 \x01(\x0b\x32\x1e.io.openaristos.TimestampRange\x12\x46\n\x08pointers\x18\x05 \x03(\x0b\x32\x34.io.openaristos.ResolveResourceRequest.PointersEntry\x1a/\n\rPointersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xbc\x01\n\x1bResolveQueryResourceRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\twarehouse\x18\x02 \x01(\t\x12K\n\x08pointers\x18\x03 \x03(\x0b\x32\x39.io.openaristos.ResolveQueryResourceRequest.PointersEntry\x1a/\n\rPointersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xc8\x02\n\x1cResolveQueryResourceResponse\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12=\n\x07mapping\x18\x04 \x01(\x0b\x32,.io.openaristos.ResolveResourceIntentMapping\x12,\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x1b.io.openaristos.ColumnEntry\x12J\n\x07\x63ontext\x18\x06 \x03(\x0b\x32\x39.io.openaristos.ResolveQueryResourceResponse.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xa2\x02\n"ResolveResourceMappingContextEntry\x12\x19\n\x11source_field_name\x18\x01 \x01(\t\x12\x1f\n\x17target_field_expression\x18\x02 \x01(\t\x12\x35\n\x0e\x61ttribute_type\x18\x03 \x01(\x0e\x32\x1d.io.openaristos.AttributeType\x12\x18\n\x10used_for_mapping\x18\x04 \x01(\x08\x12\x19\n\x11map_to_field_name\x18\x05 \x01(\t\x12\x1b\n\x13is_effective_dating\x18\x06 \x01(\x08\x12\x37\n\x0f\x63omparison_type\x18\x07 \x01(\x0e\x32\x1e.io.openaristos.ComparisonType"&\n\x17ResolveResourceResponse\x12\x0b\n\x03row\x18\x01 \x01(\t"\x84\x03\n\x1dResolveResourceIntentResponse\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12=\n\x07mapping\x18\x04 \x01(\x0b\x32,.io.openaristos.ResolveResourceIntentMapping\x12,\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x1b.io.openaristos.ColumnEntry\x12K\n\x07\x63ontext\x18\x06 \x03(\x0b\x32:.io.openaristos.ResolveResourceIntentResponse.ContextEntry\x12\x38\n\x10\x65\x66\x66\x65\x63tive_dating\x18\x07 \x01(\x0b\x32\x1e.io.openaristos.TimestampRange\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xba\x01\n\x1cResolveResourceIntentMapping\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x13\n\x0bschema_name\x18\x02 \x01(\t\x12,\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x1b.io.openaristos.ColumnEntry\x12\x43\n\x07\x63lauses\x18\x04 \x03(\x0b\x32\x32.io.openaristos.ResolveResourceIntentMappingClause"J\n\x0b\x43olumnEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61taType\x18\x02 \x01(\t\x12\x1b\n\x13is_effective_dating\x18\x03 \x01(\x08"\x91\x01\n"ResolveResourceIntentMappingClause\x12\x1b\n\x13resource_field_name\x18\x01 \x01(\t\x12\x1a\n\x12mapping_field_name\x18\x02 \x01(\t\x12\x32\n\ncomparison\x18\x03 \x01(\x0e\x32\x1e.io.openaristos.ComparisonType"0\n\x12\x43onfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"s\n\x17\x41pplyLandingZoneRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06plugin\x18\x02 \x01(\t\x12:\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32".io.openaristos.ConfigurationEntry"\x1a\n\x18\x41pplyLandingZoneResponse")\n\x19RetractLandingZoneRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1c\n\x1aRetractLandingZoneResponse"f\n\x16ListLandingZoneRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\xab\x02\n\x17ListLandingZoneResponse\x12Q\n\rlanding_zones\x18\x01 \x03(\x0b\x32:.io.openaristos.ListLandingZoneResponse.LandingZoneDetails\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails\x1a~\n\x12LandingZoneDetails\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06plugin\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12:\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32".io.openaristos.ConfigurationEntry"(\n\x18\x45nableLandingZoneRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1b\n\x19\x45nableLandingZoneResponse")\n\x19\x44isableLandingZoneRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1c\n\x1a\x44isableLandingZoneResponse"\xd8\x02\n\x0fSchemaAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\tdata_type\x18\x04 \x01(\x0e\x32\x1d.io.openaristos.AttributeType\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x11\n\tindexable\x18\x06 \x01(\x08\x12\x41\n\x0cmapping_type\x18\x07 \x01(\x0e\x32+.io.openaristos.SchemaAttribute.MappingType\x12\x11\n\tprecision\x18\x08 \x01(\x05\x12\r\n\x05scale\x18\t \x01(\x05\x12\x0e\n\x06length\x18\n \x01(\x05"L\n\x0bMappingType\x12\x0e\n\nIDENTIFIER\x10\x00\x12\x16\n\x12PARTIAL_IDENTIFIER\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\x12\x0b\n\x07IGNORED\x10\x03"n\n\x06Schema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\nattributes\x18\x04 \x03(\x0b\x32\x1f.io.openaristos.SchemaAttribute"W\n\x0eMappingContext\x12\x45\n\x13\x63oncatenation_rules\x18\x01 \x03(\x0b\x32(.io.openaristos.MappingConcatenationRule"+\n\x18MappingConcatenationRule\x12\x0f\n\x07\x65ntries\x18\x01 \x03(\t"\x96\x01\n\nEntityType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12&\n\x06schema\x18\x04 \x01(\x0b\x32\x16.io.openaristos.Schema\x12/\n\x07mapping\x18\x05 \x01(\x0b\x32\x1e.io.openaristos.MappingContext"{\n\x10RelationshipType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1a\n\x12source_entity_type\x18\x04 \x01(\t\x12\x1a\n\x12target_entity_type\x18\x05 \x01(\t"\xae\x01\n\x14\x41pplyOntologyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12,\n\x08\x65ntities\x18\x04 \x03(\x0b\x32\x1a.io.openaristos.EntityType\x12\x37\n\rrelationships\x18\x05 \x03(\x0b\x32 .io.openaristos.RelationshipType"\x17\n\x15\x41pplyOntologyResponse"&\n\x16RetractOntologyRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x19\n\x17RetractOntologyResponse"c\n\x13ListOntologyRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\xa2\x01\n\x08Ontology\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12,\n\x08\x65ntities\x18\x04 \x03(\x0b\x32\x1a.io.openaristos.EntityType\x12\x37\n\rrelationships\x18\x05 \x03(\x0b\x32 .io.openaristos.RelationshipType"\x83\x01\n\x14ListOntologyResponse\x12,\n\nontologies\x18\x01 \x03(\x0b\x32\x18.io.openaristos.Ontology\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"\x9c\x01\n\x0f\x45xecutionEngine\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0e\n\x06plugin\x18\x05 \x01(\t\x12:\n\x0e\x63onfigurations\x18\x06 \x03(\x0b\x32".io.openaristos.ConfigurationEntry"N\n\x1b\x41pplyExecutionEngineRequest\x12/\n\x06\x65ngine\x18\x01 \x01(\x0b\x32\x1f.io.openaristos.ExecutionEngine"\x1e\n\x1c\x41pplyExecutionEngineResponse"-\n\x1dRetractExecutionEngineRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t" \n\x1eRetractExecutionEngineResponse"j\n\x1aListExecutionEngineRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x8e\x01\n\x1bListExecutionEngineResponse\x12\x30\n\x07\x65ngines\x18\x01 \x03(\x0b\x32\x1f.io.openaristos.ExecutionEngine\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails",\n\x1c\x45nableExecutionEngineRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1f\n\x1d\x45nableExecutionEngineResponse"-\n\x1d\x44isableExecutionEngineRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t" \n\x1e\x44isableExecutionEngineResponse"\x96\x01\n\tWarehouse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06plugin\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12:\n\x0e\x63onfigurations\x18\x06 \x03(\x0b\x32".io.openaristos.ConfigurationEntry"E\n\x15\x41pplyWarehouseRequest\x12,\n\twarehouse\x18\x01 \x01(\x0b\x32\x19.io.openaristos.Warehouse"\xfe\x02\n\tValidator\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12?\n\x0evalidator_kind\x18\x04 \x01(\x0e\x32\'.io.openaristos.Validator.ValidatorKind\x12\x39\n\x0bschema_kind\x18\x05 \x01(\x0e\x32$.io.openaristos.Validator.SchemaKind\x12\x0e\n\x06schema\x18\x06 \x01(\t"\x88\x01\n\rValidatorKind\x12\x1b\n\x17VALIDATOR_KIND_RESOURCE\x10\x00\x12\x1a\n\x16VALIDATOR_KIND_ADAPTER\x10\x01\x12\x1e\n\x1aVALIDATOR_KIND_PERSPECTIVE\x10\x02\x12\x1e\n\x1aVALIDATOR_KIND_ENTITY_TYPE\x10\x03")\n\nSchemaKind\x12\x1b\n\x17SCHEMA_KIND_JSON_SCHEMA\x10\x00"E\n\x15\x41pplyValidatorRequest\x12,\n\tvalidator\x18\x01 \x01(\x0b\x32\x19.io.openaristos.Validator"\'\n\x17RetractValidatorRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1a\n\x18RetractValidatorResponse"d\n\x14ListValidatorRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x85\x01\n\x15ListValidatorResponse\x12-\n\nvalidators\x18\x01 \x03(\x0b\x32\x19.io.openaristos.Validator\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"\x18\n\x16\x41pplyValidatorResponse"\x18\n\x16\x41pplyWarehouseResponse"\'\n\x17RetractWarehouseRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1a\n\x18RetractWarehouseResponse"d\n\x14ListWarehouseRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x85\x01\n\x15ListWarehouseResponse\x12-\n\nwarehouses\x18\x01 \x03(\x0b\x32\x19.io.openaristos.Warehouse\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"&\n\x16\x45nableWarehouseRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x19\n\x17\x45nableWarehouseResponse"\'\n\x17\x44isableWarehouseRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x1a\n\x18\x44isableWarehouseResponse"N\n\x1b\x41pplyMasteringEngineRequest\x12/\n\x06\x65ngine\x18\x01 \x01(\x0b\x32\x1f.io.openaristos.MasteringEngine"\x1e\n\x1c\x41pplyMasteringEngineResponse"-\n\x1dRetractMasteringEngineRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t" \n\x1eRetractMasteringEngineResponse"j\n\x1aListMasteringEngineRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x98\x01\n\x1bListMasteringEngineResponse\x12:\n\x11mastering_engines\x18\x01 \x03(\x0b\x32\x1f.io.openaristos.MasteringEngine\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"\x8e\x01\n\x0fMasteringEngine\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06plugin\x18\x04 \x01(\t\x12:\n\x0e\x63onfigurations\x18\x05 \x03(\x0b\x32".io.openaristos.ConfigurationEntry"7\n\x19ResourceStoreContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"}\n\rResourceStore\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07virtual\x18\x02 \x01(\x08\x12\x11\n\twarehouse\x18\x03 \x01(\t\x12:\n\x07\x63ontext\x18\x04 \x03(\x0b\x32).io.openaristos.ResourceStoreContextEntry"9\n\x14ResourcePointerEntry\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t"3\n\x15ResourceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"@\n\x1bResourceContextPointerEntry\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x01(\t"\xaa\x01\n\x0eResourceDating\x12\x1a\n\x12\x65\x66\x66\x65\x63tive_start_dt\x18\x01 \x01(\t\x12\x18\n\x10\x65\x66\x66\x65\x63tive_end_dt\x18\x02 \x01(\t\x12\x16\n\x0evalid_start_dt\x18\x03 \x01(\t\x12\x14\n\x0cvalid_end_dt\x18\x04 \x01(\t\x12\x1a\n\x12knowledge_start_dt\x18\x05 \x01(\t\x12\x18\n\x10knowledge_end_dt\x18\x06 \x01(\t"?\n\x0fResourceHashing\x12\x16\n\x0eknowledge_hash\x18\x01 \x01(\t\x12\x14\n\x0cpayload_hash\x18\x02 \x01(\t"T\n\x12ResourceRetraction\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12\x12\n\nsoft_steps\x18\x02 \x03(\t\x12\x12\n\nhard_steps\x18\x03 \x03(\t"\x89\x03\n\x0fResourceContext\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12=\n\x08pointers\x18\x02 \x03(\x0b\x32+.io.openaristos.ResourceContextPointerEntry\x12.\n\x06\x64\x61ting\x18\x03 \x01(\x0b\x32\x1e.io.openaristos.ResourceDating\x12\x30\n\x07hashing\x18\x04 \x01(\x0b\x32\x1f.io.openaristos.ResourceHashing\x12\x37\n\x08metadata\x18\x05 \x03(\x0b\x32%.io.openaristos.ResourceMetadataEntry\x12;\n\npublishing\x18\x06 \x01(\x0b\x32\'.io.openaristos.AdapterPersistenceEntry\x12\x0f\n\x07\x64\x61taset\x18\x07 \x01(\t\x12\x36\n\nretraction\x18\x08 \x01(\x0b\x32".io.openaristos.ResourceRetraction"\xac\x03\n\x08Resource\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x18\n\x10perspective_code\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x06 \x01(\t\x12&\n\x06schema\x18\x07 \x01(\x0b\x32\x16.io.openaristos.Schema\x12\x36\n\x08pointers\x18\x08 \x03(\x0b\x32$.io.openaristos.ResourcePointerEntry\x12-\n\x06stores\x18\t \x03(\x0b\x32\x1d.io.openaristos.ResourceStore\x12\x17\n\x0fretention_hours\x18\n \x01(\r\x12\x30\n\x07\x63ontext\x18\x0b \x03(\x0b\x32\x1f.io.openaristos.ResourceContext\x12-\n\nmigrations\x18\x0c \x03(\x0b\x32\x19.io.openaristos.Migration\x12\x12\n\nis_virtual\x18\r \x01(\x08\x12\x19\n\x11\x63ustomer_metadata\x18\x0e \x01(\t"J\n\x07\x41\x64\x61pter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t"f\n\x12\x41\x64\x61pterPersistence\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12\x38\n\x07\x65ntries\x18\x02 \x01(\x0b\x32\'.io.openaristos.AdapterPersistenceEntry"e\n\x17\x41\x64\x61pterPersistenceEntry\x12\x35\n\x05steps\x18\x01 \x03(\x0b\x32&.io.openaristos.AdapterPersistenceStep\x12\x13\n\x0bmerge_steps\x18\x02 \x03(\t"4\n\x16\x41\x64\x61pterPersistenceStep\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"\x82\x01\n\x0f\x41\x64\x61pterMetadata\x12\x37\n\x0bpersistence\x18\x01 \x03(\x0b\x32".io.openaristos.AdapterPersistence\x12\x36\n\nretraction\x18\x02 \x03(\x0b\x32".io.openaristos.ResourceRetraction"d\n\tMigration\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12\x16\n\x0emigrations_uri\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12\x12\n\ntable_name\x18\x04 \x01(\t"\xd3\x03\n\x13\x41pplyAdapterRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x43\n\x12\x65xecution_profiles\x18\x06 \x03(\x0b\x32\'.io.openaristos.AdapterExecutionProfile\x12\x35\n\nparameters\x18\x07 \x03(\x0b\x32!.io.openaristos.AdapterParameters\x12+\n\tresources\x18\x08 \x03(\x0b\x32\x18.io.openaristos.Resource\x12\x31\n\x08metadata\x18\t \x01(\x0b\x32\x1f.io.openaristos.AdapterMetadata\x12T\n\x11\x63ustomer_metadata\x18\n \x03(\x0b\x32\x39.io.openaristos.ApplyAdapterRequest.CustomerMetadataEntry\x1a\x37\n\x15\x43ustomerMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x16\n\x14\x41pplyAdapterResponse"%\n\x15RetractAdapterRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x18\n\x16RetractAdapterResponse"b\n\x12ListAdapterRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\xb2\x03\n\x13ListAdapterResponse\x12\x44\n\x08\x61\x64\x61pters\x18\x01 \x03(\x0b\x32\x32.io.openaristos.ListAdapterResponse.AdapterDetails\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails\x1a\x95\x02\n\x0e\x41\x64\x61pterDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x43\n\x12\x65xecution_profiles\x18\x05 \x03(\x0b\x32\'.io.openaristos.AdapterExecutionProfile\x12\x35\n\nparameters\x18\x06 \x03(\x0b\x32!.io.openaristos.AdapterParameters\x12+\n\tresources\x18\x07 \x03(\x0b\x32\x18.io.openaristos.Resource\x12\x19\n\x11\x63ustomer_metadata\x18\x08 \x01(\t"$\n\x14\x45nableAdapterRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x17\n\x15\x45nableAdapterResponse"%\n\x15\x44isableAdapterRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x18\n\x16\x44isableAdapterResponse"B\n\x14\x41pplyResourceRequest\x12*\n\x08resource\x18\x01 \x01(\x0b\x32\x18.io.openaristos.Resource"\x17\n\x15\x41pplyResourceResponse"&\n\x16RetractResourceRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x19\n\x17RetractResourceResponse"c\n\x13ListResourceRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x82\x01\n\x14ListResourceResponse\x12+\n\tresources\x18\x01 \x03(\x0b\x32\x18.io.openaristos.Resource\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"%\n\x15\x45nableResourceRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"9\n\x16PreviewResourceRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x11\n\twarehouse\x18\x02 \x01(\t"\x18\n\x16\x45nableResourceResponse"\'\n\x17PreviewResourceResponse\x12\x0c\n\x04rows\x18\x01 \x03(\t"&\n\x16\x44isableResourceRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x19\n\x17\x44isableResourceResponse"c\n\x11\x41\x64\x61pterParameters\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\t\x12\x30\n\tdata_type\x18\x03 \x01(\x0e\x32\x1d.io.openaristos.AttributeType"l\n\x1c\x41\x64\x61pterExecutionContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x30\n\tdata_type\x18\x03 \x01(\x0e\x32\x1d.io.openaristos.AttributeType"\x80\x01\n\x17\x41\x64\x61pterExecutionProfile\x12\x13\n\x0b\x65ngine_kind\x18\x01 \x01(\t\x12\x11\n\tstreaming\x18\x02 \x01(\x08\x12=\n\x07\x63ontext\x18\x03 \x03(\x0b\x32,.io.openaristos.AdapterExecutionContextEntry"\xfa\x01\n\x1d\x43reateIngestionSessionRequest\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\x12\x14\n\x0clanding_zone\x18\x02 \x01(\t\x12\x18\n\x10mastering_engine\x18\x03 \x01(\t\x12\x12\n\nwarehouses\x18\x04 \x03(\t\x12Q\n\nparameters\x18\x05 \x03(\x0b\x32=.io.openaristos.CreateIngestionSessionRequest.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01",\n\x1e\x43reateIngestionSessionResponse\x12\n\n\x02id\x18\x01 \x01(\r"\xd7\x01\n\x1e\x45xecuteIngestionSessionRequest\x12\n\n\x02id\x18\x01 \x01(\r\x12R\n\nparameters\x18\x02 \x03(\x0b\x32>.io.openaristos.ExecuteIngestionSessionRequest.ParametersEntry\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x13\n\x0b\x65ngine_kind\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"+\n\x1d\x44\x65leteIngestionSessionRequest\x12\n\n\x02id\x18\x01 \x01(\r",\n\x1e\x44\x65leteIngestionSessionResponse\x12\n\n\x02id\x18\x01 \x01(\r"(\n\x1aGetIngestionSessionRequest\x12\n\n\x02id\x18\x01 \x01(\r"\x83\x01\n\x1eIngestionSessionStatusResponse\x12\n\n\x02id\x18\x01 \x01(\r\x12\x36\n\x06status\x18\x02 \x01(\x0e\x32&.io.openaristos.IngestionSessionStatus\x12\x1d\n\x15transaction_reference\x18\x03 \x01(\t"\x93\x01\n\x0cMasterEntity\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x42\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32-.io.openaristos.MasterEntity.DescriptorsEntry\x1a\x32\n\x10\x44\x65scriptorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"=\n\x1dMasterIngestionSessionRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r" \n\x1eMasterIngestionSessionResponse"\xb3\x01\n&PublishIngestionSessionResourceRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r\x12\x15\n\rresource_code\x18\x02 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x03 \x01(\t\x12\x16\n\x0e\x61ll_warehouses\x18\x04 \x01(\x08\x12\x15\n\rall_resources\x18\x05 \x01(\x08\x12\r\n\x05\x66orce\x18\x06 \x01(\x08"_\n\'PublishIngestionSessionResourceResponse\x12\x34\n\tresources\x18\x01 \x03(\x0b\x32!.io.openaristos.PublishingDetails"{\n,PublishIngestionSessionResourceStatusRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r\x12\x15\n\rresource_code\x18\x02 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x03 \x01(\t"\xab\x01\n%PublishIngestionSessionStatusResponse\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r\x12\x15\n\rresource_code\x18\x02 \x01(\t\x12\x16\n\x0ewarehouse_code\x18\x03 \x01(\t\x12\x35\n\x06status\x18\x04 \x01(\x0e\x32%.io.openaristos.ResourcePublishStatus"\xeb\x01\n\x1fRetractPublishingSessionRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x16\n\x0ewarehouse_code\x18\x05 \x01(\t\x12\x0b\n\x03\x61ll\x18\x06 \x01(\x08\x12L\n\x04type\x18\x07 \x01(\x0e\x32>.io.openaristos.RetractPublishingSessionRequest.RetractionType"$\n\x0eRetractionType\x12\x08\n\x04SOFT\x10\x00\x12\x08\n\x04HARD\x10\x01""\n RetractPublishingSessionResponse">\n\x1eRetractMasteringSessionRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r"!\n\x1fRetractMasteringSessionResponse"1\n\x1fHaltIncrementalMasteringRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t""\n HaltIncrementalMasteringResponse"3\n!ResumeIncrementalMasteringRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t"$\n"ResumeIncrementalMasteringResponse"\xb7\x01\n\x1aResolveResourcePathRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\twarehouse\x18\x02 \x01(\t\x12H\n\x07\x63ontext\x18\x03 \x03(\x0b\x32\x37.io.openaristos.ResolveResourcePathRequest.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xb0\x01\n\x1bResolveResourcePathResponse\x12\x16\n\x0ewarehouse_kind\x18\x01 \x01(\t\x12I\n\x07\x63ontext\x18\x02 \x03(\x0b\x32\x38.io.openaristos.ResolveResourcePathResponse.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x0b\n\tPSRequest"\xec\x01\n\nPSResponse\x12<\n\x12ingestion_sessions\x18\x01 \x03(\x0b\x32 .io.openaristos.IngestionSession\x12\x43\n\x10publish_sessions\x18\x02 \x03(\x0b\x32).io.openaristos.PSResponse.PublishSession\x1a[\n\x0ePublishSession\x12\x14\n\x0cingestion_id\x18\x01 \x01(\r\x12\x11\n\twarehouse\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t"D\n$ListIngestionSessionArtifactsRequest\x12\x1c\n\x14ingestion_session_id\x18\x01 \x01(\r"\x94\x01\n%ListIngestionSessionArtifactsResponse\x12\x17\n\x0f\x61ssets_location\x18\x01 \x01(\t\x12\x1e\n\x16relationships_location\x18\x02 \x01(\t\x12\x19\n\x11\x65ntities_location\x18\x03 \x01(\t\x12\x17\n\x0f\x65rrors_location\x18\x04 \x01(\t"\xd9\x01\n\x1cListIngestionSessionsRequest\x12)\n\x05since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x61pter\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x04 \x01(\t\x12=\n\x12pagination_options\x18\x05 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x93\x03\n\x10IngestionSession\x12\n\n\x02id\x18\x01 \x01(\r\x12\x36\n\x06status\x18\x02 \x01(\x0e\x32&.io.openaristos.IngestionSessionStatus\x12\x12\n\nwarehouses\x18\x03 \x03(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x04 \x01(\t\x12\x14\n\x0clanding_zone\x18\x05 \x01(\t\x12\x18\n\x10mastering_engine\x18\x06 \x01(\t\x12\x44\n\nparameters\x18\x07 \x03(\x0b\x32\x30.io.openaristos.IngestionSession.ParametersEntry\x12=\n\x12publishing_details\x18\x08 \x03(\x0b\x32!.io.openaristos.PublishingDetails\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x9c\x01\n\x1dListIngestionSessionsResponse\x12<\n\x12ingestion_sessions\x18\x01 \x03(\x0b\x32 .io.openaristos.IngestionSession\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"o\n\x11PublishingDetails\x12\x10\n\x08resource\x18\x01 \x01(\t\x12\x11\n\twarehouse\x18\x02 \x01(\t\x12\x35\n\x06status\x18\x03 \x01(\x0e\x32%.io.openaristos.ResourcePublishStatus"K\n\x17\x41pplyPerspectiveRequest\x12\x30\n\x0bperspective\x18\x01 \x01(\x0b\x32\x1b.io.openaristos.Perspective"\x1a\n\x18\x41pplyPerspectiveResponse"E\n\x19RetractPerspectiveRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\x12\x18\n\x10perspective_code\x18\x02 \x01(\t"\x1c\n\x1aRetractPerspectiveResponse"f\n\x16ListPerspectiveRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"\x8b\x01\n\x17ListPerspectiveResponse\x12\x31\n\x0cperspectives\x18\x01 \x03(\x0b\x32\x1b.io.openaristos.Perspective\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"b\n\rEventMetadata\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12/\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nevent_type\x18\x03 \x01(\t"\x92\x01\n\x1aPublishResourceFailedEvent\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\t\x12\x1c\n\x14ingestion_session_id\x18\x04 \x01(\r"\x94\x01\n\x1cPublishResourceCompleteEvent\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\t\x12\x1c\n\x14ingestion_session_id\x18\x04 \x01(\r"\x98\x01\n$ExecuteIngestionSessionCompleteEvent\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12?\n\x07request\x18\x02 \x01(\x0b\x32..io.openaristos.ExecuteIngestionSessionRequest"\x96\x01\n"ExecuteIngestionSessionFailedEvent\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12?\n\x07request\x18\x02 \x01(\x0b\x32..io.openaristos.ExecuteIngestionSessionRequest"\xad\x01\n\x1cIngestionSessionCreatedEvent\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12\x1c\n\x14ingestion_session_id\x18\x02 \x01(\r\x12>\n\x07request\x18\x03 \x01(\x0b\x32-.io.openaristos.CreateIngestionSessionRequest"~\n\x16ResolveUniverseRequest\x12*\n\x08universe\x18\x01 \x01(\x0b\x32\x18.io.openaristos.Universe\x12\x38\n\x10\x65\x66\x66\x65\x63tive_dating\x18\x02 \x01(\x0b\x32\x1e.io.openaristos.TimestampRange"R\n\x19ResolveUniverseGroupEntry\x12\x35\n\x07\x65ntries\x18\x01 \x03(\x0b\x32$.io.openaristos.ResolveUniverseEntry"j\n\x14ResolveUniverseEntry\x12\x11\n\tattribute\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x30\n\tdata_type\x18\x03 \x01(\x0e\x32\x1d.io.openaristos.AttributeType"\xcc\x01\n\nErrorEntry\x12\x0f\n\x07message\x18\x01 \x01(\t\x12/\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstacktrace\x18\x03 \x01(\t\x12\x38\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\'.io.openaristos.ErrorEntry.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x14\n\x12HealthCheckRequest"\xb9\x02\n\x13HealthCheckResponse\x12=\n\x08services\x18\x01 \x03(\x0b\x32+.io.openaristos.HealthCheckResponse.Service\x1aY\n\rServiceStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x06status\x18\x02 \x01(\x0e\x32*.io.openaristos.HealthCheckResponse.Status\x1a_\n\x07Service\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x43\n\x08statuses\x18\x02 \x03(\x0b\x32\x31.io.openaristos.HealthCheckResponse.ServiceStatus"\'\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02"\xa2\x01\n\x15\x45ntityCoverageRequest\x12*\n\x08universe\x18\x01 \x01(\x0b\x32\x18.io.openaristos.Universe\x12\x14\n\x0cperspectives\x18\x02 \x03(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\x38\n\x10\x65\x66\x66\x65\x63tive_dating\x18\x04 \x01(\x0b\x32\x1e.io.openaristos.TimestampRange"V\n\x16\x45ntityCoverageResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.io.openaristos.EntityCoverageResponseEntry"D\n\x1b\x45ntityCoverageResponseEntry\x12\x13\n\x0bperspective\x18\x01 \x01(\t\x12\x10\n\x08\x63overage\x18\x02 \x01(\x02"\xcd\x01\n\x08\x41ppInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x10\n\x08repeated\x18\x05 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x06 \x03(\x0b\x32%.io.openaristos.AppInput.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x82\x01\n\tAppOutput\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x37\n\x07\x63ontext\x18\x02 \x03(\x0b\x32&.io.openaristos.AppOutput.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x9d\x01\n\x13\x41ppExecutionProfile\x12\x13\n\x0b\x65ngine_kind\x18\x01 \x01(\t\x12\x41\n\x07\x63ontext\x18\x02 \x03(\x0b\x32\x30.io.openaristos.AppExecutionProfile.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xb2\x01\n\nDependency\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12,\n\x04kind\x18\x02 \x01(\x0e\x32\x1e.io.openaristos.DependencyKind\x12\x38\n\x07\x63ontext\x18\x03 \x03(\x0b\x32\'.io.openaristos.Dependency.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xf3\x01\n\x03\x41pp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12(\n\x06inputs\x18\x05 \x03(\x0b\x32\x18.io.openaristos.AppInput\x12*\n\x07outputs\x18\x06 \x03(\x0b\x32\x19.io.openaristos.AppOutput\x12?\n\x12\x65xecution_profiles\x18\x07 \x03(\x0b\x32#.io.openaristos.AppExecutionProfile\x12\x14\n\x0c\x64\x65pendencies\x18\x08 \x03(\t"3\n\x0f\x41pplyAppRequest\x12 \n\x03\x61pp\x18\x01 \x01(\x0b\x32\x13.io.openaristos.App"\x12\n\x10\x41pplyAppResponse"i\n\x11\x45xecuteAppRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06\x65ngine\x18\x02 \x01(\t\x12\x36\n\x06inputs\x18\x03 \x03(\x0b\x32&.io.openaristos.ExecuteAppRequestInput"4\n\x16\x45xecuteAppRequestInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"\x14\n\x12\x45xecuteAppResponse"H\n\x16\x41pplyDependencyRequest\x12.\n\ndependency\x18\x01 \x01(\x0b\x32\x1a.io.openaristos.Dependency"\x19\n\x17\x41pplyDependencyResponse"^\n\x0eListAppRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12=\n\x12pagination_options\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationOptions"s\n\x0fListAppResponse\x12!\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x13.io.openaristos.App\x12=\n\x12pagination_details\x18\x02 \x01(\x0b\x32!.io.openaristos.PaginationDetails"\xb3\x01\n\x10\x45mitEventRequest\x12/\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.io.openaristos.EventMetadata\x12>\n\x07\x63ontext\x18\x02 \x03(\x0b\x32-.io.openaristos.EmitEventRequest.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"!\n\x11\x45mitEventResponse\x12\x0c\n\x04uuid\x18\x01 \x01(\t*B\n\x0e\x43omparisonType\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02LT\x10\x01\x12\x07\n\x03LTE\x10\x02\x12\x06\n\x02GT\x10\x03\x12\x07\n\x03GTE\x10\x04\x12\x06\n\x02NE\x10\x05*+\n\x0e\x44\x65pendencyKind\x12\x19\n\x15\x44\x45PENDENCY_KIND_EVENT\x10\x00*>\n\rAppOutputKind\x12\x14\n\x10\x41PP_OUTPUT_EVENT\x10\x00\x12\x17\n\x13\x41PP_OUTPUT_RESOURCE\x10\x01*\xc1\x01\n\rAttributeType\x12\n\n\x06STRING\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\x0b\n\x07NUMERIC\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x46LOATING\x10\x05\x12\t\n\x05\x42YTES\x10\x06\x12\x08\n\x04\x44\x41TE\x10\x07\x12\x0c\n\x08\x44\x41TETIME\x10\x08\x12\x08\n\x04TIME\x10\t\x12\x13\n\x0fTIMESTAMP_RANGE\x10\n\x12\x08\n\x04JSON\x10\x0b\x12\x08\n\x04TEXT\x10\x0c\x12\n\n\x06\x42IGINT\x10\r*Z\n\x16IngestionSessionStatus\x12\x07\n\x03NEW\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\r\n\tCANCELLED\x10\x04*Z\n\x15ResourcePublishStatus\x12\x0f\n\x0bUNPUBLISHED\x10\x00\x12\x0e\n\nPUBLISHING\x10\x01\x12\r\n\tPUBLISHED\x10\x02\x12\x11\n\rPUBLISH_ERROR\x10\x03\x32\xdc\x37\n\x08\x42\x61kplane\x12Y\n\x0c\x41pplyAdapter\x12#.io.openaristos.ApplyAdapterRequest\x1a$.io.openaristos.ApplyAdapterResponse\x12_\n\x0eRetractAdapter\x12%.io.openaristos.RetractAdapterRequest\x1a&.io.openaristos.RetractAdapterResponse\x12V\n\x0bListAdapter\x12".io.openaristos.ListAdapterRequest\x1a#.io.openaristos.ListAdapterResponse\x12\\\n\rEnableAdapter\x12$.io.openaristos.EnableAdapterRequest\x1a%.io.openaristos.EnableAdapterResponse\x12_\n\x0e\x44isableAdapter\x12%.io.openaristos.DisableAdapterRequest\x1a&.io.openaristos.DisableAdapterResponse\x12\\\n\rApplyResource\x12$.io.openaristos.ApplyResourceRequest\x1a%.io.openaristos.ApplyResourceResponse\x12\x62\n\x0fRetractResource\x12&.io.openaristos.RetractResourceRequest\x1a\'.io.openaristos.RetractResourceResponse\x12Z\n\rListResources\x12#.io.openaristos.ListResourceRequest\x1a$.io.openaristos.ListResourceResponse\x12_\n\x0e\x45nableResource\x12%.io.openaristos.EnableResourceRequest\x1a&.io.openaristos.EnableResourceResponse\x12\x62\n\x0fPreviewResource\x12&.io.openaristos.PreviewResourceRequest\x1a\'.io.openaristos.PreviewResourceResponse\x12\x62\n\x0f\x44isableResource\x12&.io.openaristos.DisableResourceRequest\x1a\'.io.openaristos.DisableResourceResponse\x12\x62\n\x0fMigrateResource\x12&.io.openaristos.MigrateResourceRequest\x1a\'.io.openaristos.MigrateResourceResponse\x12n\n\x13MigrateAllResources\x12*.io.openaristos.MigrateAllResourcesRequest\x1a+.io.openaristos.MigrateAllResourcesResponse\x12j\n\x17ResourceMigrationStatus\x12&.io.openaristos.MigrationStatusRequest\x1a\'.io.openaristos.MigrateResourceResponse\x12\x64\n\x0fResolveResource\x12&.io.openaristos.ResolveResourceRequest\x1a\'.io.openaristos.ResolveResourceResponse0\x01\x12n\n\x15ResolveResourceIntent\x12&.io.openaristos.ResolveResourceRequest\x1a-.io.openaristos.ResolveResourceIntentResponse\x12q\n\x14ResolveQueryResource\x12+.io.openaristos.ResolveQueryResourceRequest\x1a,.io.openaristos.ResolveQueryResourceResponse\x12\x66\n\x0fResolveUniverse\x12&.io.openaristos.ResolveUniverseRequest\x1a).io.openaristos.ResolveUniverseGroupEntry0\x01\x12\x65\n\x10\x41pplyLandingZone\x12\'.io.openaristos.ApplyLandingZoneRequest\x1a(.io.openaristos.ApplyLandingZoneResponse\x12k\n\x12RetractLandingZone\x12).io.openaristos.RetractLandingZoneRequest\x1a*.io.openaristos.RetractLandingZoneResponse\x12\x62\n\x0fListLandingZone\x12&.io.openaristos.ListLandingZoneRequest\x1a\'.io.openaristos.ListLandingZoneResponse\x12h\n\x11\x45nableLandingZone\x12(.io.openaristos.EnableLandingZoneRequest\x1a).io.openaristos.EnableLandingZoneResponse\x12k\n\x12\x44isableLandingZone\x12).io.openaristos.DisableLandingZoneRequest\x1a*.io.openaristos.DisableLandingZoneResponse\x12\\\n\rApplyOntology\x12$.io.openaristos.ApplyOntologyRequest\x1a%.io.openaristos.ApplyOntologyResponse\x12\x62\n\x0fRetractOntology\x12&.io.openaristos.RetractOntologyRequest\x1a\'.io.openaristos.RetractOntologyResponse\x12Y\n\x0cListOntology\x12#.io.openaristos.ListOntologyRequest\x1a$.io.openaristos.ListOntologyResponse\x12q\n\x14\x41pplyExecutionEngine\x12+.io.openaristos.ApplyExecutionEngineRequest\x1a,.io.openaristos.ApplyExecutionEngineResponse\x12w\n\x16RetractExecutionEngine\x12-.io.openaristos.RetractExecutionEngineRequest\x1a..io.openaristos.RetractExecutionEngineResponse\x12n\n\x13ListExecutionEngine\x12*.io.openaristos.ListExecutionEngineRequest\x1a+.io.openaristos.ListExecutionEngineResponse\x12t\n\x15\x45nableExecutionEngine\x12,.io.openaristos.EnableExecutionEngineRequest\x1a-.io.openaristos.EnableExecutionEngineResponse\x12w\n\x16\x44isableExecutionEngine\x12-.io.openaristos.DisableExecutionEngineRequest\x1a..io.openaristos.DisableExecutionEngineResponse\x12_\n\x0e\x41pplyWarehouse\x12%.io.openaristos.ApplyWarehouseRequest\x1a&.io.openaristos.ApplyWarehouseResponse\x12_\n\x0e\x41pplyValidator\x12%.io.openaristos.ApplyValidatorRequest\x1a&.io.openaristos.ApplyValidatorResponse\x12\x65\n\x10RetractValidator\x12\'.io.openaristos.RetractValidatorRequest\x1a(.io.openaristos.RetractValidatorResponse\x12\\\n\rListValidator\x12$.io.openaristos.ListValidatorRequest\x1a%.io.openaristos.ListValidatorResponse\x12\x65\n\x10RetractWarehouse\x12\'.io.openaristos.RetractWarehouseRequest\x1a(.io.openaristos.RetractWarehouseResponse\x12\\\n\rListWarehouse\x12$.io.openaristos.ListWarehouseRequest\x1a%.io.openaristos.ListWarehouseResponse\x12\x62\n\x0f\x45nableWarehouse\x12&.io.openaristos.EnableWarehouseRequest\x1a\'.io.openaristos.EnableWarehouseResponse\x12\x65\n\x10\x44isableWarehouse\x12\'.io.openaristos.DisableWarehouseRequest\x1a(.io.openaristos.DisableWarehouseResponse\x12q\n\x14\x41pplyMasteringEngine\x12+.io.openaristos.ApplyMasteringEngineRequest\x1a,.io.openaristos.ApplyMasteringEngineResponse\x12w\n\x16RetractMasteringEngine\x12-.io.openaristos.RetractMasteringEngineRequest\x1a..io.openaristos.RetractMasteringEngineResponse\x12n\n\x13ListMasteringEngine\x12*.io.openaristos.ListMasteringEngineRequest\x1a+.io.openaristos.ListMasteringEngineResponse\x12w\n\x16\x43reateIngestionSession\x12-.io.openaristos.CreateIngestionSessionRequest\x1a..io.openaristos.CreateIngestionSessionResponse\x12y\n\x17\x45xecuteIngestionSession\x12..io.openaristos.ExecuteIngestionSessionRequest\x1a..io.openaristos.IngestionSessionStatusResponse\x12w\n\x16\x44\x65leteIngestionSession\x12-.io.openaristos.DeleteIngestionSessionRequest\x1a..io.openaristos.DeleteIngestionSessionResponse\x12q\n\x13GetIngestionSession\x12*.io.openaristos.GetIngestionSessionRequest\x1a..io.openaristos.IngestionSessionStatusResponse\x12w\n\x16MasterIngestionSession\x12-.io.openaristos.MasterIngestionSessionRequest\x1a..io.openaristos.MasterIngestionSessionResponse\x12}\n\x18HaltIncrementalMastering\x12/.io.openaristos.HaltIncrementalMasteringRequest\x1a\x30.io.openaristos.HaltIncrementalMasteringResponse\x12\x83\x01\n\x1aResumeIncrementalMastering\x12\x31.io.openaristos.ResumeIncrementalMasteringRequest\x1a\x32.io.openaristos.ResumeIncrementalMasteringResponse\x12\x92\x01\n\x1fPublishIngestionSessionResource\x12\x36.io.openaristos.PublishIngestionSessionResourceRequest\x1a\x37.io.openaristos.PublishIngestionSessionResourceResponse\x12\x9c\x01\n%PublishIngestionSessionResourceStatus\x12<.io.openaristos.PublishIngestionSessionResourceStatusRequest\x1a\x35.io.openaristos.PublishIngestionSessionStatusResponse\x12}\n\x18RetractPublishingSession\x12/.io.openaristos.RetractPublishingSessionRequest\x1a\x30.io.openaristos.RetractPublishingSessionResponse\x12z\n\x17RetractMasteringSession\x12..io.openaristos.RetractMasteringSessionRequest\x1a/.io.openaristos.RetractMasteringSessionResponse\x12n\n\x13ResolveResourcePath\x12*.io.openaristos.ResolveResourcePathRequest\x1a+.io.openaristos.ResolveResourcePathResponse\x12\x8c\x01\n\x1dListIngestionSessionArtifacts\x12\x34.io.openaristos.ListIngestionSessionArtifactsRequest\x1a\x35.io.openaristos.ListIngestionSessionArtifactsResponse\x12t\n\x15ListIngestionSessions\x12,.io.openaristos.ListIngestionSessionsRequest\x1a-.io.openaristos.ListIngestionSessionsResponse\x12\x42\n\tSessionPS\x12\x19.io.openaristos.PSRequest\x1a\x1a.io.openaristos.PSResponse\x12\x65\n\x10\x41pplyPerspective\x12\'.io.openaristos.ApplyPerspectiveRequest\x1a(.io.openaristos.ApplyPerspectiveResponse\x12k\n\x12RetractPerspective\x12).io.openaristos.RetractPerspectiveRequest\x1a*.io.openaristos.RetractPerspectiveResponse\x12\x62\n\x0fListPerspective\x12&.io.openaristos.ListPerspectiveRequest\x1a\'.io.openaristos.ListPerspectiveResponse\x12V\n\x0bHealthCheck\x12".io.openaristos.HealthCheckRequest\x1a#.io.openaristos.HealthCheckResponse\x12_\n\x0e\x45ntityCoverage\x12%.io.openaristos.EntityCoverageRequest\x1a&.io.openaristos.EntityCoverageResponse\x12M\n\x08\x41pplyApp\x12\x1f.io.openaristos.ApplyAppRequest\x1a .io.openaristos.ApplyAppResponse\x12S\n\nExecuteApp\x12!.io.openaristos.ExecuteAppRequest\x1a".io.openaristos.ExecuteAppResponse\x12\x62\n\x0f\x41pplyDependency\x12&.io.openaristos.ApplyDependencyRequest\x1a\'.io.openaristos.ApplyDependencyResponse\x12J\n\x07ListApp\x12\x1e.io.openaristos.ListAppRequest\x1a\x1f.io.openaristos.ListAppResponse\x12P\n\tEmitEvent\x12 .io.openaristos.EmitEventRequest\x1a!.io.openaristos.EmitEventResponseB6\n\x0eio.openaristosB\rBakplaneProtoP\x01Z\x0eproto/bakplane\xa2\x02\x02\x42Pb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_COMPARISONTYPE = _descriptor.EnumDescriptor(
    name="ComparisonType",
    full_name="io.openaristos.ComparisonType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="EQ",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LTE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GT",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GTE",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="NE",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21035,
    serialized_end=21101,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONTYPE)

ComparisonType = enum_type_wrapper.EnumTypeWrapper(_COMPARISONTYPE)
_DEPENDENCYKIND = _descriptor.EnumDescriptor(
    name="DependencyKind",
    full_name="io.openaristos.DependencyKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DEPENDENCY_KIND_EVENT",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21103,
    serialized_end=21146,
)
_sym_db.RegisterEnumDescriptor(_DEPENDENCYKIND)

DependencyKind = enum_type_wrapper.EnumTypeWrapper(_DEPENDENCYKIND)
_APPOUTPUTKIND = _descriptor.EnumDescriptor(
    name="AppOutputKind",
    full_name="io.openaristos.AppOutputKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="APP_OUTPUT_EVENT",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="APP_OUTPUT_RESOURCE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21148,
    serialized_end=21210,
)
_sym_db.RegisterEnumDescriptor(_APPOUTPUTKIND)

AppOutputKind = enum_type_wrapper.EnumTypeWrapper(_APPOUTPUTKIND)
_ATTRIBUTETYPE = _descriptor.EnumDescriptor(
    name="AttributeType",
    full_name="io.openaristos.AttributeType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STRING",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INTEGER",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="NUMERIC",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIMESTAMP",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOLEAN",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FLOATING",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BYTES",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DATE",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DATETIME",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIME",
            index=9,
            number=9,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIMESTAMP_RANGE",
            index=10,
            number=10,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="JSON",
            index=11,
            number=11,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TEXT",
            index=12,
            number=12,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BIGINT",
            index=13,
            number=13,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21213,
    serialized_end=21406,
)
_sym_db.RegisterEnumDescriptor(_ATTRIBUTETYPE)

AttributeType = enum_type_wrapper.EnumTypeWrapper(_ATTRIBUTETYPE)
_INGESTIONSESSIONSTATUS = _descriptor.EnumDescriptor(
    name="IngestionSessionStatus",
    full_name="io.openaristos.IngestionSessionStatus",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NEW",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IN_PROGRESS",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="COMPLETE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ERROR",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CANCELLED",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21408,
    serialized_end=21498,
)
_sym_db.RegisterEnumDescriptor(_INGESTIONSESSIONSTATUS)

IngestionSessionStatus = enum_type_wrapper.EnumTypeWrapper(
    _INGESTIONSESSIONSTATUS
)
_RESOURCEPUBLISHSTATUS = _descriptor.EnumDescriptor(
    name="ResourcePublishStatus",
    full_name="io.openaristos.ResourcePublishStatus",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNPUBLISHED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PUBLISHING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PUBLISHED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PUBLISH_ERROR",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=21500,
    serialized_end=21590,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEPUBLISHSTATUS)

ResourcePublishStatus = enum_type_wrapper.EnumTypeWrapper(
    _RESOURCEPUBLISHSTATUS
)
EQ = 0
LT = 1
LTE = 2
GT = 3
GTE = 4
NE = 5
DEPENDENCY_KIND_EVENT = 0
APP_OUTPUT_EVENT = 0
APP_OUTPUT_RESOURCE = 1
STRING = 0
INTEGER = 1
NUMERIC = 2
TIMESTAMP = 3
BOOLEAN = 4
FLOATING = 5
BYTES = 6
DATE = 7
DATETIME = 8
TIME = 9
TIMESTAMP_RANGE = 10
JSON = 11
TEXT = 12
BIGINT = 13
NEW = 0
IN_PROGRESS = 1
COMPLETE = 2
ERROR = 3
CANCELLED = 4
UNPUBLISHED = 0
PUBLISHING = 1
PUBLISHED = 2
PUBLISH_ERROR = 3


_MIGRATERESOURCEREQUEST_DIRECTION = _descriptor.EnumDescriptor(
    name="Direction",
    full_name="io.openaristos.MigrateResourceRequest.Direction",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UP",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOWN",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DROP",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=848,
    serialized_end=887,
)
_sym_db.RegisterEnumDescriptor(_MIGRATERESOURCEREQUEST_DIRECTION)

_MIGRATEALLRESOURCESREQUEST_DIRECTION = _descriptor.EnumDescriptor(
    name="Direction",
    full_name="io.openaristos.MigrateAllResourcesRequest.Direction",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UP",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOWN",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DROP",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=848,
    serialized_end=887,
)
_sym_db.RegisterEnumDescriptor(_MIGRATEALLRESOURCESREQUEST_DIRECTION)

_SCHEMAATTRIBUTE_MAPPINGTYPE = _descriptor.EnumDescriptor(
    name="MappingType",
    full_name="io.openaristos.SchemaAttribute.MappingType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="IDENTIFIER",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PARTIAL_IDENTIFIER",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DESC",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IGNORED",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4504,
    serialized_end=4580,
)
_sym_db.RegisterEnumDescriptor(_SCHEMAATTRIBUTE_MAPPINGTYPE)

_VALIDATOR_VALIDATORKIND = _descriptor.EnumDescriptor(
    name="ValidatorKind",
    full_name="io.openaristos.Validator.ValidatorKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="VALIDATOR_KIND_RESOURCE",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VALIDATOR_KIND_ADAPTER",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VALIDATOR_KIND_PERSPECTIVE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VALIDATOR_KIND_ENTITY_TYPE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6968,
    serialized_end=7104,
)
_sym_db.RegisterEnumDescriptor(_VALIDATOR_VALIDATORKIND)

_VALIDATOR_SCHEMAKIND = _descriptor.EnumDescriptor(
    name="SchemaKind",
    full_name="io.openaristos.Validator.SchemaKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SCHEMA_KIND_JSON_SCHEMA",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=7106,
    serialized_end=7147,
)
_sym_db.RegisterEnumDescriptor(_VALIDATOR_SCHEMAKIND)

_RETRACTPUBLISHINGSESSIONREQUEST_RETRACTIONTYPE = _descriptor.EnumDescriptor(
    name="RetractionType",
    full_name="io.openaristos.RetractPublishingSessionRequest.RetractionType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SOFT",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HARD",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=14709,
    serialized_end=14745,
)
_sym_db.RegisterEnumDescriptor(_RETRACTPUBLISHINGSESSIONREQUEST_RETRACTIONTYPE)

_HEALTHCHECKRESPONSE_STATUS = _descriptor.EnumDescriptor(
    name="Status",
    full_name="io.openaristos.HealthCheckResponse.Status",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="UP",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOWN",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=18956,
    serialized_end=18995,
)
_sym_db.RegisterEnumDescriptor(_HEALTHCHECKRESPONSE_STATUS)


_TIMESTAMPRANGE = _descriptor.Descriptor(
    name="TimestampRange",
    full_name="io.openaristos.TimestampRange",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_dt",
            full_name="io.openaristos.TimestampRange.start_dt",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_dt",
            full_name="io.openaristos.TimestampRange.end_dt",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=76,
    serialized_end=182,
)


_PAGINATIONOPTIONS = _descriptor.Descriptor(
    name="PaginationOptions",
    full_name="io.openaristos.PaginationOptions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="per_page",
            full_name="io.openaristos.PaginationOptions.per_page",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page",
            full_name="io.openaristos.PaginationOptions.page",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="io.openaristos.PaginationOptions.order_by",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=184,
    serialized_end=253,
)


_PAGINATIONDETAILS = _descriptor.Descriptor(
    name="PaginationDetails",
    full_name="io.openaristos.PaginationDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="total_pages",
            full_name="io.openaristos.PaginationDetails.total_pages",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="total_elements",
            full_name="io.openaristos.PaginationDetails.total_elements",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=255,
    serialized_end=319,
)


_UNIVERSE = _descriptor.Descriptor(
    name="Universe",
    full_name="io.openaristos.Universe",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="definition",
            full_name="io.openaristos.Universe.definition",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dialect",
            full_name="io.openaristos.Universe.dialect",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.Universe.engine",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=321,
    serialized_end=384,
)


_PERSPECTIVE = _descriptor.Descriptor(
    name="Perspective",
    full_name="io.openaristos.Perspective",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Perspective.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Perspective.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Perspective.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="weight",
            full_name="io.openaristos.Perspective.weight",
            index=3,
            number=4,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="permanent_attributes",
            full_name="io.openaristos.Perspective.permanent_attributes",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=387,
    serialized_end=542,
)


_PERSPECTIVEPERMANENTATTRIBUTE = _descriptor.Descriptor(
    name="PerspectivePermanentAttribute",
    full_name="io.openaristos.PerspectivePermanentAttribute",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entity_type_code",
            full_name="io.openaristos.PerspectivePermanentAttribute.entity_type_code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attribute_code",
            full_name="io.openaristos.PerspectivePermanentAttribute.attribute_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=544,
    serialized_end=625,
)


_MIGRATERESOURCEREQUEST_FORCE = _descriptor.Descriptor(
    name="Force",
    full_name="io.openaristos.MigrateResourceRequest.Force",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="io.openaristos.MigrateResourceRequest.Force.version",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=822,
    serialized_end=846,
)

_MIGRATERESOURCEREQUEST = _descriptor.Descriptor(
    name="MigrateResourceRequest",
    full_name="io.openaristos.MigrateResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.MigrateResourceRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.MigrateResourceRequest.warehouse_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="direction",
            full_name="io.openaristos.MigrateResourceRequest.direction",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="io.openaristos.MigrateResourceRequest.force",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _MIGRATERESOURCEREQUEST_FORCE,
    ],
    enum_types=[
        _MIGRATERESOURCEREQUEST_DIRECTION,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=628,
    serialized_end=887,
)


_MIGRATEALLRESOURCESREQUEST_FORCE = _descriptor.Descriptor(
    name="Force",
    full_name="io.openaristos.MigrateAllResourcesRequest.Force",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="io.openaristos.MigrateAllResourcesRequest.Force.version",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=822,
    serialized_end=846,
)

_MIGRATEALLRESOURCESREQUEST = _descriptor.Descriptor(
    name="MigrateAllResourcesRequest",
    full_name="io.openaristos.MigrateAllResourcesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="adapter_code",
            full_name="io.openaristos.MigrateAllResourcesRequest.adapter_code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.MigrateAllResourcesRequest.warehouse_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="direction",
            full_name="io.openaristos.MigrateAllResourcesRequest.direction",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="io.openaristos.MigrateAllResourcesRequest.force",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _MIGRATEALLRESOURCESREQUEST_FORCE,
    ],
    enum_types=[
        _MIGRATEALLRESOURCESREQUEST_DIRECTION,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=890,
    serialized_end=1169,
)


_MIGRATIONDETAILS = _descriptor.Descriptor(
    name="MigrationDetails",
    full_name="io.openaristos.MigrationDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="io.openaristos.MigrationDetails.version",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.MigrationDetails.warehouse_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.MigrationDetails.code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1171,
    serialized_end=1244,
)


_MIGRATEALLRESOURCESRESPONSE = _descriptor.Descriptor(
    name="MigrateAllResourcesResponse",
    full_name="io.openaristos.MigrateAllResourcesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="migrations",
            full_name="io.openaristos.MigrateAllResourcesResponse.migrations",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1246,
    serialized_end=1329,
)


_MIGRATIONSTATUSREQUEST = _descriptor.Descriptor(
    name="MigrationStatusRequest",
    full_name="io.openaristos.MigrationStatusRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.MigrationStatusRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.MigrationStatusRequest.warehouse_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1331,
    serialized_end=1393,
)


_MIGRATERESOURCERESPONSE = _descriptor.Descriptor(
    name="MigrateResourceResponse",
    full_name="io.openaristos.MigrateResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="migration",
            full_name="io.openaristos.MigrateResourceResponse.migration",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1395,
    serialized_end=1473,
)


_RESOLVERESOURCEREQUEST_POINTERSENTRY = _descriptor.Descriptor(
    name="PointersEntry",
    full_name="io.openaristos.ResolveResourceRequest.PointersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveResourceRequest.PointersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveResourceRequest.PointersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1709,
    serialized_end=1756,
)

_RESOLVERESOURCEREQUEST = _descriptor.Descriptor(
    name="ResolveResourceRequest",
    full_name="io.openaristos.ResolveResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="universe",
            full_name="io.openaristos.ResolveResourceRequest.universe",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="path",
            full_name="io.openaristos.ResolveResourceRequest.path",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.ResolveResourceRequest.warehouse",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effective_dating",
            full_name="io.openaristos.ResolveResourceRequest.effective_dating",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pointers",
            full_name="io.openaristos.ResolveResourceRequest.pointers",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVERESOURCEREQUEST_POINTERSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1476,
    serialized_end=1756,
)


_RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY = _descriptor.Descriptor(
    name="PointersEntry",
    full_name="io.openaristos.ResolveQueryResourceRequest.PointersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveQueryResourceRequest.PointersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveQueryResourceRequest.PointersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1709,
    serialized_end=1756,
)

_RESOLVEQUERYRESOURCEREQUEST = _descriptor.Descriptor(
    name="ResolveQueryResourceRequest",
    full_name="io.openaristos.ResolveQueryResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="path",
            full_name="io.openaristos.ResolveQueryResourceRequest.path",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.ResolveQueryResourceRequest.warehouse",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pointers",
            full_name="io.openaristos.ResolveQueryResourceRequest.pointers",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1759,
    serialized_end=1947,
)


_RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.ResolveQueryResourceResponse.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveQueryResourceResponse.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveQueryResourceResponse.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_RESOLVEQUERYRESOURCERESPONSE = _descriptor.Descriptor(
    name="ResolveQueryResourceResponse",
    full_name="io.openaristos.ResolveQueryResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.ResolveQueryResourceResponse.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="table_name",
            full_name="io.openaristos.ResolveQueryResourceResponse.table_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema_name",
            full_name="io.openaristos.ResolveQueryResourceResponse.schema_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mapping",
            full_name="io.openaristos.ResolveQueryResourceResponse.mapping",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="columns",
            full_name="io.openaristos.ResolveQueryResourceResponse.columns",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ResolveQueryResourceResponse.context",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1950,
    serialized_end=2278,
)


_RESOLVERESOURCEMAPPINGCONTEXTENTRY = _descriptor.Descriptor(
    name="ResolveResourceMappingContextEntry",
    full_name="io.openaristos.ResolveResourceMappingContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="source_field_name",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.source_field_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="target_field_expression",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.target_field_expression",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attribute_type",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.attribute_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="used_for_mapping",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.used_for_mapping",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="map_to_field_name",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.map_to_field_name",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_effective_dating",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.is_effective_dating",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="comparison_type",
            full_name="io.openaristos.ResolveResourceMappingContextEntry.comparison_type",
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2281,
    serialized_end=2571,
)


_RESOLVERESOURCERESPONSE = _descriptor.Descriptor(
    name="ResolveResourceResponse",
    full_name="io.openaristos.ResolveResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="row",
            full_name="io.openaristos.ResolveResourceResponse.row",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2573,
    serialized_end=2611,
)


_RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.ResolveResourceIntentResponse.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveResourceIntentResponse.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveResourceIntentResponse.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_RESOLVERESOURCEINTENTRESPONSE = _descriptor.Descriptor(
    name="ResolveResourceIntentResponse",
    full_name="io.openaristos.ResolveResourceIntentResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.ResolveResourceIntentResponse.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="table_name",
            full_name="io.openaristos.ResolveResourceIntentResponse.table_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema_name",
            full_name="io.openaristos.ResolveResourceIntentResponse.schema_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mapping",
            full_name="io.openaristos.ResolveResourceIntentResponse.mapping",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="columns",
            full_name="io.openaristos.ResolveResourceIntentResponse.columns",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ResolveResourceIntentResponse.context",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effective_dating",
            full_name="io.openaristos.ResolveResourceIntentResponse.effective_dating",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2614,
    serialized_end=3002,
)


_RESOLVERESOURCEINTENTMAPPING = _descriptor.Descriptor(
    name="ResolveResourceIntentMapping",
    full_name="io.openaristos.ResolveResourceIntentMapping",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="table_name",
            full_name="io.openaristos.ResolveResourceIntentMapping.table_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema_name",
            full_name="io.openaristos.ResolveResourceIntentMapping.schema_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="columns",
            full_name="io.openaristos.ResolveResourceIntentMapping.columns",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="clauses",
            full_name="io.openaristos.ResolveResourceIntentMapping.clauses",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3005,
    serialized_end=3191,
)


_COLUMNENTRY = _descriptor.Descriptor(
    name="ColumnEntry",
    full_name="io.openaristos.ColumnEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.ColumnEntry.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dataType",
            full_name="io.openaristos.ColumnEntry.dataType",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_effective_dating",
            full_name="io.openaristos.ColumnEntry.is_effective_dating",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3193,
    serialized_end=3267,
)


_RESOLVERESOURCEINTENTMAPPINGCLAUSE = _descriptor.Descriptor(
    name="ResolveResourceIntentMappingClause",
    full_name="io.openaristos.ResolveResourceIntentMappingClause",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resource_field_name",
            full_name="io.openaristos.ResolveResourceIntentMappingClause.resource_field_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mapping_field_name",
            full_name="io.openaristos.ResolveResourceIntentMappingClause.mapping_field_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="comparison",
            full_name="io.openaristos.ResolveResourceIntentMappingClause.comparison",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3270,
    serialized_end=3415,
)


_CONFIGURATIONENTRY = _descriptor.Descriptor(
    name="ConfigurationEntry",
    full_name="io.openaristos.ConfigurationEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ConfigurationEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ConfigurationEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3417,
    serialized_end=3465,
)


_APPLYLANDINGZONEREQUEST = _descriptor.Descriptor(
    name="ApplyLandingZoneRequest",
    full_name="io.openaristos.ApplyLandingZoneRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ApplyLandingZoneRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="plugin",
            full_name="io.openaristos.ApplyLandingZoneRequest.plugin",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="configurations",
            full_name="io.openaristos.ApplyLandingZoneRequest.configurations",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3467,
    serialized_end=3582,
)


_APPLYLANDINGZONERESPONSE = _descriptor.Descriptor(
    name="ApplyLandingZoneResponse",
    full_name="io.openaristos.ApplyLandingZoneResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3584,
    serialized_end=3610,
)


_RETRACTLANDINGZONEREQUEST = _descriptor.Descriptor(
    name="RetractLandingZoneRequest",
    full_name="io.openaristos.RetractLandingZoneRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractLandingZoneRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3612,
    serialized_end=3653,
)


_RETRACTLANDINGZONERESPONSE = _descriptor.Descriptor(
    name="RetractLandingZoneResponse",
    full_name="io.openaristos.RetractLandingZoneResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3655,
    serialized_end=3683,
)


_LISTLANDINGZONEREQUEST = _descriptor.Descriptor(
    name="ListLandingZoneRequest",
    full_name="io.openaristos.ListLandingZoneRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListLandingZoneRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListLandingZoneRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3685,
    serialized_end=3787,
)


_LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS = _descriptor.Descriptor(
    name="LandingZoneDetails",
    full_name="io.openaristos.ListLandingZoneResponse.LandingZoneDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ListLandingZoneResponse.LandingZoneDetails.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="plugin",
            full_name="io.openaristos.ListLandingZoneResponse.LandingZoneDetails.plugin",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="active",
            full_name="io.openaristos.ListLandingZoneResponse.LandingZoneDetails.active",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="configurations",
            full_name="io.openaristos.ListLandingZoneResponse.LandingZoneDetails.configurations",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3963,
    serialized_end=4089,
)

_LISTLANDINGZONERESPONSE = _descriptor.Descriptor(
    name="ListLandingZoneResponse",
    full_name="io.openaristos.ListLandingZoneResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="landing_zones",
            full_name="io.openaristos.ListLandingZoneResponse.landing_zones",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListLandingZoneResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3790,
    serialized_end=4089,
)


_ENABLELANDINGZONEREQUEST = _descriptor.Descriptor(
    name="EnableLandingZoneRequest",
    full_name="io.openaristos.EnableLandingZoneRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EnableLandingZoneRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4091,
    serialized_end=4131,
)


_ENABLELANDINGZONERESPONSE = _descriptor.Descriptor(
    name="EnableLandingZoneResponse",
    full_name="io.openaristos.EnableLandingZoneResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4133,
    serialized_end=4160,
)


_DISABLELANDINGZONEREQUEST = _descriptor.Descriptor(
    name="DisableLandingZoneRequest",
    full_name="io.openaristos.DisableLandingZoneRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.DisableLandingZoneRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4162,
    serialized_end=4203,
)


_DISABLELANDINGZONERESPONSE = _descriptor.Descriptor(
    name="DisableLandingZoneResponse",
    full_name="io.openaristos.DisableLandingZoneResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4205,
    serialized_end=4233,
)


_SCHEMAATTRIBUTE = _descriptor.Descriptor(
    name="SchemaAttribute",
    full_name="io.openaristos.SchemaAttribute",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.SchemaAttribute.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.SchemaAttribute.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.SchemaAttribute.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="io.openaristos.SchemaAttribute.data_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mode",
            full_name="io.openaristos.SchemaAttribute.mode",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="indexable",
            full_name="io.openaristos.SchemaAttribute.indexable",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mapping_type",
            full_name="io.openaristos.SchemaAttribute.mapping_type",
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="precision",
            full_name="io.openaristos.SchemaAttribute.precision",
            index=7,
            number=8,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="scale",
            full_name="io.openaristos.SchemaAttribute.scale",
            index=8,
            number=9,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="length",
            full_name="io.openaristos.SchemaAttribute.length",
            index=9,
            number=10,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _SCHEMAATTRIBUTE_MAPPINGTYPE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4236,
    serialized_end=4580,
)


_SCHEMA = _descriptor.Descriptor(
    name="Schema",
    full_name="io.openaristos.Schema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Schema.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Schema.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Schema.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attributes",
            full_name="io.openaristos.Schema.attributes",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4582,
    serialized_end=4692,
)


_MAPPINGCONTEXT = _descriptor.Descriptor(
    name="MappingContext",
    full_name="io.openaristos.MappingContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="concatenation_rules",
            full_name="io.openaristos.MappingContext.concatenation_rules",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4694,
    serialized_end=4781,
)


_MAPPINGCONCATENATIONRULE = _descriptor.Descriptor(
    name="MappingConcatenationRule",
    full_name="io.openaristos.MappingConcatenationRule",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="io.openaristos.MappingConcatenationRule.entries",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4783,
    serialized_end=4826,
)


_ENTITYTYPE = _descriptor.Descriptor(
    name="EntityType",
    full_name="io.openaristos.EntityType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.EntityType.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EntityType.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.EntityType.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="io.openaristos.EntityType.schema",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mapping",
            full_name="io.openaristos.EntityType.mapping",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4829,
    serialized_end=4979,
)


_RELATIONSHIPTYPE = _descriptor.Descriptor(
    name="RelationshipType",
    full_name="io.openaristos.RelationshipType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.RelationshipType.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RelationshipType.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.RelationshipType.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="source_entity_type",
            full_name="io.openaristos.RelationshipType.source_entity_type",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="target_entity_type",
            full_name="io.openaristos.RelationshipType.target_entity_type",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4981,
    serialized_end=5104,
)


_APPLYONTOLOGYREQUEST = _descriptor.Descriptor(
    name="ApplyOntologyRequest",
    full_name="io.openaristos.ApplyOntologyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.ApplyOntologyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ApplyOntologyRequest.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.ApplyOntologyRequest.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities",
            full_name="io.openaristos.ApplyOntologyRequest.entities",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="relationships",
            full_name="io.openaristos.ApplyOntologyRequest.relationships",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5107,
    serialized_end=5281,
)


_APPLYONTOLOGYRESPONSE = _descriptor.Descriptor(
    name="ApplyOntologyResponse",
    full_name="io.openaristos.ApplyOntologyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5283,
    serialized_end=5306,
)


_RETRACTONTOLOGYREQUEST = _descriptor.Descriptor(
    name="RetractOntologyRequest",
    full_name="io.openaristos.RetractOntologyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractOntologyRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5308,
    serialized_end=5346,
)


_RETRACTONTOLOGYRESPONSE = _descriptor.Descriptor(
    name="RetractOntologyResponse",
    full_name="io.openaristos.RetractOntologyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5348,
    serialized_end=5373,
)


_LISTONTOLOGYREQUEST = _descriptor.Descriptor(
    name="ListOntologyRequest",
    full_name="io.openaristos.ListOntologyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListOntologyRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListOntologyRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5375,
    serialized_end=5474,
)


_ONTOLOGY = _descriptor.Descriptor(
    name="Ontology",
    full_name="io.openaristos.Ontology",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Ontology.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Ontology.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Ontology.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities",
            full_name="io.openaristos.Ontology.entities",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="relationships",
            full_name="io.openaristos.Ontology.relationships",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5477,
    serialized_end=5639,
)


_LISTONTOLOGYRESPONSE = _descriptor.Descriptor(
    name="ListOntologyResponse",
    full_name="io.openaristos.ListOntologyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ontologies",
            full_name="io.openaristos.ListOntologyResponse.ontologies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListOntologyResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5642,
    serialized_end=5773,
)


_EXECUTIONENGINE = _descriptor.Descriptor(
    name="ExecutionEngine",
    full_name="io.openaristos.ExecutionEngine",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.ExecutionEngine.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ExecutionEngine.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.ExecutionEngine.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="io.openaristos.ExecutionEngine.kind",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="plugin",
            full_name="io.openaristos.ExecutionEngine.plugin",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="configurations",
            full_name="io.openaristos.ExecutionEngine.configurations",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5776,
    serialized_end=5932,
)


_APPLYEXECUTIONENGINEREQUEST = _descriptor.Descriptor(
    name="ApplyExecutionEngineRequest",
    full_name="io.openaristos.ApplyExecutionEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.ApplyExecutionEngineRequest.engine",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5934,
    serialized_end=6012,
)


_APPLYEXECUTIONENGINERESPONSE = _descriptor.Descriptor(
    name="ApplyExecutionEngineResponse",
    full_name="io.openaristos.ApplyExecutionEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6014,
    serialized_end=6044,
)


_RETRACTEXECUTIONENGINEREQUEST = _descriptor.Descriptor(
    name="RetractExecutionEngineRequest",
    full_name="io.openaristos.RetractExecutionEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractExecutionEngineRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6046,
    serialized_end=6091,
)


_RETRACTEXECUTIONENGINERESPONSE = _descriptor.Descriptor(
    name="RetractExecutionEngineResponse",
    full_name="io.openaristos.RetractExecutionEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6093,
    serialized_end=6125,
)


_LISTEXECUTIONENGINEREQUEST = _descriptor.Descriptor(
    name="ListExecutionEngineRequest",
    full_name="io.openaristos.ListExecutionEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListExecutionEngineRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListExecutionEngineRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6127,
    serialized_end=6233,
)


_LISTEXECUTIONENGINERESPONSE = _descriptor.Descriptor(
    name="ListExecutionEngineResponse",
    full_name="io.openaristos.ListExecutionEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engines",
            full_name="io.openaristos.ListExecutionEngineResponse.engines",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListExecutionEngineResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6236,
    serialized_end=6378,
)


_ENABLEEXECUTIONENGINEREQUEST = _descriptor.Descriptor(
    name="EnableExecutionEngineRequest",
    full_name="io.openaristos.EnableExecutionEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EnableExecutionEngineRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6380,
    serialized_end=6424,
)


_ENABLEEXECUTIONENGINERESPONSE = _descriptor.Descriptor(
    name="EnableExecutionEngineResponse",
    full_name="io.openaristos.EnableExecutionEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6426,
    serialized_end=6457,
)


_DISABLEEXECUTIONENGINEREQUEST = _descriptor.Descriptor(
    name="DisableExecutionEngineRequest",
    full_name="io.openaristos.DisableExecutionEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.DisableExecutionEngineRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6459,
    serialized_end=6504,
)


_DISABLEEXECUTIONENGINERESPONSE = _descriptor.Descriptor(
    name="DisableExecutionEngineResponse",
    full_name="io.openaristos.DisableExecutionEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6506,
    serialized_end=6538,
)


_WAREHOUSE = _descriptor.Descriptor(
    name="Warehouse",
    full_name="io.openaristos.Warehouse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Warehouse.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Warehouse.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Warehouse.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="plugin",
            full_name="io.openaristos.Warehouse.plugin",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="io.openaristos.Warehouse.kind",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="configurations",
            full_name="io.openaristos.Warehouse.configurations",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6541,
    serialized_end=6691,
)


_APPLYWAREHOUSEREQUEST = _descriptor.Descriptor(
    name="ApplyWarehouseRequest",
    full_name="io.openaristos.ApplyWarehouseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.ApplyWarehouseRequest.warehouse",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6693,
    serialized_end=6762,
)


_VALIDATOR = _descriptor.Descriptor(
    name="Validator",
    full_name="io.openaristos.Validator",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Validator.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Validator.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Validator.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validator_kind",
            full_name="io.openaristos.Validator.validator_kind",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema_kind",
            full_name="io.openaristos.Validator.schema_kind",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="io.openaristos.Validator.schema",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _VALIDATOR_VALIDATORKIND,
        _VALIDATOR_SCHEMAKIND,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6765,
    serialized_end=7147,
)


_APPLYVALIDATORREQUEST = _descriptor.Descriptor(
    name="ApplyValidatorRequest",
    full_name="io.openaristos.ApplyValidatorRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="validator",
            full_name="io.openaristos.ApplyValidatorRequest.validator",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7149,
    serialized_end=7218,
)


_RETRACTVALIDATORREQUEST = _descriptor.Descriptor(
    name="RetractValidatorRequest",
    full_name="io.openaristos.RetractValidatorRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractValidatorRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7220,
    serialized_end=7259,
)


_RETRACTVALIDATORRESPONSE = _descriptor.Descriptor(
    name="RetractValidatorResponse",
    full_name="io.openaristos.RetractValidatorResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7261,
    serialized_end=7287,
)


_LISTVALIDATORREQUEST = _descriptor.Descriptor(
    name="ListValidatorRequest",
    full_name="io.openaristos.ListValidatorRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListValidatorRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListValidatorRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7289,
    serialized_end=7389,
)


_LISTVALIDATORRESPONSE = _descriptor.Descriptor(
    name="ListValidatorResponse",
    full_name="io.openaristos.ListValidatorResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="validators",
            full_name="io.openaristos.ListValidatorResponse.validators",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListValidatorResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7392,
    serialized_end=7525,
)


_APPLYVALIDATORRESPONSE = _descriptor.Descriptor(
    name="ApplyValidatorResponse",
    full_name="io.openaristos.ApplyValidatorResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7527,
    serialized_end=7551,
)


_APPLYWAREHOUSERESPONSE = _descriptor.Descriptor(
    name="ApplyWarehouseResponse",
    full_name="io.openaristos.ApplyWarehouseResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7553,
    serialized_end=7577,
)


_RETRACTWAREHOUSEREQUEST = _descriptor.Descriptor(
    name="RetractWarehouseRequest",
    full_name="io.openaristos.RetractWarehouseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractWarehouseRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7579,
    serialized_end=7618,
)


_RETRACTWAREHOUSERESPONSE = _descriptor.Descriptor(
    name="RetractWarehouseResponse",
    full_name="io.openaristos.RetractWarehouseResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7620,
    serialized_end=7646,
)


_LISTWAREHOUSEREQUEST = _descriptor.Descriptor(
    name="ListWarehouseRequest",
    full_name="io.openaristos.ListWarehouseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListWarehouseRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListWarehouseRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7648,
    serialized_end=7748,
)


_LISTWAREHOUSERESPONSE = _descriptor.Descriptor(
    name="ListWarehouseResponse",
    full_name="io.openaristos.ListWarehouseResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouses",
            full_name="io.openaristos.ListWarehouseResponse.warehouses",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListWarehouseResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7751,
    serialized_end=7884,
)


_ENABLEWAREHOUSEREQUEST = _descriptor.Descriptor(
    name="EnableWarehouseRequest",
    full_name="io.openaristos.EnableWarehouseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EnableWarehouseRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7886,
    serialized_end=7924,
)


_ENABLEWAREHOUSERESPONSE = _descriptor.Descriptor(
    name="EnableWarehouseResponse",
    full_name="io.openaristos.EnableWarehouseResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7926,
    serialized_end=7951,
)


_DISABLEWAREHOUSEREQUEST = _descriptor.Descriptor(
    name="DisableWarehouseRequest",
    full_name="io.openaristos.DisableWarehouseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.DisableWarehouseRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7953,
    serialized_end=7992,
)


_DISABLEWAREHOUSERESPONSE = _descriptor.Descriptor(
    name="DisableWarehouseResponse",
    full_name="io.openaristos.DisableWarehouseResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7994,
    serialized_end=8020,
)


_APPLYMASTERINGENGINEREQUEST = _descriptor.Descriptor(
    name="ApplyMasteringEngineRequest",
    full_name="io.openaristos.ApplyMasteringEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.ApplyMasteringEngineRequest.engine",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8022,
    serialized_end=8100,
)


_APPLYMASTERINGENGINERESPONSE = _descriptor.Descriptor(
    name="ApplyMasteringEngineResponse",
    full_name="io.openaristos.ApplyMasteringEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8102,
    serialized_end=8132,
)


_RETRACTMASTERINGENGINEREQUEST = _descriptor.Descriptor(
    name="RetractMasteringEngineRequest",
    full_name="io.openaristos.RetractMasteringEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractMasteringEngineRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8134,
    serialized_end=8179,
)


_RETRACTMASTERINGENGINERESPONSE = _descriptor.Descriptor(
    name="RetractMasteringEngineResponse",
    full_name="io.openaristos.RetractMasteringEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8181,
    serialized_end=8213,
)


_LISTMASTERINGENGINEREQUEST = _descriptor.Descriptor(
    name="ListMasteringEngineRequest",
    full_name="io.openaristos.ListMasteringEngineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListMasteringEngineRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListMasteringEngineRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8215,
    serialized_end=8321,
)


_LISTMASTERINGENGINERESPONSE = _descriptor.Descriptor(
    name="ListMasteringEngineResponse",
    full_name="io.openaristos.ListMasteringEngineResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="mastering_engines",
            full_name="io.openaristos.ListMasteringEngineResponse.mastering_engines",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListMasteringEngineResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8324,
    serialized_end=8476,
)


_MASTERINGENGINE = _descriptor.Descriptor(
    name="MasteringEngine",
    full_name="io.openaristos.MasteringEngine",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.MasteringEngine.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.MasteringEngine.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.MasteringEngine.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="plugin",
            full_name="io.openaristos.MasteringEngine.plugin",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="configurations",
            full_name="io.openaristos.MasteringEngine.configurations",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8479,
    serialized_end=8621,
)


_RESOURCESTORECONTEXTENTRY = _descriptor.Descriptor(
    name="ResourceStoreContextEntry",
    full_name="io.openaristos.ResourceStoreContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResourceStoreContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResourceStoreContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8623,
    serialized_end=8678,
)


_RESOURCESTORE = _descriptor.Descriptor(
    name="ResourceStore",
    full_name="io.openaristos.ResourceStore",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ResourceStore.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="virtual",
            full_name="io.openaristos.ResourceStore.virtual",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.ResourceStore.warehouse",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ResourceStore.context",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8680,
    serialized_end=8805,
)


_RESOURCEPOINTERENTRY = _descriptor.Descriptor(
    name="ResourcePointerEntry",
    full_name="io.openaristos.ResourcePointerEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ResourcePointerEntry.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type",
            full_name="io.openaristos.ResourcePointerEntry.entity_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8807,
    serialized_end=8864,
)


_RESOURCEMETADATAENTRY = _descriptor.Descriptor(
    name="ResourceMetadataEntry",
    full_name="io.openaristos.ResourceMetadataEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResourceMetadataEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResourceMetadataEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8866,
    serialized_end=8917,
)


_RESOURCECONTEXTPOINTERENTRY = _descriptor.Descriptor(
    name="ResourceContextPointerEntry",
    full_name="io.openaristos.ResourceContextPointerEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ResourceContextPointerEntry.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="column_name",
            full_name="io.openaristos.ResourceContextPointerEntry.column_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8919,
    serialized_end=8983,
)


_RESOURCEDATING = _descriptor.Descriptor(
    name="ResourceDating",
    full_name="io.openaristos.ResourceDating",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="effective_start_dt",
            full_name="io.openaristos.ResourceDating.effective_start_dt",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effective_end_dt",
            full_name="io.openaristos.ResourceDating.effective_end_dt",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="valid_start_dt",
            full_name="io.openaristos.ResourceDating.valid_start_dt",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="valid_end_dt",
            full_name="io.openaristos.ResourceDating.valid_end_dt",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="knowledge_start_dt",
            full_name="io.openaristos.ResourceDating.knowledge_start_dt",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="knowledge_end_dt",
            full_name="io.openaristos.ResourceDating.knowledge_end_dt",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8986,
    serialized_end=9156,
)


_RESOURCEHASHING = _descriptor.Descriptor(
    name="ResourceHashing",
    full_name="io.openaristos.ResourceHashing",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="knowledge_hash",
            full_name="io.openaristos.ResourceHashing.knowledge_hash",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload_hash",
            full_name="io.openaristos.ResourceHashing.payload_hash",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9158,
    serialized_end=9221,
)


_RESOURCERETRACTION = _descriptor.Descriptor(
    name="ResourceRetraction",
    full_name="io.openaristos.ResourceRetraction",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.ResourceRetraction.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="soft_steps",
            full_name="io.openaristos.ResourceRetraction.soft_steps",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="hard_steps",
            full_name="io.openaristos.ResourceRetraction.hard_steps",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9223,
    serialized_end=9307,
)


_RESOURCECONTEXT = _descriptor.Descriptor(
    name="ResourceContext",
    full_name="io.openaristos.ResourceContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.ResourceContext.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pointers",
            full_name="io.openaristos.ResourceContext.pointers",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dating",
            full_name="io.openaristos.ResourceContext.dating",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="hashing",
            full_name="io.openaristos.ResourceContext.hashing",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.ResourceContext.metadata",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="publishing",
            full_name="io.openaristos.ResourceContext.publishing",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="io.openaristos.ResourceContext.dataset",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retraction",
            full_name="io.openaristos.ResourceContext.retraction",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9310,
    serialized_end=9703,
)


_RESOURCE = _descriptor.Descriptor(
    name="Resource",
    full_name="io.openaristos.Resource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Resource.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="io.openaristos.Resource.kind",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="perspective_code",
            full_name="io.openaristos.Resource.perspective_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Resource.description",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Resource.name",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="io.openaristos.Resource.dataset",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="io.openaristos.Resource.schema",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pointers",
            full_name="io.openaristos.Resource.pointers",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stores",
            full_name="io.openaristos.Resource.stores",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retention_hours",
            full_name="io.openaristos.Resource.retention_hours",
            index=9,
            number=10,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.Resource.context",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="migrations",
            full_name="io.openaristos.Resource.migrations",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_virtual",
            full_name="io.openaristos.Resource.is_virtual",
            index=12,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="customer_metadata",
            full_name="io.openaristos.Resource.customer_metadata",
            index=13,
            number=14,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9706,
    serialized_end=10134,
)


_ADAPTER = _descriptor.Descriptor(
    name="Adapter",
    full_name="io.openaristos.Adapter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.Adapter.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Adapter.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.Adapter.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="author",
            full_name="io.openaristos.Adapter.author",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10136,
    serialized_end=10210,
)


_ADAPTERPERSISTENCE = _descriptor.Descriptor(
    name="AdapterPersistence",
    full_name="io.openaristos.AdapterPersistence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.AdapterPersistence.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="io.openaristos.AdapterPersistence.entries",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10212,
    serialized_end=10314,
)


_ADAPTERPERSISTENCEENTRY = _descriptor.Descriptor(
    name="AdapterPersistenceEntry",
    full_name="io.openaristos.AdapterPersistenceEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="steps",
            full_name="io.openaristos.AdapterPersistenceEntry.steps",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="merge_steps",
            full_name="io.openaristos.AdapterPersistenceEntry.merge_steps",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10316,
    serialized_end=10417,
)


_ADAPTERPERSISTENCESTEP = _descriptor.Descriptor(
    name="AdapterPersistenceStep",
    full_name="io.openaristos.AdapterPersistenceStep",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AdapterPersistenceStep.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.AdapterPersistenceStep.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10419,
    serialized_end=10471,
)


_ADAPTERMETADATA = _descriptor.Descriptor(
    name="AdapterMetadata",
    full_name="io.openaristos.AdapterMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="persistence",
            full_name="io.openaristos.AdapterMetadata.persistence",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retraction",
            full_name="io.openaristos.AdapterMetadata.retraction",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10474,
    serialized_end=10604,
)


_MIGRATION = _descriptor.Descriptor(
    name="Migration",
    full_name="io.openaristos.Migration",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.Migration.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="migrations_uri",
            full_name="io.openaristos.Migration.migrations_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schema_name",
            full_name="io.openaristos.Migration.schema_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="table_name",
            full_name="io.openaristos.Migration.table_name",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10606,
    serialized_end=10706,
)


_APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY = _descriptor.Descriptor(
    name="CustomerMetadataEntry",
    full_name="io.openaristos.ApplyAdapterRequest.CustomerMetadataEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ApplyAdapterRequest.CustomerMetadataEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ApplyAdapterRequest.CustomerMetadataEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11121,
    serialized_end=11176,
)

_APPLYADAPTERREQUEST = _descriptor.Descriptor(
    name="ApplyAdapterRequest",
    full_name="io.openaristos.ApplyAdapterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.ApplyAdapterRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ApplyAdapterRequest.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.ApplyAdapterRequest.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="author",
            full_name="io.openaristos.ApplyAdapterRequest.author",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="provider",
            full_name="io.openaristos.ApplyAdapterRequest.provider",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="execution_profiles",
            full_name="io.openaristos.ApplyAdapterRequest.execution_profiles",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="io.openaristos.ApplyAdapterRequest.parameters",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="io.openaristos.ApplyAdapterRequest.resources",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.ApplyAdapterRequest.metadata",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="customer_metadata",
            full_name="io.openaristos.ApplyAdapterRequest.customer_metadata",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10709,
    serialized_end=11176,
)


_APPLYADAPTERRESPONSE = _descriptor.Descriptor(
    name="ApplyAdapterResponse",
    full_name="io.openaristos.ApplyAdapterResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11178,
    serialized_end=11200,
)


_RETRACTADAPTERREQUEST = _descriptor.Descriptor(
    name="RetractAdapterRequest",
    full_name="io.openaristos.RetractAdapterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractAdapterRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11202,
    serialized_end=11239,
)


_RETRACTADAPTERRESPONSE = _descriptor.Descriptor(
    name="RetractAdapterResponse",
    full_name="io.openaristos.RetractAdapterResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11241,
    serialized_end=11265,
)


_LISTADAPTERREQUEST = _descriptor.Descriptor(
    name="ListAdapterRequest",
    full_name="io.openaristos.ListAdapterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListAdapterRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListAdapterRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11267,
    serialized_end=11365,
)


_LISTADAPTERRESPONSE_ADAPTERDETAILS = _descriptor.Descriptor(
    name="AdapterDetails",
    full_name="io.openaristos.ListAdapterResponse.AdapterDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="author",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.author",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="execution_profiles",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.execution_profiles",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.parameters",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.resources",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="customer_metadata",
            full_name="io.openaristos.ListAdapterResponse.AdapterDetails.customer_metadata",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11525,
    serialized_end=11802,
)

_LISTADAPTERRESPONSE = _descriptor.Descriptor(
    name="ListAdapterResponse",
    full_name="io.openaristos.ListAdapterResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="adapters",
            full_name="io.openaristos.ListAdapterResponse.adapters",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListAdapterResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _LISTADAPTERRESPONSE_ADAPTERDETAILS,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11368,
    serialized_end=11802,
)


_ENABLEADAPTERREQUEST = _descriptor.Descriptor(
    name="EnableAdapterRequest",
    full_name="io.openaristos.EnableAdapterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EnableAdapterRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11804,
    serialized_end=11840,
)


_ENABLEADAPTERRESPONSE = _descriptor.Descriptor(
    name="EnableAdapterResponse",
    full_name="io.openaristos.EnableAdapterResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11842,
    serialized_end=11865,
)


_DISABLEADAPTERREQUEST = _descriptor.Descriptor(
    name="DisableAdapterRequest",
    full_name="io.openaristos.DisableAdapterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.DisableAdapterRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11867,
    serialized_end=11904,
)


_DISABLEADAPTERRESPONSE = _descriptor.Descriptor(
    name="DisableAdapterResponse",
    full_name="io.openaristos.DisableAdapterResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11906,
    serialized_end=11930,
)


_APPLYRESOURCEREQUEST = _descriptor.Descriptor(
    name="ApplyResourceRequest",
    full_name="io.openaristos.ApplyResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="io.openaristos.ApplyResourceRequest.resource",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11932,
    serialized_end=11998,
)


_APPLYRESOURCERESPONSE = _descriptor.Descriptor(
    name="ApplyResourceResponse",
    full_name="io.openaristos.ApplyResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12000,
    serialized_end=12023,
)


_RETRACTRESOURCEREQUEST = _descriptor.Descriptor(
    name="RetractResourceRequest",
    full_name="io.openaristos.RetractResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.RetractResourceRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12025,
    serialized_end=12063,
)


_RETRACTRESOURCERESPONSE = _descriptor.Descriptor(
    name="RetractResourceResponse",
    full_name="io.openaristos.RetractResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12065,
    serialized_end=12090,
)


_LISTRESOURCEREQUEST = _descriptor.Descriptor(
    name="ListResourceRequest",
    full_name="io.openaristos.ListResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListResourceRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListResourceRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12092,
    serialized_end=12191,
)


_LISTRESOURCERESPONSE = _descriptor.Descriptor(
    name="ListResourceResponse",
    full_name="io.openaristos.ListResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="io.openaristos.ListResourceResponse.resources",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListResourceResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12194,
    serialized_end=12324,
)


_ENABLERESOURCEREQUEST = _descriptor.Descriptor(
    name="EnableResourceRequest",
    full_name="io.openaristos.EnableResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.EnableResourceRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12326,
    serialized_end=12363,
)


_PREVIEWRESOURCEREQUEST = _descriptor.Descriptor(
    name="PreviewResourceRequest",
    full_name="io.openaristos.PreviewResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.PreviewResourceRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.PreviewResourceRequest.warehouse",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12365,
    serialized_end=12422,
)


_ENABLERESOURCERESPONSE = _descriptor.Descriptor(
    name="EnableResourceResponse",
    full_name="io.openaristos.EnableResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12424,
    serialized_end=12448,
)


_PREVIEWRESOURCERESPONSE = _descriptor.Descriptor(
    name="PreviewResourceResponse",
    full_name="io.openaristos.PreviewResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="rows",
            full_name="io.openaristos.PreviewResourceResponse.rows",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12450,
    serialized_end=12489,
)


_DISABLERESOURCEREQUEST = _descriptor.Descriptor(
    name="DisableResourceRequest",
    full_name="io.openaristos.DisableResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.DisableResourceRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12491,
    serialized_end=12529,
)


_DISABLERESOURCERESPONSE = _descriptor.Descriptor(
    name="DisableResourceResponse",
    full_name="io.openaristos.DisableResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12531,
    serialized_end=12556,
)


_ADAPTERPARAMETERS = _descriptor.Descriptor(
    name="AdapterParameters",
    full_name="io.openaristos.AdapterParameters",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AdapterParameters.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default",
            full_name="io.openaristos.AdapterParameters.default",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="io.openaristos.AdapterParameters.data_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12558,
    serialized_end=12657,
)


_ADAPTEREXECUTIONCONTEXTENTRY = _descriptor.Descriptor(
    name="AdapterExecutionContextEntry",
    full_name="io.openaristos.AdapterExecutionContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AdapterExecutionContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.AdapterExecutionContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="io.openaristos.AdapterExecutionContextEntry.data_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12659,
    serialized_end=12767,
)


_ADAPTEREXECUTIONPROFILE = _descriptor.Descriptor(
    name="AdapterExecutionProfile",
    full_name="io.openaristos.AdapterExecutionProfile",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine_kind",
            full_name="io.openaristos.AdapterExecutionProfile.engine_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="streaming",
            full_name="io.openaristos.AdapterExecutionProfile.streaming",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.AdapterExecutionProfile.context",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12770,
    serialized_end=12898,
)


_CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
    name="ParametersEntry",
    full_name="io.openaristos.CreateIngestionSessionRequest.ParametersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.CreateIngestionSessionRequest.ParametersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.CreateIngestionSessionRequest.ParametersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13102,
    serialized_end=13151,
)

_CREATEINGESTIONSESSIONREQUEST = _descriptor.Descriptor(
    name="CreateIngestionSessionRequest",
    full_name="io.openaristos.CreateIngestionSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="adapter",
            full_name="io.openaristos.CreateIngestionSessionRequest.adapter",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="landing_zone",
            full_name="io.openaristos.CreateIngestionSessionRequest.landing_zone",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mastering_engine",
            full_name="io.openaristos.CreateIngestionSessionRequest.mastering_engine",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouses",
            full_name="io.openaristos.CreateIngestionSessionRequest.warehouses",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="io.openaristos.CreateIngestionSessionRequest.parameters",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12901,
    serialized_end=13151,
)


_CREATEINGESTIONSESSIONRESPONSE = _descriptor.Descriptor(
    name="CreateIngestionSessionResponse",
    full_name="io.openaristos.CreateIngestionSessionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.CreateIngestionSessionResponse.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13153,
    serialized_end=13197,
)


_EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
    name="ParametersEntry",
    full_name="io.openaristos.ExecuteIngestionSessionRequest.ParametersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.ParametersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.ParametersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13102,
    serialized_end=13151,
)

_EXECUTEINGESTIONSESSIONREQUEST = _descriptor.Descriptor(
    name="ExecuteIngestionSessionRequest",
    full_name="io.openaristos.ExecuteIngestionSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.parameters",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.force",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="engine_kind",
            full_name="io.openaristos.ExecuteIngestionSessionRequest.engine_kind",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13200,
    serialized_end=13415,
)


_DELETEINGESTIONSESSIONREQUEST = _descriptor.Descriptor(
    name="DeleteIngestionSessionRequest",
    full_name="io.openaristos.DeleteIngestionSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.DeleteIngestionSessionRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13417,
    serialized_end=13460,
)


_DELETEINGESTIONSESSIONRESPONSE = _descriptor.Descriptor(
    name="DeleteIngestionSessionResponse",
    full_name="io.openaristos.DeleteIngestionSessionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.DeleteIngestionSessionResponse.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13462,
    serialized_end=13506,
)


_GETINGESTIONSESSIONREQUEST = _descriptor.Descriptor(
    name="GetIngestionSessionRequest",
    full_name="io.openaristos.GetIngestionSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.GetIngestionSessionRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13508,
    serialized_end=13548,
)


_INGESTIONSESSIONSTATUSRESPONSE = _descriptor.Descriptor(
    name="IngestionSessionStatusResponse",
    full_name="io.openaristos.IngestionSessionStatusResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.IngestionSessionStatusResponse.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.IngestionSessionStatusResponse.status",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="transaction_reference",
            full_name="io.openaristos.IngestionSessionStatusResponse.transaction_reference",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13551,
    serialized_end=13682,
)


_MASTERENTITY_DESCRIPTORSENTRY = _descriptor.Descriptor(
    name="DescriptorsEntry",
    full_name="io.openaristos.MasterEntity.DescriptorsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.MasterEntity.DescriptorsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.MasterEntity.DescriptorsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13782,
    serialized_end=13832,
)

_MASTERENTITY = _descriptor.Descriptor(
    name="MasterEntity",
    full_name="io.openaristos.MasterEntity",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uid",
            full_name="io.openaristos.MasterEntity.uid",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="descriptors",
            full_name="io.openaristos.MasterEntity.descriptors",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _MASTERENTITY_DESCRIPTORSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13685,
    serialized_end=13832,
)


_MASTERINGESTIONSESSIONREQUEST = _descriptor.Descriptor(
    name="MasterIngestionSessionRequest",
    full_name="io.openaristos.MasterIngestionSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.MasterIngestionSessionRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13834,
    serialized_end=13895,
)


_MASTERINGESTIONSESSIONRESPONSE = _descriptor.Descriptor(
    name="MasterIngestionSessionResponse",
    full_name="io.openaristos.MasterIngestionSessionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13897,
    serialized_end=13929,
)


_PUBLISHINGESTIONSESSIONRESOURCEREQUEST = _descriptor.Descriptor(
    name="PublishIngestionSessionResourceRequest",
    full_name="io.openaristos.PublishIngestionSessionResourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource_code",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.resource_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.warehouse_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="all_warehouses",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.all_warehouses",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="all_resources",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.all_resources",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="io.openaristos.PublishIngestionSessionResourceRequest.force",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13932,
    serialized_end=14111,
)


_PUBLISHINGESTIONSESSIONRESOURCERESPONSE = _descriptor.Descriptor(
    name="PublishIngestionSessionResourceResponse",
    full_name="io.openaristos.PublishIngestionSessionResourceResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="io.openaristos.PublishIngestionSessionResourceResponse.resources",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14113,
    serialized_end=14208,
)


_PUBLISHINGESTIONSESSIONRESOURCESTATUSREQUEST = _descriptor.Descriptor(
    name="PublishIngestionSessionResourceStatusRequest",
    full_name="io.openaristos.PublishIngestionSessionResourceStatusRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.PublishIngestionSessionResourceStatusRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource_code",
            full_name="io.openaristos.PublishIngestionSessionResourceStatusRequest.resource_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.PublishIngestionSessionResourceStatusRequest.warehouse_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14210,
    serialized_end=14333,
)


_PUBLISHINGESTIONSESSIONSTATUSRESPONSE = _descriptor.Descriptor(
    name="PublishIngestionSessionStatusResponse",
    full_name="io.openaristos.PublishIngestionSessionStatusResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.PublishIngestionSessionStatusResponse.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource_code",
            full_name="io.openaristos.PublishIngestionSessionStatusResponse.resource_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.PublishIngestionSessionStatusResponse.warehouse_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.PublishIngestionSessionStatusResponse.status",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14336,
    serialized_end=14507,
)


_RETRACTPUBLISHINGSESSIONREQUEST = _descriptor.Descriptor(
    name="RetractPublishingSessionRequest",
    full_name="io.openaristos.RetractPublishingSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.RetractPublishingSessionRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="io.openaristos.RetractPublishingSessionRequest.resources",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse_code",
            full_name="io.openaristos.RetractPublishingSessionRequest.warehouse_code",
            index=2,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="all",
            full_name="io.openaristos.RetractPublishingSessionRequest.all",
            index=3,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="io.openaristos.RetractPublishingSessionRequest.type",
            index=4,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _RETRACTPUBLISHINGSESSIONREQUEST_RETRACTIONTYPE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14510,
    serialized_end=14745,
)


_RETRACTPUBLISHINGSESSIONRESPONSE = _descriptor.Descriptor(
    name="RetractPublishingSessionResponse",
    full_name="io.openaristos.RetractPublishingSessionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14747,
    serialized_end=14781,
)


_RETRACTMASTERINGSESSIONREQUEST = _descriptor.Descriptor(
    name="RetractMasteringSessionRequest",
    full_name="io.openaristos.RetractMasteringSessionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.RetractMasteringSessionRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14783,
    serialized_end=14845,
)


_RETRACTMASTERINGSESSIONRESPONSE = _descriptor.Descriptor(
    name="RetractMasteringSessionResponse",
    full_name="io.openaristos.RetractMasteringSessionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14847,
    serialized_end=14880,
)


_HALTINCREMENTALMASTERINGREQUEST = _descriptor.Descriptor(
    name="HaltIncrementalMasteringRequest",
    full_name="io.openaristos.HaltIncrementalMasteringRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.HaltIncrementalMasteringRequest.engine",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14882,
    serialized_end=14931,
)


_HALTINCREMENTALMASTERINGRESPONSE = _descriptor.Descriptor(
    name="HaltIncrementalMasteringResponse",
    full_name="io.openaristos.HaltIncrementalMasteringResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14933,
    serialized_end=14967,
)


_RESUMEINCREMENTALMASTERINGREQUEST = _descriptor.Descriptor(
    name="ResumeIncrementalMasteringRequest",
    full_name="io.openaristos.ResumeIncrementalMasteringRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.ResumeIncrementalMasteringRequest.engine",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=14969,
    serialized_end=15020,
)


_RESUMEINCREMENTALMASTERINGRESPONSE = _descriptor.Descriptor(
    name="ResumeIncrementalMasteringResponse",
    full_name="io.openaristos.ResumeIncrementalMasteringResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15022,
    serialized_end=15058,
)


_RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.ResolveResourcePathRequest.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveResourcePathRequest.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveResourcePathRequest.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_RESOLVERESOURCEPATHREQUEST = _descriptor.Descriptor(
    name="ResolveResourcePathRequest",
    full_name="io.openaristos.ResolveResourcePathRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="path",
            full_name="io.openaristos.ResolveResourcePathRequest.path",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.ResolveResourcePathRequest.warehouse",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ResolveResourcePathRequest.context",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15061,
    serialized_end=15244,
)


_RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.ResolveResourcePathResponse.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ResolveResourcePathResponse.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveResourcePathResponse.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_RESOLVERESOURCEPATHRESPONSE = _descriptor.Descriptor(
    name="ResolveResourcePathResponse",
    full_name="io.openaristos.ResolveResourcePathResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="warehouse_kind",
            full_name="io.openaristos.ResolveResourcePathResponse.warehouse_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ResolveResourcePathResponse.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15247,
    serialized_end=15423,
)


_PSREQUEST = _descriptor.Descriptor(
    name="PSRequest",
    full_name="io.openaristos.PSRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15425,
    serialized_end=15436,
)


_PSRESPONSE_PUBLISHSESSION = _descriptor.Descriptor(
    name="PublishSession",
    full_name="io.openaristos.PSResponse.PublishSession",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_id",
            full_name="io.openaristos.PSResponse.PublishSession.ingestion_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.PSResponse.PublishSession.warehouse",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="io.openaristos.PSResponse.PublishSession.resource",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.PSResponse.PublishSession.status",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15584,
    serialized_end=15675,
)

_PSRESPONSE = _descriptor.Descriptor(
    name="PSResponse",
    full_name="io.openaristos.PSResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_sessions",
            full_name="io.openaristos.PSResponse.ingestion_sessions",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="publish_sessions",
            full_name="io.openaristos.PSResponse.publish_sessions",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _PSRESPONSE_PUBLISHSESSION,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15439,
    serialized_end=15675,
)


_LISTINGESTIONSESSIONARTIFACTSREQUEST = _descriptor.Descriptor(
    name="ListIngestionSessionArtifactsRequest",
    full_name="io.openaristos.ListIngestionSessionArtifactsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.ListIngestionSessionArtifactsRequest.ingestion_session_id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15677,
    serialized_end=15745,
)


_LISTINGESTIONSESSIONARTIFACTSRESPONSE = _descriptor.Descriptor(
    name="ListIngestionSessionArtifactsResponse",
    full_name="io.openaristos.ListIngestionSessionArtifactsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="assets_location",
            full_name="io.openaristos.ListIngestionSessionArtifactsResponse.assets_location",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="relationships_location",
            full_name="io.openaristos.ListIngestionSessionArtifactsResponse.relationships_location",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities_location",
            full_name="io.openaristos.ListIngestionSessionArtifactsResponse.entities_location",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="errors_location",
            full_name="io.openaristos.ListIngestionSessionArtifactsResponse.errors_location",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15748,
    serialized_end=15896,
)


_LISTINGESTIONSESSIONSREQUEST = _descriptor.Descriptor(
    name="ListIngestionSessionsRequest",
    full_name="io.openaristos.ListIngestionSessionsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="since",
            full_name="io.openaristos.ListIngestionSessionsRequest.since",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="until",
            full_name="io.openaristos.ListIngestionSessionsRequest.until",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="adapter",
            full_name="io.openaristos.ListIngestionSessionsRequest.adapter",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="destination",
            full_name="io.openaristos.ListIngestionSessionsRequest.destination",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListIngestionSessionsRequest.pagination_options",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=15899,
    serialized_end=16116,
)


_INGESTIONSESSION_PARAMETERSENTRY = _descriptor.Descriptor(
    name="ParametersEntry",
    full_name="io.openaristos.IngestionSession.ParametersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.IngestionSession.ParametersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.IngestionSession.ParametersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=13102,
    serialized_end=13151,
)

_INGESTIONSESSION = _descriptor.Descriptor(
    name="IngestionSession",
    full_name="io.openaristos.IngestionSession",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="io.openaristos.IngestionSession.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.IngestionSession.status",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouses",
            full_name="io.openaristos.IngestionSession.warehouses",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="adapter",
            full_name="io.openaristos.IngestionSession.adapter",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="landing_zone",
            full_name="io.openaristos.IngestionSession.landing_zone",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mastering_engine",
            full_name="io.openaristos.IngestionSession.mastering_engine",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="io.openaristos.IngestionSession.parameters",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="publishing_details",
            full_name="io.openaristos.IngestionSession.publishing_details",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="created_at",
            full_name="io.openaristos.IngestionSession.created_at",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _INGESTIONSESSION_PARAMETERSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16119,
    serialized_end=16522,
)


_LISTINGESTIONSESSIONSRESPONSE = _descriptor.Descriptor(
    name="ListIngestionSessionsResponse",
    full_name="io.openaristos.ListIngestionSessionsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ingestion_sessions",
            full_name="io.openaristos.ListIngestionSessionsResponse.ingestion_sessions",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListIngestionSessionsResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16525,
    serialized_end=16681,
)


_PUBLISHINGDETAILS = _descriptor.Descriptor(
    name="PublishingDetails",
    full_name="io.openaristos.PublishingDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="io.openaristos.PublishingDetails.resource",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="warehouse",
            full_name="io.openaristos.PublishingDetails.warehouse",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.PublishingDetails.status",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16683,
    serialized_end=16794,
)


_APPLYPERSPECTIVEREQUEST = _descriptor.Descriptor(
    name="ApplyPerspectiveRequest",
    full_name="io.openaristos.ApplyPerspectiveRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="perspective",
            full_name="io.openaristos.ApplyPerspectiveRequest.perspective",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16796,
    serialized_end=16871,
)


_APPLYPERSPECTIVERESPONSE = _descriptor.Descriptor(
    name="ApplyPerspectiveResponse",
    full_name="io.openaristos.ApplyPerspectiveResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16873,
    serialized_end=16899,
)


_RETRACTPERSPECTIVEREQUEST = _descriptor.Descriptor(
    name="RetractPerspectiveRequest",
    full_name="io.openaristos.RetractPerspectiveRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.RetractPerspectiveRequest.engine",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="perspective_code",
            full_name="io.openaristos.RetractPerspectiveRequest.perspective_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16901,
    serialized_end=16970,
)


_RETRACTPERSPECTIVERESPONSE = _descriptor.Descriptor(
    name="RetractPerspectiveResponse",
    full_name="io.openaristos.RetractPerspectiveResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=16972,
    serialized_end=17000,
)


_LISTPERSPECTIVEREQUEST = _descriptor.Descriptor(
    name="ListPerspectiveRequest",
    full_name="io.openaristos.ListPerspectiveRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListPerspectiveRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListPerspectiveRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17002,
    serialized_end=17104,
)


_LISTPERSPECTIVERESPONSE = _descriptor.Descriptor(
    name="ListPerspectiveResponse",
    full_name="io.openaristos.ListPerspectiveResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="perspectives",
            full_name="io.openaristos.ListPerspectiveResponse.perspectives",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListPerspectiveResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17107,
    serialized_end=17246,
)


_EVENTMETADATA = _descriptor.Descriptor(
    name="EventMetadata",
    full_name="io.openaristos.EventMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uuid",
            full_name="io.openaristos.EventMetadata.uuid",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="occurred_at",
            full_name="io.openaristos.EventMetadata.occurred_at",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="event_type",
            full_name="io.openaristos.EventMetadata.event_type",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17248,
    serialized_end=17346,
)


_PUBLISHRESOURCEFAILEDEVENT = _descriptor.Descriptor(
    name="PublishResourceFailedEvent",
    full_name="io.openaristos.PublishResourceFailedEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.PublishResourceFailedEvent.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="io.openaristos.PublishResourceFailedEvent.resource",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="destination",
            full_name="io.openaristos.PublishResourceFailedEvent.destination",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.PublishResourceFailedEvent.ingestion_session_id",
            index=3,
            number=4,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17349,
    serialized_end=17495,
)


_PUBLISHRESOURCECOMPLETEEVENT = _descriptor.Descriptor(
    name="PublishResourceCompleteEvent",
    full_name="io.openaristos.PublishResourceCompleteEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.PublishResourceCompleteEvent.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="io.openaristos.PublishResourceCompleteEvent.resource",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="destination",
            full_name="io.openaristos.PublishResourceCompleteEvent.destination",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.PublishResourceCompleteEvent.ingestion_session_id",
            index=3,
            number=4,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17498,
    serialized_end=17646,
)


_EXECUTEINGESTIONSESSIONCOMPLETEEVENT = _descriptor.Descriptor(
    name="ExecuteIngestionSessionCompleteEvent",
    full_name="io.openaristos.ExecuteIngestionSessionCompleteEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.ExecuteIngestionSessionCompleteEvent.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="request",
            full_name="io.openaristos.ExecuteIngestionSessionCompleteEvent.request",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17649,
    serialized_end=17801,
)


_EXECUTEINGESTIONSESSIONFAILEDEVENT = _descriptor.Descriptor(
    name="ExecuteIngestionSessionFailedEvent",
    full_name="io.openaristos.ExecuteIngestionSessionFailedEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.ExecuteIngestionSessionFailedEvent.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="request",
            full_name="io.openaristos.ExecuteIngestionSessionFailedEvent.request",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17804,
    serialized_end=17954,
)


_INGESTIONSESSIONCREATEDEVENT = _descriptor.Descriptor(
    name="IngestionSessionCreatedEvent",
    full_name="io.openaristos.IngestionSessionCreatedEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.IngestionSessionCreatedEvent.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ingestion_session_id",
            full_name="io.openaristos.IngestionSessionCreatedEvent.ingestion_session_id",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="request",
            full_name="io.openaristos.IngestionSessionCreatedEvent.request",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=17957,
    serialized_end=18130,
)


_RESOLVEUNIVERSEREQUEST = _descriptor.Descriptor(
    name="ResolveUniverseRequest",
    full_name="io.openaristos.ResolveUniverseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="universe",
            full_name="io.openaristos.ResolveUniverseRequest.universe",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effective_dating",
            full_name="io.openaristos.ResolveUniverseRequest.effective_dating",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18132,
    serialized_end=18258,
)


_RESOLVEUNIVERSEGROUPENTRY = _descriptor.Descriptor(
    name="ResolveUniverseGroupEntry",
    full_name="io.openaristos.ResolveUniverseGroupEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="io.openaristos.ResolveUniverseGroupEntry.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18260,
    serialized_end=18342,
)


_RESOLVEUNIVERSEENTRY = _descriptor.Descriptor(
    name="ResolveUniverseEntry",
    full_name="io.openaristos.ResolveUniverseEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="attribute",
            full_name="io.openaristos.ResolveUniverseEntry.attribute",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ResolveUniverseEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="io.openaristos.ResolveUniverseEntry.data_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18344,
    serialized_end=18450,
)


_ERRORENTRY_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.ErrorEntry.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ErrorEntry.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ErrorEntry.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_ERRORENTRY = _descriptor.Descriptor(
    name="ErrorEntry",
    full_name="io.openaristos.ErrorEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message",
            full_name="io.openaristos.ErrorEntry.message",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="occurred_at",
            full_name="io.openaristos.ErrorEntry.occurred_at",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stacktrace",
            full_name="io.openaristos.ErrorEntry.stacktrace",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.ErrorEntry.context",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _ERRORENTRY_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18453,
    serialized_end=18657,
)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
    name="HealthCheckRequest",
    full_name="io.openaristos.HealthCheckRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18659,
    serialized_end=18679,
)


_HEALTHCHECKRESPONSE_SERVICESTATUS = _descriptor.Descriptor(
    name="ServiceStatus",
    full_name="io.openaristos.HealthCheckResponse.ServiceStatus",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.HealthCheckResponse.ServiceStatus.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="io.openaristos.HealthCheckResponse.ServiceStatus.status",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18768,
    serialized_end=18857,
)

_HEALTHCHECKRESPONSE_SERVICE = _descriptor.Descriptor(
    name="Service",
    full_name="io.openaristos.HealthCheckResponse.Service",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="service",
            full_name="io.openaristos.HealthCheckResponse.Service.service",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="statuses",
            full_name="io.openaristos.HealthCheckResponse.Service.statuses",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18859,
    serialized_end=18954,
)

_HEALTHCHECKRESPONSE = _descriptor.Descriptor(
    name="HealthCheckResponse",
    full_name="io.openaristos.HealthCheckResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="services",
            full_name="io.openaristos.HealthCheckResponse.services",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _HEALTHCHECKRESPONSE_SERVICESTATUS,
        _HEALTHCHECKRESPONSE_SERVICE,
    ],
    enum_types=[
        _HEALTHCHECKRESPONSE_STATUS,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18682,
    serialized_end=18995,
)


_ENTITYCOVERAGEREQUEST = _descriptor.Descriptor(
    name="EntityCoverageRequest",
    full_name="io.openaristos.EntityCoverageRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="universe",
            full_name="io.openaristos.EntityCoverageRequest.universe",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="perspectives",
            full_name="io.openaristos.EntityCoverageRequest.perspectives",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="alias",
            full_name="io.openaristos.EntityCoverageRequest.alias",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effective_dating",
            full_name="io.openaristos.EntityCoverageRequest.effective_dating",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18998,
    serialized_end=19160,
)


_ENTITYCOVERAGERESPONSE = _descriptor.Descriptor(
    name="EntityCoverageResponse",
    full_name="io.openaristos.EntityCoverageResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="io.openaristos.EntityCoverageResponse.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19162,
    serialized_end=19248,
)


_ENTITYCOVERAGERESPONSEENTRY = _descriptor.Descriptor(
    name="EntityCoverageResponseEntry",
    full_name="io.openaristos.EntityCoverageResponseEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="perspective",
            full_name="io.openaristos.EntityCoverageResponseEntry.perspective",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="coverage",
            full_name="io.openaristos.EntityCoverageResponseEntry.coverage",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19250,
    serialized_end=19318,
)


_APPINPUT_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.AppInput.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AppInput.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.AppInput.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_APPINPUT = _descriptor.Descriptor(
    name="AppInput",
    full_name="io.openaristos.AppInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AppInput.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="io.openaristos.AppInput.data_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="required",
            full_name="io.openaristos.AppInput.required",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_value",
            full_name="io.openaristos.AppInput.default_value",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="repeated",
            full_name="io.openaristos.AppInput.repeated",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.AppInput.context",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _APPINPUT_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19321,
    serialized_end=19526,
)


_APPOUTPUT_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.AppOutput.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AppOutput.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.AppOutput.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_APPOUTPUT = _descriptor.Descriptor(
    name="AppOutput",
    full_name="io.openaristos.AppOutput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="io.openaristos.AppOutput.kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.AppOutput.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _APPOUTPUT_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19529,
    serialized_end=19659,
)


_APPEXECUTIONPROFILE_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.AppExecutionProfile.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.AppExecutionProfile.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.AppExecutionProfile.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_APPEXECUTIONPROFILE = _descriptor.Descriptor(
    name="AppExecutionProfile",
    full_name="io.openaristos.AppExecutionProfile",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="engine_kind",
            full_name="io.openaristos.AppExecutionProfile.engine_kind",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.AppExecutionProfile.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _APPEXECUTIONPROFILE_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19662,
    serialized_end=19819,
)


_DEPENDENCY_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.Dependency.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.Dependency.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.Dependency.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_DEPENDENCY = _descriptor.Descriptor(
    name="Dependency",
    full_name="io.openaristos.Dependency",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.Dependency.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="io.openaristos.Dependency.kind",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.Dependency.context",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _DEPENDENCY_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=19822,
    serialized_end=20000,
)


_APP = _descriptor.Descriptor(
    name="App",
    full_name="io.openaristos.App",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="io.openaristos.App.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.App.code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="author",
            full_name="io.openaristos.App.author",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="io.openaristos.App.description",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="inputs",
            full_name="io.openaristos.App.inputs",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="outputs",
            full_name="io.openaristos.App.outputs",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="execution_profiles",
            full_name="io.openaristos.App.execution_profiles",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dependencies",
            full_name="io.openaristos.App.dependencies",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20003,
    serialized_end=20246,
)


_APPLYAPPREQUEST = _descriptor.Descriptor(
    name="ApplyAppRequest",
    full_name="io.openaristos.ApplyAppRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="app",
            full_name="io.openaristos.ApplyAppRequest.app",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20248,
    serialized_end=20299,
)


_APPLYAPPRESPONSE = _descriptor.Descriptor(
    name="ApplyAppResponse",
    full_name="io.openaristos.ApplyAppResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20301,
    serialized_end=20319,
)


_EXECUTEAPPREQUEST = _descriptor.Descriptor(
    name="ExecuteAppRequest",
    full_name="io.openaristos.ExecuteAppRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="io.openaristos.ExecuteAppRequest.code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="engine",
            full_name="io.openaristos.ExecuteAppRequest.engine",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="inputs",
            full_name="io.openaristos.ExecuteAppRequest.inputs",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20321,
    serialized_end=20426,
)


_EXECUTEAPPREQUESTINPUT = _descriptor.Descriptor(
    name="ExecuteAppRequestInput",
    full_name="io.openaristos.ExecuteAppRequestInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.ExecuteAppRequestInput.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.ExecuteAppRequestInput.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20428,
    serialized_end=20480,
)


_EXECUTEAPPRESPONSE = _descriptor.Descriptor(
    name="ExecuteAppResponse",
    full_name="io.openaristos.ExecuteAppResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20482,
    serialized_end=20502,
)


_APPLYDEPENDENCYREQUEST = _descriptor.Descriptor(
    name="ApplyDependencyRequest",
    full_name="io.openaristos.ApplyDependencyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="dependency",
            full_name="io.openaristos.ApplyDependencyRequest.dependency",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20504,
    serialized_end=20576,
)


_APPLYDEPENDENCYRESPONSE = _descriptor.Descriptor(
    name="ApplyDependencyResponse",
    full_name="io.openaristos.ApplyDependencyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20578,
    serialized_end=20603,
)


_LISTAPPREQUEST = _descriptor.Descriptor(
    name="ListAppRequest",
    full_name="io.openaristos.ListAppRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="io.openaristos.ListAppRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_options",
            full_name="io.openaristos.ListAppRequest.pagination_options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20605,
    serialized_end=20699,
)


_LISTAPPRESPONSE = _descriptor.Descriptor(
    name="ListAppResponse",
    full_name="io.openaristos.ListAppResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="apps",
            full_name="io.openaristos.ListAppResponse.apps",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pagination_details",
            full_name="io.openaristos.ListAppResponse.pagination_details",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20701,
    serialized_end=20816,
)


_EMITEVENTREQUEST_CONTEXTENTRY = _descriptor.Descriptor(
    name="ContextEntry",
    full_name="io.openaristos.EmitEventRequest.ContextEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="io.openaristos.EmitEventRequest.ContextEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="io.openaristos.EmitEventRequest.ContextEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2232,
    serialized_end=2278,
)

_EMITEVENTREQUEST = _descriptor.Descriptor(
    name="EmitEventRequest",
    full_name="io.openaristos.EmitEventRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="io.openaristos.EmitEventRequest.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="io.openaristos.EmitEventRequest.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _EMITEVENTREQUEST_CONTEXTENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20819,
    serialized_end=20998,
)


_EMITEVENTRESPONSE = _descriptor.Descriptor(
    name="EmitEventResponse",
    full_name="io.openaristos.EmitEventResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uuid",
            full_name="io.openaristos.EmitEventResponse.uuid",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=21000,
    serialized_end=21033,
)

_TIMESTAMPRANGE.fields_by_name[
    "start_dt"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPRANGE.fields_by_name[
    "end_dt"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERSPECTIVE.fields_by_name[
    "permanent_attributes"
].message_type = _PERSPECTIVEPERMANENTATTRIBUTE
_MIGRATERESOURCEREQUEST_FORCE.containing_type = _MIGRATERESOURCEREQUEST
_MIGRATERESOURCEREQUEST.fields_by_name[
    "direction"
].enum_type = _MIGRATERESOURCEREQUEST_DIRECTION
_MIGRATERESOURCEREQUEST.fields_by_name[
    "force"
].message_type = _MIGRATERESOURCEREQUEST_FORCE
_MIGRATERESOURCEREQUEST_DIRECTION.containing_type = _MIGRATERESOURCEREQUEST
_MIGRATEALLRESOURCESREQUEST_FORCE.containing_type = _MIGRATEALLRESOURCESREQUEST
_MIGRATEALLRESOURCESREQUEST.fields_by_name[
    "direction"
].enum_type = _MIGRATEALLRESOURCESREQUEST_DIRECTION
_MIGRATEALLRESOURCESREQUEST.fields_by_name[
    "force"
].message_type = _MIGRATEALLRESOURCESREQUEST_FORCE
_MIGRATEALLRESOURCESREQUEST_DIRECTION.containing_type = (
    _MIGRATEALLRESOURCESREQUEST
)
_MIGRATEALLRESOURCESRESPONSE.fields_by_name[
    "migrations"
].message_type = _MIGRATIONDETAILS
_MIGRATERESOURCERESPONSE.fields_by_name[
    "migration"
].message_type = _MIGRATIONDETAILS
_RESOLVERESOURCEREQUEST_POINTERSENTRY.containing_type = _RESOLVERESOURCEREQUEST
_RESOLVERESOURCEREQUEST.fields_by_name["universe"].message_type = _UNIVERSE
_RESOLVERESOURCEREQUEST.fields_by_name[
    "effective_dating"
].message_type = _TIMESTAMPRANGE
_RESOLVERESOURCEREQUEST.fields_by_name[
    "pointers"
].message_type = _RESOLVERESOURCEREQUEST_POINTERSENTRY
_RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY.containing_type = (
    _RESOLVEQUERYRESOURCEREQUEST
)
_RESOLVEQUERYRESOURCEREQUEST.fields_by_name[
    "pointers"
].message_type = _RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY
_RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY.containing_type = (
    _RESOLVEQUERYRESOURCERESPONSE
)
_RESOLVEQUERYRESOURCERESPONSE.fields_by_name[
    "mapping"
].message_type = _RESOLVERESOURCEINTENTMAPPING
_RESOLVEQUERYRESOURCERESPONSE.fields_by_name[
    "columns"
].message_type = _COLUMNENTRY
_RESOLVEQUERYRESOURCERESPONSE.fields_by_name[
    "context"
].message_type = _RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY
_RESOLVERESOURCEMAPPINGCONTEXTENTRY.fields_by_name[
    "attribute_type"
].enum_type = _ATTRIBUTETYPE
_RESOLVERESOURCEMAPPINGCONTEXTENTRY.fields_by_name[
    "comparison_type"
].enum_type = _COMPARISONTYPE
_RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY.containing_type = (
    _RESOLVERESOURCEINTENTRESPONSE
)
_RESOLVERESOURCEINTENTRESPONSE.fields_by_name[
    "mapping"
].message_type = _RESOLVERESOURCEINTENTMAPPING
_RESOLVERESOURCEINTENTRESPONSE.fields_by_name[
    "columns"
].message_type = _COLUMNENTRY
_RESOLVERESOURCEINTENTRESPONSE.fields_by_name[
    "context"
].message_type = _RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY
_RESOLVERESOURCEINTENTRESPONSE.fields_by_name[
    "effective_dating"
].message_type = _TIMESTAMPRANGE
_RESOLVERESOURCEINTENTMAPPING.fields_by_name[
    "columns"
].message_type = _COLUMNENTRY
_RESOLVERESOURCEINTENTMAPPING.fields_by_name[
    "clauses"
].message_type = _RESOLVERESOURCEINTENTMAPPINGCLAUSE
_RESOLVERESOURCEINTENTMAPPINGCLAUSE.fields_by_name[
    "comparison"
].enum_type = _COMPARISONTYPE
_APPLYLANDINGZONEREQUEST.fields_by_name[
    "configurations"
].message_type = _CONFIGURATIONENTRY
_LISTLANDINGZONEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS.fields_by_name[
    "configurations"
].message_type = _CONFIGURATIONENTRY
_LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS.containing_type = (
    _LISTLANDINGZONERESPONSE
)
_LISTLANDINGZONERESPONSE.fields_by_name[
    "landing_zones"
].message_type = _LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS
_LISTLANDINGZONERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_SCHEMAATTRIBUTE.fields_by_name["data_type"].enum_type = _ATTRIBUTETYPE
_SCHEMAATTRIBUTE.fields_by_name[
    "mapping_type"
].enum_type = _SCHEMAATTRIBUTE_MAPPINGTYPE
_SCHEMAATTRIBUTE_MAPPINGTYPE.containing_type = _SCHEMAATTRIBUTE
_SCHEMA.fields_by_name["attributes"].message_type = _SCHEMAATTRIBUTE
_MAPPINGCONTEXT.fields_by_name[
    "concatenation_rules"
].message_type = _MAPPINGCONCATENATIONRULE
_ENTITYTYPE.fields_by_name["schema"].message_type = _SCHEMA
_ENTITYTYPE.fields_by_name["mapping"].message_type = _MAPPINGCONTEXT
_APPLYONTOLOGYREQUEST.fields_by_name["entities"].message_type = _ENTITYTYPE
_APPLYONTOLOGYREQUEST.fields_by_name[
    "relationships"
].message_type = _RELATIONSHIPTYPE
_LISTONTOLOGYREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_ONTOLOGY.fields_by_name["entities"].message_type = _ENTITYTYPE
_ONTOLOGY.fields_by_name["relationships"].message_type = _RELATIONSHIPTYPE
_LISTONTOLOGYRESPONSE.fields_by_name["ontologies"].message_type = _ONTOLOGY
_LISTONTOLOGYRESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_EXECUTIONENGINE.fields_by_name[
    "configurations"
].message_type = _CONFIGURATIONENTRY
_APPLYEXECUTIONENGINEREQUEST.fields_by_name[
    "engine"
].message_type = _EXECUTIONENGINE
_LISTEXECUTIONENGINEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTEXECUTIONENGINERESPONSE.fields_by_name[
    "engines"
].message_type = _EXECUTIONENGINE
_LISTEXECUTIONENGINERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_WAREHOUSE.fields_by_name["configurations"].message_type = _CONFIGURATIONENTRY
_APPLYWAREHOUSEREQUEST.fields_by_name["warehouse"].message_type = _WAREHOUSE
_VALIDATOR.fields_by_name[
    "validator_kind"
].enum_type = _VALIDATOR_VALIDATORKIND
_VALIDATOR.fields_by_name["schema_kind"].enum_type = _VALIDATOR_SCHEMAKIND
_VALIDATOR_VALIDATORKIND.containing_type = _VALIDATOR
_VALIDATOR_SCHEMAKIND.containing_type = _VALIDATOR
_APPLYVALIDATORREQUEST.fields_by_name["validator"].message_type = _VALIDATOR
_LISTVALIDATORREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTVALIDATORRESPONSE.fields_by_name["validators"].message_type = _VALIDATOR
_LISTVALIDATORRESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_LISTWAREHOUSEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTWAREHOUSERESPONSE.fields_by_name["warehouses"].message_type = _WAREHOUSE
_LISTWAREHOUSERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_APPLYMASTERINGENGINEREQUEST.fields_by_name[
    "engine"
].message_type = _MASTERINGENGINE
_LISTMASTERINGENGINEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTMASTERINGENGINERESPONSE.fields_by_name[
    "mastering_engines"
].message_type = _MASTERINGENGINE
_LISTMASTERINGENGINERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_MASTERINGENGINE.fields_by_name[
    "configurations"
].message_type = _CONFIGURATIONENTRY
_RESOURCESTORE.fields_by_name[
    "context"
].message_type = _RESOURCESTORECONTEXTENTRY
_RESOURCECONTEXT.fields_by_name[
    "pointers"
].message_type = _RESOURCECONTEXTPOINTERENTRY
_RESOURCECONTEXT.fields_by_name["dating"].message_type = _RESOURCEDATING
_RESOURCECONTEXT.fields_by_name["hashing"].message_type = _RESOURCEHASHING
_RESOURCECONTEXT.fields_by_name[
    "metadata"
].message_type = _RESOURCEMETADATAENTRY
_RESOURCECONTEXT.fields_by_name[
    "publishing"
].message_type = _ADAPTERPERSISTENCEENTRY
_RESOURCECONTEXT.fields_by_name[
    "retraction"
].message_type = _RESOURCERETRACTION
_RESOURCE.fields_by_name["schema"].message_type = _SCHEMA
_RESOURCE.fields_by_name["pointers"].message_type = _RESOURCEPOINTERENTRY
_RESOURCE.fields_by_name["stores"].message_type = _RESOURCESTORE
_RESOURCE.fields_by_name["context"].message_type = _RESOURCECONTEXT
_RESOURCE.fields_by_name["migrations"].message_type = _MIGRATION
_ADAPTERPERSISTENCE.fields_by_name[
    "entries"
].message_type = _ADAPTERPERSISTENCEENTRY
_ADAPTERPERSISTENCEENTRY.fields_by_name[
    "steps"
].message_type = _ADAPTERPERSISTENCESTEP
_ADAPTERMETADATA.fields_by_name[
    "persistence"
].message_type = _ADAPTERPERSISTENCE
_ADAPTERMETADATA.fields_by_name[
    "retraction"
].message_type = _RESOURCERETRACTION
_APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY.containing_type = (
    _APPLYADAPTERREQUEST
)
_APPLYADAPTERREQUEST.fields_by_name[
    "execution_profiles"
].message_type = _ADAPTEREXECUTIONPROFILE
_APPLYADAPTERREQUEST.fields_by_name[
    "parameters"
].message_type = _ADAPTERPARAMETERS
_APPLYADAPTERREQUEST.fields_by_name["resources"].message_type = _RESOURCE
_APPLYADAPTERREQUEST.fields_by_name["metadata"].message_type = _ADAPTERMETADATA
_APPLYADAPTERREQUEST.fields_by_name[
    "customer_metadata"
].message_type = _APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY
_LISTADAPTERREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTADAPTERRESPONSE_ADAPTERDETAILS.fields_by_name[
    "execution_profiles"
].message_type = _ADAPTEREXECUTIONPROFILE
_LISTADAPTERRESPONSE_ADAPTERDETAILS.fields_by_name[
    "parameters"
].message_type = _ADAPTERPARAMETERS
_LISTADAPTERRESPONSE_ADAPTERDETAILS.fields_by_name[
    "resources"
].message_type = _RESOURCE
_LISTADAPTERRESPONSE_ADAPTERDETAILS.containing_type = _LISTADAPTERRESPONSE
_LISTADAPTERRESPONSE.fields_by_name[
    "adapters"
].message_type = _LISTADAPTERRESPONSE_ADAPTERDETAILS
_LISTADAPTERRESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_APPLYRESOURCEREQUEST.fields_by_name["resource"].message_type = _RESOURCE
_LISTRESOURCEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTRESOURCERESPONSE.fields_by_name["resources"].message_type = _RESOURCE
_LISTRESOURCERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_ADAPTERPARAMETERS.fields_by_name["data_type"].enum_type = _ATTRIBUTETYPE
_ADAPTEREXECUTIONCONTEXTENTRY.fields_by_name[
    "data_type"
].enum_type = _ATTRIBUTETYPE
_ADAPTEREXECUTIONPROFILE.fields_by_name[
    "context"
].message_type = _ADAPTEREXECUTIONCONTEXTENTRY
_CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY.containing_type = (
    _CREATEINGESTIONSESSIONREQUEST
)
_CREATEINGESTIONSESSIONREQUEST.fields_by_name[
    "parameters"
].message_type = _CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY
_EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY.containing_type = (
    _EXECUTEINGESTIONSESSIONREQUEST
)
_EXECUTEINGESTIONSESSIONREQUEST.fields_by_name[
    "parameters"
].message_type = _EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY
_INGESTIONSESSIONSTATUSRESPONSE.fields_by_name[
    "status"
].enum_type = _INGESTIONSESSIONSTATUS
_MASTERENTITY_DESCRIPTORSENTRY.containing_type = _MASTERENTITY
_MASTERENTITY.fields_by_name[
    "descriptors"
].message_type = _MASTERENTITY_DESCRIPTORSENTRY
_PUBLISHINGESTIONSESSIONRESOURCERESPONSE.fields_by_name[
    "resources"
].message_type = _PUBLISHINGDETAILS
_PUBLISHINGESTIONSESSIONSTATUSRESPONSE.fields_by_name[
    "status"
].enum_type = _RESOURCEPUBLISHSTATUS
_RETRACTPUBLISHINGSESSIONREQUEST.fields_by_name[
    "type"
].enum_type = _RETRACTPUBLISHINGSESSIONREQUEST_RETRACTIONTYPE
_RETRACTPUBLISHINGSESSIONREQUEST_RETRACTIONTYPE.containing_type = (
    _RETRACTPUBLISHINGSESSIONREQUEST
)
_RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY.containing_type = (
    _RESOLVERESOURCEPATHREQUEST
)
_RESOLVERESOURCEPATHREQUEST.fields_by_name[
    "context"
].message_type = _RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY
_RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY.containing_type = (
    _RESOLVERESOURCEPATHRESPONSE
)
_RESOLVERESOURCEPATHRESPONSE.fields_by_name[
    "context"
].message_type = _RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY
_PSRESPONSE_PUBLISHSESSION.containing_type = _PSRESPONSE
_PSRESPONSE.fields_by_name[
    "ingestion_sessions"
].message_type = _INGESTIONSESSION
_PSRESPONSE.fields_by_name[
    "publish_sessions"
].message_type = _PSRESPONSE_PUBLISHSESSION
_LISTINGESTIONSESSIONSREQUEST.fields_by_name[
    "since"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTINGESTIONSESSIONSREQUEST.fields_by_name[
    "until"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTINGESTIONSESSIONSREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_INGESTIONSESSION_PARAMETERSENTRY.containing_type = _INGESTIONSESSION
_INGESTIONSESSION.fields_by_name["status"].enum_type = _INGESTIONSESSIONSTATUS
_INGESTIONSESSION.fields_by_name[
    "parameters"
].message_type = _INGESTIONSESSION_PARAMETERSENTRY
_INGESTIONSESSION.fields_by_name[
    "publishing_details"
].message_type = _PUBLISHINGDETAILS
_INGESTIONSESSION.fields_by_name[
    "created_at"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTINGESTIONSESSIONSRESPONSE.fields_by_name[
    "ingestion_sessions"
].message_type = _INGESTIONSESSION
_LISTINGESTIONSESSIONSRESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_PUBLISHINGDETAILS.fields_by_name["status"].enum_type = _RESOURCEPUBLISHSTATUS
_APPLYPERSPECTIVEREQUEST.fields_by_name[
    "perspective"
].message_type = _PERSPECTIVE
_LISTPERSPECTIVEREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTPERSPECTIVERESPONSE.fields_by_name[
    "perspectives"
].message_type = _PERSPECTIVE
_LISTPERSPECTIVERESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_EVENTMETADATA.fields_by_name[
    "occurred_at"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PUBLISHRESOURCEFAILEDEVENT.fields_by_name[
    "metadata"
].message_type = _EVENTMETADATA
_PUBLISHRESOURCECOMPLETEEVENT.fields_by_name[
    "metadata"
].message_type = _EVENTMETADATA
_EXECUTEINGESTIONSESSIONCOMPLETEEVENT.fields_by_name[
    "metadata"
].message_type = _EVENTMETADATA
_EXECUTEINGESTIONSESSIONCOMPLETEEVENT.fields_by_name[
    "request"
].message_type = _EXECUTEINGESTIONSESSIONREQUEST
_EXECUTEINGESTIONSESSIONFAILEDEVENT.fields_by_name[
    "metadata"
].message_type = _EVENTMETADATA
_EXECUTEINGESTIONSESSIONFAILEDEVENT.fields_by_name[
    "request"
].message_type = _EXECUTEINGESTIONSESSIONREQUEST
_INGESTIONSESSIONCREATEDEVENT.fields_by_name[
    "metadata"
].message_type = _EVENTMETADATA
_INGESTIONSESSIONCREATEDEVENT.fields_by_name[
    "request"
].message_type = _CREATEINGESTIONSESSIONREQUEST
_RESOLVEUNIVERSEREQUEST.fields_by_name["universe"].message_type = _UNIVERSE
_RESOLVEUNIVERSEREQUEST.fields_by_name[
    "effective_dating"
].message_type = _TIMESTAMPRANGE
_RESOLVEUNIVERSEGROUPENTRY.fields_by_name[
    "entries"
].message_type = _RESOLVEUNIVERSEENTRY
_RESOLVEUNIVERSEENTRY.fields_by_name["data_type"].enum_type = _ATTRIBUTETYPE
_ERRORENTRY_CONTEXTENTRY.containing_type = _ERRORENTRY
_ERRORENTRY.fields_by_name[
    "occurred_at"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ERRORENTRY.fields_by_name["context"].message_type = _ERRORENTRY_CONTEXTENTRY
_HEALTHCHECKRESPONSE_SERVICESTATUS.fields_by_name[
    "status"
].enum_type = _HEALTHCHECKRESPONSE_STATUS
_HEALTHCHECKRESPONSE_SERVICESTATUS.containing_type = _HEALTHCHECKRESPONSE
_HEALTHCHECKRESPONSE_SERVICE.fields_by_name[
    "statuses"
].message_type = _HEALTHCHECKRESPONSE_SERVICESTATUS
_HEALTHCHECKRESPONSE_SERVICE.containing_type = _HEALTHCHECKRESPONSE
_HEALTHCHECKRESPONSE.fields_by_name[
    "services"
].message_type = _HEALTHCHECKRESPONSE_SERVICE
_HEALTHCHECKRESPONSE_STATUS.containing_type = _HEALTHCHECKRESPONSE
_ENTITYCOVERAGEREQUEST.fields_by_name["universe"].message_type = _UNIVERSE
_ENTITYCOVERAGEREQUEST.fields_by_name[
    "effective_dating"
].message_type = _TIMESTAMPRANGE
_ENTITYCOVERAGERESPONSE.fields_by_name[
    "entries"
].message_type = _ENTITYCOVERAGERESPONSEENTRY
_APPINPUT_CONTEXTENTRY.containing_type = _APPINPUT
_APPINPUT.fields_by_name["context"].message_type = _APPINPUT_CONTEXTENTRY
_APPOUTPUT_CONTEXTENTRY.containing_type = _APPOUTPUT
_APPOUTPUT.fields_by_name["context"].message_type = _APPOUTPUT_CONTEXTENTRY
_APPEXECUTIONPROFILE_CONTEXTENTRY.containing_type = _APPEXECUTIONPROFILE
_APPEXECUTIONPROFILE.fields_by_name[
    "context"
].message_type = _APPEXECUTIONPROFILE_CONTEXTENTRY
_DEPENDENCY_CONTEXTENTRY.containing_type = _DEPENDENCY
_DEPENDENCY.fields_by_name["kind"].enum_type = _DEPENDENCYKIND
_DEPENDENCY.fields_by_name["context"].message_type = _DEPENDENCY_CONTEXTENTRY
_APP.fields_by_name["inputs"].message_type = _APPINPUT
_APP.fields_by_name["outputs"].message_type = _APPOUTPUT
_APP.fields_by_name["execution_profiles"].message_type = _APPEXECUTIONPROFILE
_APPLYAPPREQUEST.fields_by_name["app"].message_type = _APP
_EXECUTEAPPREQUEST.fields_by_name[
    "inputs"
].message_type = _EXECUTEAPPREQUESTINPUT
_APPLYDEPENDENCYREQUEST.fields_by_name["dependency"].message_type = _DEPENDENCY
_LISTAPPREQUEST.fields_by_name[
    "pagination_options"
].message_type = _PAGINATIONOPTIONS
_LISTAPPRESPONSE.fields_by_name["apps"].message_type = _APP
_LISTAPPRESPONSE.fields_by_name[
    "pagination_details"
].message_type = _PAGINATIONDETAILS
_EMITEVENTREQUEST_CONTEXTENTRY.containing_type = _EMITEVENTREQUEST
_EMITEVENTREQUEST.fields_by_name["metadata"].message_type = _EVENTMETADATA
_EMITEVENTREQUEST.fields_by_name[
    "context"
].message_type = _EMITEVENTREQUEST_CONTEXTENTRY
DESCRIPTOR.message_types_by_name["TimestampRange"] = _TIMESTAMPRANGE
DESCRIPTOR.message_types_by_name["PaginationOptions"] = _PAGINATIONOPTIONS
DESCRIPTOR.message_types_by_name["PaginationDetails"] = _PAGINATIONDETAILS
DESCRIPTOR.message_types_by_name["Universe"] = _UNIVERSE
DESCRIPTOR.message_types_by_name["Perspective"] = _PERSPECTIVE
DESCRIPTOR.message_types_by_name[
    "PerspectivePermanentAttribute"
] = _PERSPECTIVEPERMANENTATTRIBUTE
DESCRIPTOR.message_types_by_name[
    "MigrateResourceRequest"
] = _MIGRATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "MigrateAllResourcesRequest"
] = _MIGRATEALLRESOURCESREQUEST
DESCRIPTOR.message_types_by_name["MigrationDetails"] = _MIGRATIONDETAILS
DESCRIPTOR.message_types_by_name[
    "MigrateAllResourcesResponse"
] = _MIGRATEALLRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name[
    "MigrationStatusRequest"
] = _MIGRATIONSTATUSREQUEST
DESCRIPTOR.message_types_by_name[
    "MigrateResourceResponse"
] = _MIGRATERESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "ResolveResourceRequest"
] = _RESOLVERESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "ResolveQueryResourceRequest"
] = _RESOLVEQUERYRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "ResolveQueryResourceResponse"
] = _RESOLVEQUERYRESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "ResolveResourceMappingContextEntry"
] = _RESOLVERESOURCEMAPPINGCONTEXTENTRY
DESCRIPTOR.message_types_by_name[
    "ResolveResourceResponse"
] = _RESOLVERESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "ResolveResourceIntentResponse"
] = _RESOLVERESOURCEINTENTRESPONSE
DESCRIPTOR.message_types_by_name[
    "ResolveResourceIntentMapping"
] = _RESOLVERESOURCEINTENTMAPPING
DESCRIPTOR.message_types_by_name["ColumnEntry"] = _COLUMNENTRY
DESCRIPTOR.message_types_by_name[
    "ResolveResourceIntentMappingClause"
] = _RESOLVERESOURCEINTENTMAPPINGCLAUSE
DESCRIPTOR.message_types_by_name["ConfigurationEntry"] = _CONFIGURATIONENTRY
DESCRIPTOR.message_types_by_name[
    "ApplyLandingZoneRequest"
] = _APPLYLANDINGZONEREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyLandingZoneResponse"
] = _APPLYLANDINGZONERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractLandingZoneRequest"
] = _RETRACTLANDINGZONEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractLandingZoneResponse"
] = _RETRACTLANDINGZONERESPONSE
DESCRIPTOR.message_types_by_name[
    "ListLandingZoneRequest"
] = _LISTLANDINGZONEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListLandingZoneResponse"
] = _LISTLANDINGZONERESPONSE
DESCRIPTOR.message_types_by_name[
    "EnableLandingZoneRequest"
] = _ENABLELANDINGZONEREQUEST
DESCRIPTOR.message_types_by_name[
    "EnableLandingZoneResponse"
] = _ENABLELANDINGZONERESPONSE
DESCRIPTOR.message_types_by_name[
    "DisableLandingZoneRequest"
] = _DISABLELANDINGZONEREQUEST
DESCRIPTOR.message_types_by_name[
    "DisableLandingZoneResponse"
] = _DISABLELANDINGZONERESPONSE
DESCRIPTOR.message_types_by_name["SchemaAttribute"] = _SCHEMAATTRIBUTE
DESCRIPTOR.message_types_by_name["Schema"] = _SCHEMA
DESCRIPTOR.message_types_by_name["MappingContext"] = _MAPPINGCONTEXT
DESCRIPTOR.message_types_by_name[
    "MappingConcatenationRule"
] = _MAPPINGCONCATENATIONRULE
DESCRIPTOR.message_types_by_name["EntityType"] = _ENTITYTYPE
DESCRIPTOR.message_types_by_name["RelationshipType"] = _RELATIONSHIPTYPE
DESCRIPTOR.message_types_by_name[
    "ApplyOntologyRequest"
] = _APPLYONTOLOGYREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyOntologyResponse"
] = _APPLYONTOLOGYRESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractOntologyRequest"
] = _RETRACTONTOLOGYREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractOntologyResponse"
] = _RETRACTONTOLOGYRESPONSE
DESCRIPTOR.message_types_by_name["ListOntologyRequest"] = _LISTONTOLOGYREQUEST
DESCRIPTOR.message_types_by_name["Ontology"] = _ONTOLOGY
DESCRIPTOR.message_types_by_name[
    "ListOntologyResponse"
] = _LISTONTOLOGYRESPONSE
DESCRIPTOR.message_types_by_name["ExecutionEngine"] = _EXECUTIONENGINE
DESCRIPTOR.message_types_by_name[
    "ApplyExecutionEngineRequest"
] = _APPLYEXECUTIONENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyExecutionEngineResponse"
] = _APPLYEXECUTIONENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractExecutionEngineRequest"
] = _RETRACTEXECUTIONENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractExecutionEngineResponse"
] = _RETRACTEXECUTIONENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "ListExecutionEngineRequest"
] = _LISTEXECUTIONENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListExecutionEngineResponse"
] = _LISTEXECUTIONENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "EnableExecutionEngineRequest"
] = _ENABLEEXECUTIONENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "EnableExecutionEngineResponse"
] = _ENABLEEXECUTIONENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "DisableExecutionEngineRequest"
] = _DISABLEEXECUTIONENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "DisableExecutionEngineResponse"
] = _DISABLEEXECUTIONENGINERESPONSE
DESCRIPTOR.message_types_by_name["Warehouse"] = _WAREHOUSE
DESCRIPTOR.message_types_by_name[
    "ApplyWarehouseRequest"
] = _APPLYWAREHOUSEREQUEST
DESCRIPTOR.message_types_by_name["Validator"] = _VALIDATOR
DESCRIPTOR.message_types_by_name[
    "ApplyValidatorRequest"
] = _APPLYVALIDATORREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractValidatorRequest"
] = _RETRACTVALIDATORREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractValidatorResponse"
] = _RETRACTVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name[
    "ListValidatorRequest"
] = _LISTVALIDATORREQUEST
DESCRIPTOR.message_types_by_name[
    "ListValidatorResponse"
] = _LISTVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name[
    "ApplyValidatorResponse"
] = _APPLYVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name[
    "ApplyWarehouseResponse"
] = _APPLYWAREHOUSERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractWarehouseRequest"
] = _RETRACTWAREHOUSEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractWarehouseResponse"
] = _RETRACTWAREHOUSERESPONSE
DESCRIPTOR.message_types_by_name[
    "ListWarehouseRequest"
] = _LISTWAREHOUSEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListWarehouseResponse"
] = _LISTWAREHOUSERESPONSE
DESCRIPTOR.message_types_by_name[
    "EnableWarehouseRequest"
] = _ENABLEWAREHOUSEREQUEST
DESCRIPTOR.message_types_by_name[
    "EnableWarehouseResponse"
] = _ENABLEWAREHOUSERESPONSE
DESCRIPTOR.message_types_by_name[
    "DisableWarehouseRequest"
] = _DISABLEWAREHOUSEREQUEST
DESCRIPTOR.message_types_by_name[
    "DisableWarehouseResponse"
] = _DISABLEWAREHOUSERESPONSE
DESCRIPTOR.message_types_by_name[
    "ApplyMasteringEngineRequest"
] = _APPLYMASTERINGENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyMasteringEngineResponse"
] = _APPLYMASTERINGENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractMasteringEngineRequest"
] = _RETRACTMASTERINGENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractMasteringEngineResponse"
] = _RETRACTMASTERINGENGINERESPONSE
DESCRIPTOR.message_types_by_name[
    "ListMasteringEngineRequest"
] = _LISTMASTERINGENGINEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListMasteringEngineResponse"
] = _LISTMASTERINGENGINERESPONSE
DESCRIPTOR.message_types_by_name["MasteringEngine"] = _MASTERINGENGINE
DESCRIPTOR.message_types_by_name[
    "ResourceStoreContextEntry"
] = _RESOURCESTORECONTEXTENTRY
DESCRIPTOR.message_types_by_name["ResourceStore"] = _RESOURCESTORE
DESCRIPTOR.message_types_by_name[
    "ResourcePointerEntry"
] = _RESOURCEPOINTERENTRY
DESCRIPTOR.message_types_by_name[
    "ResourceMetadataEntry"
] = _RESOURCEMETADATAENTRY
DESCRIPTOR.message_types_by_name[
    "ResourceContextPointerEntry"
] = _RESOURCECONTEXTPOINTERENTRY
DESCRIPTOR.message_types_by_name["ResourceDating"] = _RESOURCEDATING
DESCRIPTOR.message_types_by_name["ResourceHashing"] = _RESOURCEHASHING
DESCRIPTOR.message_types_by_name["ResourceRetraction"] = _RESOURCERETRACTION
DESCRIPTOR.message_types_by_name["ResourceContext"] = _RESOURCECONTEXT
DESCRIPTOR.message_types_by_name["Resource"] = _RESOURCE
DESCRIPTOR.message_types_by_name["Adapter"] = _ADAPTER
DESCRIPTOR.message_types_by_name["AdapterPersistence"] = _ADAPTERPERSISTENCE
DESCRIPTOR.message_types_by_name[
    "AdapterPersistenceEntry"
] = _ADAPTERPERSISTENCEENTRY
DESCRIPTOR.message_types_by_name[
    "AdapterPersistenceStep"
] = _ADAPTERPERSISTENCESTEP
DESCRIPTOR.message_types_by_name["AdapterMetadata"] = _ADAPTERMETADATA
DESCRIPTOR.message_types_by_name["Migration"] = _MIGRATION
DESCRIPTOR.message_types_by_name["ApplyAdapterRequest"] = _APPLYADAPTERREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyAdapterResponse"
] = _APPLYADAPTERRESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractAdapterRequest"
] = _RETRACTADAPTERREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractAdapterResponse"
] = _RETRACTADAPTERRESPONSE
DESCRIPTOR.message_types_by_name["ListAdapterRequest"] = _LISTADAPTERREQUEST
DESCRIPTOR.message_types_by_name["ListAdapterResponse"] = _LISTADAPTERRESPONSE
DESCRIPTOR.message_types_by_name[
    "EnableAdapterRequest"
] = _ENABLEADAPTERREQUEST
DESCRIPTOR.message_types_by_name[
    "EnableAdapterResponse"
] = _ENABLEADAPTERRESPONSE
DESCRIPTOR.message_types_by_name[
    "DisableAdapterRequest"
] = _DISABLEADAPTERREQUEST
DESCRIPTOR.message_types_by_name[
    "DisableAdapterResponse"
] = _DISABLEADAPTERRESPONSE
DESCRIPTOR.message_types_by_name[
    "ApplyResourceRequest"
] = _APPLYRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyResourceResponse"
] = _APPLYRESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractResourceRequest"
] = _RETRACTRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractResourceResponse"
] = _RETRACTRESOURCERESPONSE
DESCRIPTOR.message_types_by_name["ListResourceRequest"] = _LISTRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListResourceResponse"
] = _LISTRESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "EnableResourceRequest"
] = _ENABLERESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "PreviewResourceRequest"
] = _PREVIEWRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "EnableResourceResponse"
] = _ENABLERESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "PreviewResourceResponse"
] = _PREVIEWRESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "DisableResourceRequest"
] = _DISABLERESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "DisableResourceResponse"
] = _DISABLERESOURCERESPONSE
DESCRIPTOR.message_types_by_name["AdapterParameters"] = _ADAPTERPARAMETERS
DESCRIPTOR.message_types_by_name[
    "AdapterExecutionContextEntry"
] = _ADAPTEREXECUTIONCONTEXTENTRY
DESCRIPTOR.message_types_by_name[
    "AdapterExecutionProfile"
] = _ADAPTEREXECUTIONPROFILE
DESCRIPTOR.message_types_by_name[
    "CreateIngestionSessionRequest"
] = _CREATEINGESTIONSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateIngestionSessionResponse"
] = _CREATEINGESTIONSESSIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "ExecuteIngestionSessionRequest"
] = _EXECUTEINGESTIONSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteIngestionSessionRequest"
] = _DELETEINGESTIONSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteIngestionSessionResponse"
] = _DELETEINGESTIONSESSIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "GetIngestionSessionRequest"
] = _GETINGESTIONSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "IngestionSessionStatusResponse"
] = _INGESTIONSESSIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name["MasterEntity"] = _MASTERENTITY
DESCRIPTOR.message_types_by_name[
    "MasterIngestionSessionRequest"
] = _MASTERINGESTIONSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "MasterIngestionSessionResponse"
] = _MASTERINGESTIONSESSIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "PublishIngestionSessionResourceRequest"
] = _PUBLISHINGESTIONSESSIONRESOURCEREQUEST
DESCRIPTOR.message_types_by_name[
    "PublishIngestionSessionResourceResponse"
] = _PUBLISHINGESTIONSESSIONRESOURCERESPONSE
DESCRIPTOR.message_types_by_name[
    "PublishIngestionSessionResourceStatusRequest"
] = _PUBLISHINGESTIONSESSIONRESOURCESTATUSREQUEST
DESCRIPTOR.message_types_by_name[
    "PublishIngestionSessionStatusResponse"
] = _PUBLISHINGESTIONSESSIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractPublishingSessionRequest"
] = _RETRACTPUBLISHINGSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractPublishingSessionResponse"
] = _RETRACTPUBLISHINGSESSIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractMasteringSessionRequest"
] = _RETRACTMASTERINGSESSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractMasteringSessionResponse"
] = _RETRACTMASTERINGSESSIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "HaltIncrementalMasteringRequest"
] = _HALTINCREMENTALMASTERINGREQUEST
DESCRIPTOR.message_types_by_name[
    "HaltIncrementalMasteringResponse"
] = _HALTINCREMENTALMASTERINGRESPONSE
DESCRIPTOR.message_types_by_name[
    "ResumeIncrementalMasteringRequest"
] = _RESUMEINCREMENTALMASTERINGREQUEST
DESCRIPTOR.message_types_by_name[
    "ResumeIncrementalMasteringResponse"
] = _RESUMEINCREMENTALMASTERINGRESPONSE
DESCRIPTOR.message_types_by_name[
    "ResolveResourcePathRequest"
] = _RESOLVERESOURCEPATHREQUEST
DESCRIPTOR.message_types_by_name[
    "ResolveResourcePathResponse"
] = _RESOLVERESOURCEPATHRESPONSE
DESCRIPTOR.message_types_by_name["PSRequest"] = _PSREQUEST
DESCRIPTOR.message_types_by_name["PSResponse"] = _PSRESPONSE
DESCRIPTOR.message_types_by_name[
    "ListIngestionSessionArtifactsRequest"
] = _LISTINGESTIONSESSIONARTIFACTSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListIngestionSessionArtifactsResponse"
] = _LISTINGESTIONSESSIONARTIFACTSRESPONSE
DESCRIPTOR.message_types_by_name[
    "ListIngestionSessionsRequest"
] = _LISTINGESTIONSESSIONSREQUEST
DESCRIPTOR.message_types_by_name["IngestionSession"] = _INGESTIONSESSION
DESCRIPTOR.message_types_by_name[
    "ListIngestionSessionsResponse"
] = _LISTINGESTIONSESSIONSRESPONSE
DESCRIPTOR.message_types_by_name["PublishingDetails"] = _PUBLISHINGDETAILS
DESCRIPTOR.message_types_by_name[
    "ApplyPerspectiveRequest"
] = _APPLYPERSPECTIVEREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyPerspectiveResponse"
] = _APPLYPERSPECTIVERESPONSE
DESCRIPTOR.message_types_by_name[
    "RetractPerspectiveRequest"
] = _RETRACTPERSPECTIVEREQUEST
DESCRIPTOR.message_types_by_name[
    "RetractPerspectiveResponse"
] = _RETRACTPERSPECTIVERESPONSE
DESCRIPTOR.message_types_by_name[
    "ListPerspectiveRequest"
] = _LISTPERSPECTIVEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListPerspectiveResponse"
] = _LISTPERSPECTIVERESPONSE
DESCRIPTOR.message_types_by_name["EventMetadata"] = _EVENTMETADATA
DESCRIPTOR.message_types_by_name[
    "PublishResourceFailedEvent"
] = _PUBLISHRESOURCEFAILEDEVENT
DESCRIPTOR.message_types_by_name[
    "PublishResourceCompleteEvent"
] = _PUBLISHRESOURCECOMPLETEEVENT
DESCRIPTOR.message_types_by_name[
    "ExecuteIngestionSessionCompleteEvent"
] = _EXECUTEINGESTIONSESSIONCOMPLETEEVENT
DESCRIPTOR.message_types_by_name[
    "ExecuteIngestionSessionFailedEvent"
] = _EXECUTEINGESTIONSESSIONFAILEDEVENT
DESCRIPTOR.message_types_by_name[
    "IngestionSessionCreatedEvent"
] = _INGESTIONSESSIONCREATEDEVENT
DESCRIPTOR.message_types_by_name[
    "ResolveUniverseRequest"
] = _RESOLVEUNIVERSEREQUEST
DESCRIPTOR.message_types_by_name[
    "ResolveUniverseGroupEntry"
] = _RESOLVEUNIVERSEGROUPENTRY
DESCRIPTOR.message_types_by_name[
    "ResolveUniverseEntry"
] = _RESOLVEUNIVERSEENTRY
DESCRIPTOR.message_types_by_name["ErrorEntry"] = _ERRORENTRY
DESCRIPTOR.message_types_by_name["HealthCheckRequest"] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name["HealthCheckResponse"] = _HEALTHCHECKRESPONSE
DESCRIPTOR.message_types_by_name[
    "EntityCoverageRequest"
] = _ENTITYCOVERAGEREQUEST
DESCRIPTOR.message_types_by_name[
    "EntityCoverageResponse"
] = _ENTITYCOVERAGERESPONSE
DESCRIPTOR.message_types_by_name[
    "EntityCoverageResponseEntry"
] = _ENTITYCOVERAGERESPONSEENTRY
DESCRIPTOR.message_types_by_name["AppInput"] = _APPINPUT
DESCRIPTOR.message_types_by_name["AppOutput"] = _APPOUTPUT
DESCRIPTOR.message_types_by_name["AppExecutionProfile"] = _APPEXECUTIONPROFILE
DESCRIPTOR.message_types_by_name["Dependency"] = _DEPENDENCY
DESCRIPTOR.message_types_by_name["App"] = _APP
DESCRIPTOR.message_types_by_name["ApplyAppRequest"] = _APPLYAPPREQUEST
DESCRIPTOR.message_types_by_name["ApplyAppResponse"] = _APPLYAPPRESPONSE
DESCRIPTOR.message_types_by_name["ExecuteAppRequest"] = _EXECUTEAPPREQUEST
DESCRIPTOR.message_types_by_name[
    "ExecuteAppRequestInput"
] = _EXECUTEAPPREQUESTINPUT
DESCRIPTOR.message_types_by_name["ExecuteAppResponse"] = _EXECUTEAPPRESPONSE
DESCRIPTOR.message_types_by_name[
    "ApplyDependencyRequest"
] = _APPLYDEPENDENCYREQUEST
DESCRIPTOR.message_types_by_name[
    "ApplyDependencyResponse"
] = _APPLYDEPENDENCYRESPONSE
DESCRIPTOR.message_types_by_name["ListAppRequest"] = _LISTAPPREQUEST
DESCRIPTOR.message_types_by_name["ListAppResponse"] = _LISTAPPRESPONSE
DESCRIPTOR.message_types_by_name["EmitEventRequest"] = _EMITEVENTREQUEST
DESCRIPTOR.message_types_by_name["EmitEventResponse"] = _EMITEVENTRESPONSE
DESCRIPTOR.enum_types_by_name["ComparisonType"] = _COMPARISONTYPE
DESCRIPTOR.enum_types_by_name["DependencyKind"] = _DEPENDENCYKIND
DESCRIPTOR.enum_types_by_name["AppOutputKind"] = _APPOUTPUTKIND
DESCRIPTOR.enum_types_by_name["AttributeType"] = _ATTRIBUTETYPE
DESCRIPTOR.enum_types_by_name[
    "IngestionSessionStatus"
] = _INGESTIONSESSIONSTATUS
DESCRIPTOR.enum_types_by_name["ResourcePublishStatus"] = _RESOURCEPUBLISHSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimestampRange = _reflection.GeneratedProtocolMessageType(
    "TimestampRange",
    (_message.Message,),
    {
        "DESCRIPTOR": _TIMESTAMPRANGE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.TimestampRange)
    },
)
_sym_db.RegisterMessage(TimestampRange)

PaginationOptions = _reflection.GeneratedProtocolMessageType(
    "PaginationOptions",
    (_message.Message,),
    {
        "DESCRIPTOR": _PAGINATIONOPTIONS,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PaginationOptions)
    },
)
_sym_db.RegisterMessage(PaginationOptions)

PaginationDetails = _reflection.GeneratedProtocolMessageType(
    "PaginationDetails",
    (_message.Message,),
    {
        "DESCRIPTOR": _PAGINATIONDETAILS,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PaginationDetails)
    },
)
_sym_db.RegisterMessage(PaginationDetails)

Universe = _reflection.GeneratedProtocolMessageType(
    "Universe",
    (_message.Message,),
    {
        "DESCRIPTOR": _UNIVERSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Universe)
    },
)
_sym_db.RegisterMessage(Universe)

Perspective = _reflection.GeneratedProtocolMessageType(
    "Perspective",
    (_message.Message,),
    {
        "DESCRIPTOR": _PERSPECTIVE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Perspective)
    },
)
_sym_db.RegisterMessage(Perspective)

PerspectivePermanentAttribute = _reflection.GeneratedProtocolMessageType(
    "PerspectivePermanentAttribute",
    (_message.Message,),
    {
        "DESCRIPTOR": _PERSPECTIVEPERMANENTATTRIBUTE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PerspectivePermanentAttribute)
    },
)
_sym_db.RegisterMessage(PerspectivePermanentAttribute)

MigrateResourceRequest = _reflection.GeneratedProtocolMessageType(
    "MigrateResourceRequest",
    (_message.Message,),
    {
        "Force": _reflection.GeneratedProtocolMessageType(
            "Force",
            (_message.Message,),
            {
                "DESCRIPTOR": _MIGRATERESOURCEREQUEST_FORCE,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.MigrateResourceRequest.Force)
            },
        ),
        "DESCRIPTOR": _MIGRATERESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrateResourceRequest)
    },
)
_sym_db.RegisterMessage(MigrateResourceRequest)
_sym_db.RegisterMessage(MigrateResourceRequest.Force)

MigrateAllResourcesRequest = _reflection.GeneratedProtocolMessageType(
    "MigrateAllResourcesRequest",
    (_message.Message,),
    {
        "Force": _reflection.GeneratedProtocolMessageType(
            "Force",
            (_message.Message,),
            {
                "DESCRIPTOR": _MIGRATEALLRESOURCESREQUEST_FORCE,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.MigrateAllResourcesRequest.Force)
            },
        ),
        "DESCRIPTOR": _MIGRATEALLRESOURCESREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrateAllResourcesRequest)
    },
)
_sym_db.RegisterMessage(MigrateAllResourcesRequest)
_sym_db.RegisterMessage(MigrateAllResourcesRequest.Force)

MigrationDetails = _reflection.GeneratedProtocolMessageType(
    "MigrationDetails",
    (_message.Message,),
    {
        "DESCRIPTOR": _MIGRATIONDETAILS,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrationDetails)
    },
)
_sym_db.RegisterMessage(MigrationDetails)

MigrateAllResourcesResponse = _reflection.GeneratedProtocolMessageType(
    "MigrateAllResourcesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _MIGRATEALLRESOURCESRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrateAllResourcesResponse)
    },
)
_sym_db.RegisterMessage(MigrateAllResourcesResponse)

MigrationStatusRequest = _reflection.GeneratedProtocolMessageType(
    "MigrationStatusRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MIGRATIONSTATUSREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrationStatusRequest)
    },
)
_sym_db.RegisterMessage(MigrationStatusRequest)

MigrateResourceResponse = _reflection.GeneratedProtocolMessageType(
    "MigrateResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _MIGRATERESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MigrateResourceResponse)
    },
)
_sym_db.RegisterMessage(MigrateResourceResponse)

ResolveResourceRequest = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceRequest",
    (_message.Message,),
    {
        "PointersEntry": _reflection.GeneratedProtocolMessageType(
            "PointersEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVERESOURCEREQUEST_POINTERSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceRequest.PointersEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVERESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceRequest)
    },
)
_sym_db.RegisterMessage(ResolveResourceRequest)
_sym_db.RegisterMessage(ResolveResourceRequest.PointersEntry)

ResolveQueryResourceRequest = _reflection.GeneratedProtocolMessageType(
    "ResolveQueryResourceRequest",
    (_message.Message,),
    {
        "PointersEntry": _reflection.GeneratedProtocolMessageType(
            "PointersEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveQueryResourceRequest.PointersEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVEQUERYRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveQueryResourceRequest)
    },
)
_sym_db.RegisterMessage(ResolveQueryResourceRequest)
_sym_db.RegisterMessage(ResolveQueryResourceRequest.PointersEntry)

ResolveQueryResourceResponse = _reflection.GeneratedProtocolMessageType(
    "ResolveQueryResourceResponse",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveQueryResourceResponse.ContextEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVEQUERYRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveQueryResourceResponse)
    },
)
_sym_db.RegisterMessage(ResolveQueryResourceResponse)
_sym_db.RegisterMessage(ResolveQueryResourceResponse.ContextEntry)

ResolveResourceMappingContextEntry = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceMappingContextEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVERESOURCEMAPPINGCONTEXTENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceMappingContextEntry)
    },
)
_sym_db.RegisterMessage(ResolveResourceMappingContextEntry)

ResolveResourceResponse = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVERESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceResponse)
    },
)
_sym_db.RegisterMessage(ResolveResourceResponse)

ResolveResourceIntentResponse = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceIntentResponse",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceIntentResponse.ContextEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVERESOURCEINTENTRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceIntentResponse)
    },
)
_sym_db.RegisterMessage(ResolveResourceIntentResponse)
_sym_db.RegisterMessage(ResolveResourceIntentResponse.ContextEntry)

ResolveResourceIntentMapping = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceIntentMapping",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVERESOURCEINTENTMAPPING,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceIntentMapping)
    },
)
_sym_db.RegisterMessage(ResolveResourceIntentMapping)

ColumnEntry = _reflection.GeneratedProtocolMessageType(
    "ColumnEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _COLUMNENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ColumnEntry)
    },
)
_sym_db.RegisterMessage(ColumnEntry)

ResolveResourceIntentMappingClause = _reflection.GeneratedProtocolMessageType(
    "ResolveResourceIntentMappingClause",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVERESOURCEINTENTMAPPINGCLAUSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourceIntentMappingClause)
    },
)
_sym_db.RegisterMessage(ResolveResourceIntentMappingClause)

ConfigurationEntry = _reflection.GeneratedProtocolMessageType(
    "ConfigurationEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGURATIONENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ConfigurationEntry)
    },
)
_sym_db.RegisterMessage(ConfigurationEntry)

ApplyLandingZoneRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyLandingZoneRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYLANDINGZONEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyLandingZoneRequest)
    },
)
_sym_db.RegisterMessage(ApplyLandingZoneRequest)

ApplyLandingZoneResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyLandingZoneResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYLANDINGZONERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyLandingZoneResponse)
    },
)
_sym_db.RegisterMessage(ApplyLandingZoneResponse)

RetractLandingZoneRequest = _reflection.GeneratedProtocolMessageType(
    "RetractLandingZoneRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTLANDINGZONEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractLandingZoneRequest)
    },
)
_sym_db.RegisterMessage(RetractLandingZoneRequest)

RetractLandingZoneResponse = _reflection.GeneratedProtocolMessageType(
    "RetractLandingZoneResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTLANDINGZONERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractLandingZoneResponse)
    },
)
_sym_db.RegisterMessage(RetractLandingZoneResponse)

ListLandingZoneRequest = _reflection.GeneratedProtocolMessageType(
    "ListLandingZoneRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTLANDINGZONEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListLandingZoneRequest)
    },
)
_sym_db.RegisterMessage(ListLandingZoneRequest)

ListLandingZoneResponse = _reflection.GeneratedProtocolMessageType(
    "ListLandingZoneResponse",
    (_message.Message,),
    {
        "LandingZoneDetails": _reflection.GeneratedProtocolMessageType(
            "LandingZoneDetails",
            (_message.Message,),
            {
                "DESCRIPTOR": _LISTLANDINGZONERESPONSE_LANDINGZONEDETAILS,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ListLandingZoneResponse.LandingZoneDetails)
            },
        ),
        "DESCRIPTOR": _LISTLANDINGZONERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListLandingZoneResponse)
    },
)
_sym_db.RegisterMessage(ListLandingZoneResponse)
_sym_db.RegisterMessage(ListLandingZoneResponse.LandingZoneDetails)

EnableLandingZoneRequest = _reflection.GeneratedProtocolMessageType(
    "EnableLandingZoneRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLELANDINGZONEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableLandingZoneRequest)
    },
)
_sym_db.RegisterMessage(EnableLandingZoneRequest)

EnableLandingZoneResponse = _reflection.GeneratedProtocolMessageType(
    "EnableLandingZoneResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLELANDINGZONERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableLandingZoneResponse)
    },
)
_sym_db.RegisterMessage(EnableLandingZoneResponse)

DisableLandingZoneRequest = _reflection.GeneratedProtocolMessageType(
    "DisableLandingZoneRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLELANDINGZONEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableLandingZoneRequest)
    },
)
_sym_db.RegisterMessage(DisableLandingZoneRequest)

DisableLandingZoneResponse = _reflection.GeneratedProtocolMessageType(
    "DisableLandingZoneResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLELANDINGZONERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableLandingZoneResponse)
    },
)
_sym_db.RegisterMessage(DisableLandingZoneResponse)

SchemaAttribute = _reflection.GeneratedProtocolMessageType(
    "SchemaAttribute",
    (_message.Message,),
    {
        "DESCRIPTOR": _SCHEMAATTRIBUTE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.SchemaAttribute)
    },
)
_sym_db.RegisterMessage(SchemaAttribute)

Schema = _reflection.GeneratedProtocolMessageType(
    "Schema",
    (_message.Message,),
    {
        "DESCRIPTOR": _SCHEMA,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Schema)
    },
)
_sym_db.RegisterMessage(Schema)

MappingContext = _reflection.GeneratedProtocolMessageType(
    "MappingContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _MAPPINGCONTEXT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MappingContext)
    },
)
_sym_db.RegisterMessage(MappingContext)

MappingConcatenationRule = _reflection.GeneratedProtocolMessageType(
    "MappingConcatenationRule",
    (_message.Message,),
    {
        "DESCRIPTOR": _MAPPINGCONCATENATIONRULE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MappingConcatenationRule)
    },
)
_sym_db.RegisterMessage(MappingConcatenationRule)

EntityType = _reflection.GeneratedProtocolMessageType(
    "EntityType",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTITYTYPE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EntityType)
    },
)
_sym_db.RegisterMessage(EntityType)

RelationshipType = _reflection.GeneratedProtocolMessageType(
    "RelationshipType",
    (_message.Message,),
    {
        "DESCRIPTOR": _RELATIONSHIPTYPE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RelationshipType)
    },
)
_sym_db.RegisterMessage(RelationshipType)

ApplyOntologyRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyOntologyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYONTOLOGYREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyOntologyRequest)
    },
)
_sym_db.RegisterMessage(ApplyOntologyRequest)

ApplyOntologyResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyOntologyResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYONTOLOGYRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyOntologyResponse)
    },
)
_sym_db.RegisterMessage(ApplyOntologyResponse)

RetractOntologyRequest = _reflection.GeneratedProtocolMessageType(
    "RetractOntologyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTONTOLOGYREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractOntologyRequest)
    },
)
_sym_db.RegisterMessage(RetractOntologyRequest)

RetractOntologyResponse = _reflection.GeneratedProtocolMessageType(
    "RetractOntologyResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTONTOLOGYRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractOntologyResponse)
    },
)
_sym_db.RegisterMessage(RetractOntologyResponse)

ListOntologyRequest = _reflection.GeneratedProtocolMessageType(
    "ListOntologyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTONTOLOGYREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListOntologyRequest)
    },
)
_sym_db.RegisterMessage(ListOntologyRequest)

Ontology = _reflection.GeneratedProtocolMessageType(
    "Ontology",
    (_message.Message,),
    {
        "DESCRIPTOR": _ONTOLOGY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Ontology)
    },
)
_sym_db.RegisterMessage(Ontology)

ListOntologyResponse = _reflection.GeneratedProtocolMessageType(
    "ListOntologyResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTONTOLOGYRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListOntologyResponse)
    },
)
_sym_db.RegisterMessage(ListOntologyResponse)

ExecutionEngine = _reflection.GeneratedProtocolMessageType(
    "ExecutionEngine",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTIONENGINE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecutionEngine)
    },
)
_sym_db.RegisterMessage(ExecutionEngine)

ApplyExecutionEngineRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyExecutionEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYEXECUTIONENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyExecutionEngineRequest)
    },
)
_sym_db.RegisterMessage(ApplyExecutionEngineRequest)

ApplyExecutionEngineResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyExecutionEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYEXECUTIONENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyExecutionEngineResponse)
    },
)
_sym_db.RegisterMessage(ApplyExecutionEngineResponse)

RetractExecutionEngineRequest = _reflection.GeneratedProtocolMessageType(
    "RetractExecutionEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTEXECUTIONENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractExecutionEngineRequest)
    },
)
_sym_db.RegisterMessage(RetractExecutionEngineRequest)

RetractExecutionEngineResponse = _reflection.GeneratedProtocolMessageType(
    "RetractExecutionEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTEXECUTIONENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractExecutionEngineResponse)
    },
)
_sym_db.RegisterMessage(RetractExecutionEngineResponse)

ListExecutionEngineRequest = _reflection.GeneratedProtocolMessageType(
    "ListExecutionEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTEXECUTIONENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListExecutionEngineRequest)
    },
)
_sym_db.RegisterMessage(ListExecutionEngineRequest)

ListExecutionEngineResponse = _reflection.GeneratedProtocolMessageType(
    "ListExecutionEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTEXECUTIONENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListExecutionEngineResponse)
    },
)
_sym_db.RegisterMessage(ListExecutionEngineResponse)

EnableExecutionEngineRequest = _reflection.GeneratedProtocolMessageType(
    "EnableExecutionEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEEXECUTIONENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableExecutionEngineRequest)
    },
)
_sym_db.RegisterMessage(EnableExecutionEngineRequest)

EnableExecutionEngineResponse = _reflection.GeneratedProtocolMessageType(
    "EnableExecutionEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEEXECUTIONENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableExecutionEngineResponse)
    },
)
_sym_db.RegisterMessage(EnableExecutionEngineResponse)

DisableExecutionEngineRequest = _reflection.GeneratedProtocolMessageType(
    "DisableExecutionEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEEXECUTIONENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableExecutionEngineRequest)
    },
)
_sym_db.RegisterMessage(DisableExecutionEngineRequest)

DisableExecutionEngineResponse = _reflection.GeneratedProtocolMessageType(
    "DisableExecutionEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEEXECUTIONENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableExecutionEngineResponse)
    },
)
_sym_db.RegisterMessage(DisableExecutionEngineResponse)

Warehouse = _reflection.GeneratedProtocolMessageType(
    "Warehouse",
    (_message.Message,),
    {
        "DESCRIPTOR": _WAREHOUSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Warehouse)
    },
)
_sym_db.RegisterMessage(Warehouse)

ApplyWarehouseRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyWarehouseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYWAREHOUSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyWarehouseRequest)
    },
)
_sym_db.RegisterMessage(ApplyWarehouseRequest)

Validator = _reflection.GeneratedProtocolMessageType(
    "Validator",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATOR,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Validator)
    },
)
_sym_db.RegisterMessage(Validator)

ApplyValidatorRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyValidatorRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYVALIDATORREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyValidatorRequest)
    },
)
_sym_db.RegisterMessage(ApplyValidatorRequest)

RetractValidatorRequest = _reflection.GeneratedProtocolMessageType(
    "RetractValidatorRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTVALIDATORREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractValidatorRequest)
    },
)
_sym_db.RegisterMessage(RetractValidatorRequest)

RetractValidatorResponse = _reflection.GeneratedProtocolMessageType(
    "RetractValidatorResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTVALIDATORRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractValidatorResponse)
    },
)
_sym_db.RegisterMessage(RetractValidatorResponse)

ListValidatorRequest = _reflection.GeneratedProtocolMessageType(
    "ListValidatorRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTVALIDATORREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListValidatorRequest)
    },
)
_sym_db.RegisterMessage(ListValidatorRequest)

ListValidatorResponse = _reflection.GeneratedProtocolMessageType(
    "ListValidatorResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTVALIDATORRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListValidatorResponse)
    },
)
_sym_db.RegisterMessage(ListValidatorResponse)

ApplyValidatorResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyValidatorResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYVALIDATORRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyValidatorResponse)
    },
)
_sym_db.RegisterMessage(ApplyValidatorResponse)

ApplyWarehouseResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyWarehouseResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYWAREHOUSERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyWarehouseResponse)
    },
)
_sym_db.RegisterMessage(ApplyWarehouseResponse)

RetractWarehouseRequest = _reflection.GeneratedProtocolMessageType(
    "RetractWarehouseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTWAREHOUSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractWarehouseRequest)
    },
)
_sym_db.RegisterMessage(RetractWarehouseRequest)

RetractWarehouseResponse = _reflection.GeneratedProtocolMessageType(
    "RetractWarehouseResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTWAREHOUSERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractWarehouseResponse)
    },
)
_sym_db.RegisterMessage(RetractWarehouseResponse)

ListWarehouseRequest = _reflection.GeneratedProtocolMessageType(
    "ListWarehouseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTWAREHOUSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListWarehouseRequest)
    },
)
_sym_db.RegisterMessage(ListWarehouseRequest)

ListWarehouseResponse = _reflection.GeneratedProtocolMessageType(
    "ListWarehouseResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTWAREHOUSERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListWarehouseResponse)
    },
)
_sym_db.RegisterMessage(ListWarehouseResponse)

EnableWarehouseRequest = _reflection.GeneratedProtocolMessageType(
    "EnableWarehouseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEWAREHOUSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableWarehouseRequest)
    },
)
_sym_db.RegisterMessage(EnableWarehouseRequest)

EnableWarehouseResponse = _reflection.GeneratedProtocolMessageType(
    "EnableWarehouseResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEWAREHOUSERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableWarehouseResponse)
    },
)
_sym_db.RegisterMessage(EnableWarehouseResponse)

DisableWarehouseRequest = _reflection.GeneratedProtocolMessageType(
    "DisableWarehouseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEWAREHOUSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableWarehouseRequest)
    },
)
_sym_db.RegisterMessage(DisableWarehouseRequest)

DisableWarehouseResponse = _reflection.GeneratedProtocolMessageType(
    "DisableWarehouseResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEWAREHOUSERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableWarehouseResponse)
    },
)
_sym_db.RegisterMessage(DisableWarehouseResponse)

ApplyMasteringEngineRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyMasteringEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYMASTERINGENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyMasteringEngineRequest)
    },
)
_sym_db.RegisterMessage(ApplyMasteringEngineRequest)

ApplyMasteringEngineResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyMasteringEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYMASTERINGENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyMasteringEngineResponse)
    },
)
_sym_db.RegisterMessage(ApplyMasteringEngineResponse)

RetractMasteringEngineRequest = _reflection.GeneratedProtocolMessageType(
    "RetractMasteringEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTMASTERINGENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractMasteringEngineRequest)
    },
)
_sym_db.RegisterMessage(RetractMasteringEngineRequest)

RetractMasteringEngineResponse = _reflection.GeneratedProtocolMessageType(
    "RetractMasteringEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTMASTERINGENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractMasteringEngineResponse)
    },
)
_sym_db.RegisterMessage(RetractMasteringEngineResponse)

ListMasteringEngineRequest = _reflection.GeneratedProtocolMessageType(
    "ListMasteringEngineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTMASTERINGENGINEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListMasteringEngineRequest)
    },
)
_sym_db.RegisterMessage(ListMasteringEngineRequest)

ListMasteringEngineResponse = _reflection.GeneratedProtocolMessageType(
    "ListMasteringEngineResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTMASTERINGENGINERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListMasteringEngineResponse)
    },
)
_sym_db.RegisterMessage(ListMasteringEngineResponse)

MasteringEngine = _reflection.GeneratedProtocolMessageType(
    "MasteringEngine",
    (_message.Message,),
    {
        "DESCRIPTOR": _MASTERINGENGINE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MasteringEngine)
    },
)
_sym_db.RegisterMessage(MasteringEngine)

ResourceStoreContextEntry = _reflection.GeneratedProtocolMessageType(
    "ResourceStoreContextEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCESTORECONTEXTENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceStoreContextEntry)
    },
)
_sym_db.RegisterMessage(ResourceStoreContextEntry)

ResourceStore = _reflection.GeneratedProtocolMessageType(
    "ResourceStore",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCESTORE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceStore)
    },
)
_sym_db.RegisterMessage(ResourceStore)

ResourcePointerEntry = _reflection.GeneratedProtocolMessageType(
    "ResourcePointerEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEPOINTERENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourcePointerEntry)
    },
)
_sym_db.RegisterMessage(ResourcePointerEntry)

ResourceMetadataEntry = _reflection.GeneratedProtocolMessageType(
    "ResourceMetadataEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEMETADATAENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceMetadataEntry)
    },
)
_sym_db.RegisterMessage(ResourceMetadataEntry)

ResourceContextPointerEntry = _reflection.GeneratedProtocolMessageType(
    "ResourceContextPointerEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCECONTEXTPOINTERENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceContextPointerEntry)
    },
)
_sym_db.RegisterMessage(ResourceContextPointerEntry)

ResourceDating = _reflection.GeneratedProtocolMessageType(
    "ResourceDating",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEDATING,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceDating)
    },
)
_sym_db.RegisterMessage(ResourceDating)

ResourceHashing = _reflection.GeneratedProtocolMessageType(
    "ResourceHashing",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEHASHING,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceHashing)
    },
)
_sym_db.RegisterMessage(ResourceHashing)

ResourceRetraction = _reflection.GeneratedProtocolMessageType(
    "ResourceRetraction",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCERETRACTION,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceRetraction)
    },
)
_sym_db.RegisterMessage(ResourceRetraction)

ResourceContext = _reflection.GeneratedProtocolMessageType(
    "ResourceContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCECONTEXT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResourceContext)
    },
)
_sym_db.RegisterMessage(ResourceContext)

Resource = _reflection.GeneratedProtocolMessageType(
    "Resource",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Resource)
    },
)
_sym_db.RegisterMessage(Resource)

Adapter = _reflection.GeneratedProtocolMessageType(
    "Adapter",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTER,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Adapter)
    },
)
_sym_db.RegisterMessage(Adapter)

AdapterPersistence = _reflection.GeneratedProtocolMessageType(
    "AdapterPersistence",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTERPERSISTENCE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterPersistence)
    },
)
_sym_db.RegisterMessage(AdapterPersistence)

AdapterPersistenceEntry = _reflection.GeneratedProtocolMessageType(
    "AdapterPersistenceEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTERPERSISTENCEENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterPersistenceEntry)
    },
)
_sym_db.RegisterMessage(AdapterPersistenceEntry)

AdapterPersistenceStep = _reflection.GeneratedProtocolMessageType(
    "AdapterPersistenceStep",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTERPERSISTENCESTEP,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterPersistenceStep)
    },
)
_sym_db.RegisterMessage(AdapterPersistenceStep)

AdapterMetadata = _reflection.GeneratedProtocolMessageType(
    "AdapterMetadata",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTERMETADATA,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterMetadata)
    },
)
_sym_db.RegisterMessage(AdapterMetadata)

Migration = _reflection.GeneratedProtocolMessageType(
    "Migration",
    (_message.Message,),
    {
        "DESCRIPTOR": _MIGRATION,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Migration)
    },
)
_sym_db.RegisterMessage(Migration)

ApplyAdapterRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyAdapterRequest",
    (_message.Message,),
    {
        "CustomerMetadataEntry": _reflection.GeneratedProtocolMessageType(
            "CustomerMetadataEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ApplyAdapterRequest.CustomerMetadataEntry)
            },
        ),
        "DESCRIPTOR": _APPLYADAPTERREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyAdapterRequest)
    },
)
_sym_db.RegisterMessage(ApplyAdapterRequest)
_sym_db.RegisterMessage(ApplyAdapterRequest.CustomerMetadataEntry)

ApplyAdapterResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyAdapterResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYADAPTERRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyAdapterResponse)
    },
)
_sym_db.RegisterMessage(ApplyAdapterResponse)

RetractAdapterRequest = _reflection.GeneratedProtocolMessageType(
    "RetractAdapterRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTADAPTERREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractAdapterRequest)
    },
)
_sym_db.RegisterMessage(RetractAdapterRequest)

RetractAdapterResponse = _reflection.GeneratedProtocolMessageType(
    "RetractAdapterResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTADAPTERRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractAdapterResponse)
    },
)
_sym_db.RegisterMessage(RetractAdapterResponse)

ListAdapterRequest = _reflection.GeneratedProtocolMessageType(
    "ListAdapterRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTADAPTERREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListAdapterRequest)
    },
)
_sym_db.RegisterMessage(ListAdapterRequest)

ListAdapterResponse = _reflection.GeneratedProtocolMessageType(
    "ListAdapterResponse",
    (_message.Message,),
    {
        "AdapterDetails": _reflection.GeneratedProtocolMessageType(
            "AdapterDetails",
            (_message.Message,),
            {
                "DESCRIPTOR": _LISTADAPTERRESPONSE_ADAPTERDETAILS,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ListAdapterResponse.AdapterDetails)
            },
        ),
        "DESCRIPTOR": _LISTADAPTERRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListAdapterResponse)
    },
)
_sym_db.RegisterMessage(ListAdapterResponse)
_sym_db.RegisterMessage(ListAdapterResponse.AdapterDetails)

EnableAdapterRequest = _reflection.GeneratedProtocolMessageType(
    "EnableAdapterRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEADAPTERREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableAdapterRequest)
    },
)
_sym_db.RegisterMessage(EnableAdapterRequest)

EnableAdapterResponse = _reflection.GeneratedProtocolMessageType(
    "EnableAdapterResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLEADAPTERRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableAdapterResponse)
    },
)
_sym_db.RegisterMessage(EnableAdapterResponse)

DisableAdapterRequest = _reflection.GeneratedProtocolMessageType(
    "DisableAdapterRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEADAPTERREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableAdapterRequest)
    },
)
_sym_db.RegisterMessage(DisableAdapterRequest)

DisableAdapterResponse = _reflection.GeneratedProtocolMessageType(
    "DisableAdapterResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLEADAPTERRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableAdapterResponse)
    },
)
_sym_db.RegisterMessage(DisableAdapterResponse)

ApplyResourceRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyResourceRequest)
    },
)
_sym_db.RegisterMessage(ApplyResourceRequest)

ApplyResourceResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyResourceResponse)
    },
)
_sym_db.RegisterMessage(ApplyResourceResponse)

RetractResourceRequest = _reflection.GeneratedProtocolMessageType(
    "RetractResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractResourceRequest)
    },
)
_sym_db.RegisterMessage(RetractResourceRequest)

RetractResourceResponse = _reflection.GeneratedProtocolMessageType(
    "RetractResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractResourceResponse)
    },
)
_sym_db.RegisterMessage(RetractResourceResponse)

ListResourceRequest = _reflection.GeneratedProtocolMessageType(
    "ListResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListResourceRequest)
    },
)
_sym_db.RegisterMessage(ListResourceRequest)

ListResourceResponse = _reflection.GeneratedProtocolMessageType(
    "ListResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListResourceResponse)
    },
)
_sym_db.RegisterMessage(ListResourceResponse)

EnableResourceRequest = _reflection.GeneratedProtocolMessageType(
    "EnableResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLERESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableResourceRequest)
    },
)
_sym_db.RegisterMessage(EnableResourceRequest)

PreviewResourceRequest = _reflection.GeneratedProtocolMessageType(
    "PreviewResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PREVIEWRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PreviewResourceRequest)
    },
)
_sym_db.RegisterMessage(PreviewResourceRequest)

EnableResourceResponse = _reflection.GeneratedProtocolMessageType(
    "EnableResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENABLERESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EnableResourceResponse)
    },
)
_sym_db.RegisterMessage(EnableResourceResponse)

PreviewResourceResponse = _reflection.GeneratedProtocolMessageType(
    "PreviewResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _PREVIEWRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PreviewResourceResponse)
    },
)
_sym_db.RegisterMessage(PreviewResourceResponse)

DisableResourceRequest = _reflection.GeneratedProtocolMessageType(
    "DisableResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLERESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableResourceRequest)
    },
)
_sym_db.RegisterMessage(DisableResourceRequest)

DisableResourceResponse = _reflection.GeneratedProtocolMessageType(
    "DisableResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISABLERESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DisableResourceResponse)
    },
)
_sym_db.RegisterMessage(DisableResourceResponse)

AdapterParameters = _reflection.GeneratedProtocolMessageType(
    "AdapterParameters",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTERPARAMETERS,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterParameters)
    },
)
_sym_db.RegisterMessage(AdapterParameters)

AdapterExecutionContextEntry = _reflection.GeneratedProtocolMessageType(
    "AdapterExecutionContextEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTEREXECUTIONCONTEXTENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterExecutionContextEntry)
    },
)
_sym_db.RegisterMessage(AdapterExecutionContextEntry)

AdapterExecutionProfile = _reflection.GeneratedProtocolMessageType(
    "AdapterExecutionProfile",
    (_message.Message,),
    {
        "DESCRIPTOR": _ADAPTEREXECUTIONPROFILE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AdapterExecutionProfile)
    },
)
_sym_db.RegisterMessage(AdapterExecutionProfile)

CreateIngestionSessionRequest = _reflection.GeneratedProtocolMessageType(
    "CreateIngestionSessionRequest",
    (_message.Message,),
    {
        "ParametersEntry": _reflection.GeneratedProtocolMessageType(
            "ParametersEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.CreateIngestionSessionRequest.ParametersEntry)
            },
        ),
        "DESCRIPTOR": _CREATEINGESTIONSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.CreateIngestionSessionRequest)
    },
)
_sym_db.RegisterMessage(CreateIngestionSessionRequest)
_sym_db.RegisterMessage(CreateIngestionSessionRequest.ParametersEntry)

CreateIngestionSessionResponse = _reflection.GeneratedProtocolMessageType(
    "CreateIngestionSessionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEINGESTIONSESSIONRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.CreateIngestionSessionResponse)
    },
)
_sym_db.RegisterMessage(CreateIngestionSessionResponse)

ExecuteIngestionSessionRequest = _reflection.GeneratedProtocolMessageType(
    "ExecuteIngestionSessionRequest",
    (_message.Message,),
    {
        "ParametersEntry": _reflection.GeneratedProtocolMessageType(
            "ParametersEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteIngestionSessionRequest.ParametersEntry)
            },
        ),
        "DESCRIPTOR": _EXECUTEINGESTIONSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteIngestionSessionRequest)
    },
)
_sym_db.RegisterMessage(ExecuteIngestionSessionRequest)
_sym_db.RegisterMessage(ExecuteIngestionSessionRequest.ParametersEntry)

DeleteIngestionSessionRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteIngestionSessionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEINGESTIONSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DeleteIngestionSessionRequest)
    },
)
_sym_db.RegisterMessage(DeleteIngestionSessionRequest)

DeleteIngestionSessionResponse = _reflection.GeneratedProtocolMessageType(
    "DeleteIngestionSessionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEINGESTIONSESSIONRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.DeleteIngestionSessionResponse)
    },
)
_sym_db.RegisterMessage(DeleteIngestionSessionResponse)

GetIngestionSessionRequest = _reflection.GeneratedProtocolMessageType(
    "GetIngestionSessionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETINGESTIONSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.GetIngestionSessionRequest)
    },
)
_sym_db.RegisterMessage(GetIngestionSessionRequest)

IngestionSessionStatusResponse = _reflection.GeneratedProtocolMessageType(
    "IngestionSessionStatusResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _INGESTIONSESSIONSTATUSRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.IngestionSessionStatusResponse)
    },
)
_sym_db.RegisterMessage(IngestionSessionStatusResponse)

MasterEntity = _reflection.GeneratedProtocolMessageType(
    "MasterEntity",
    (_message.Message,),
    {
        "DescriptorsEntry": _reflection.GeneratedProtocolMessageType(
            "DescriptorsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _MASTERENTITY_DESCRIPTORSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.MasterEntity.DescriptorsEntry)
            },
        ),
        "DESCRIPTOR": _MASTERENTITY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MasterEntity)
    },
)
_sym_db.RegisterMessage(MasterEntity)
_sym_db.RegisterMessage(MasterEntity.DescriptorsEntry)

MasterIngestionSessionRequest = _reflection.GeneratedProtocolMessageType(
    "MasterIngestionSessionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MASTERINGESTIONSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MasterIngestionSessionRequest)
    },
)
_sym_db.RegisterMessage(MasterIngestionSessionRequest)

MasterIngestionSessionResponse = _reflection.GeneratedProtocolMessageType(
    "MasterIngestionSessionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _MASTERINGESTIONSESSIONRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.MasterIngestionSessionResponse)
    },
)
_sym_db.RegisterMessage(MasterIngestionSessionResponse)

PublishIngestionSessionResourceRequest = _reflection.GeneratedProtocolMessageType(
    "PublishIngestionSessionResourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHINGESTIONSESSIONRESOURCEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishIngestionSessionResourceRequest)
    },
)
_sym_db.RegisterMessage(PublishIngestionSessionResourceRequest)

PublishIngestionSessionResourceResponse = _reflection.GeneratedProtocolMessageType(
    "PublishIngestionSessionResourceResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHINGESTIONSESSIONRESOURCERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishIngestionSessionResourceResponse)
    },
)
_sym_db.RegisterMessage(PublishIngestionSessionResourceResponse)

PublishIngestionSessionResourceStatusRequest = _reflection.GeneratedProtocolMessageType(
    "PublishIngestionSessionResourceStatusRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHINGESTIONSESSIONRESOURCESTATUSREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishIngestionSessionResourceStatusRequest)
    },
)
_sym_db.RegisterMessage(PublishIngestionSessionResourceStatusRequest)

PublishIngestionSessionStatusResponse = _reflection.GeneratedProtocolMessageType(
    "PublishIngestionSessionStatusResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHINGESTIONSESSIONSTATUSRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishIngestionSessionStatusResponse)
    },
)
_sym_db.RegisterMessage(PublishIngestionSessionStatusResponse)

RetractPublishingSessionRequest = _reflection.GeneratedProtocolMessageType(
    "RetractPublishingSessionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTPUBLISHINGSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractPublishingSessionRequest)
    },
)
_sym_db.RegisterMessage(RetractPublishingSessionRequest)

RetractPublishingSessionResponse = _reflection.GeneratedProtocolMessageType(
    "RetractPublishingSessionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTPUBLISHINGSESSIONRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractPublishingSessionResponse)
    },
)
_sym_db.RegisterMessage(RetractPublishingSessionResponse)

RetractMasteringSessionRequest = _reflection.GeneratedProtocolMessageType(
    "RetractMasteringSessionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTMASTERINGSESSIONREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractMasteringSessionRequest)
    },
)
_sym_db.RegisterMessage(RetractMasteringSessionRequest)

RetractMasteringSessionResponse = _reflection.GeneratedProtocolMessageType(
    "RetractMasteringSessionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTMASTERINGSESSIONRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractMasteringSessionResponse)
    },
)
_sym_db.RegisterMessage(RetractMasteringSessionResponse)

HaltIncrementalMasteringRequest = _reflection.GeneratedProtocolMessageType(
    "HaltIncrementalMasteringRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _HALTINCREMENTALMASTERINGREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.HaltIncrementalMasteringRequest)
    },
)
_sym_db.RegisterMessage(HaltIncrementalMasteringRequest)

HaltIncrementalMasteringResponse = _reflection.GeneratedProtocolMessageType(
    "HaltIncrementalMasteringResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _HALTINCREMENTALMASTERINGRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.HaltIncrementalMasteringResponse)
    },
)
_sym_db.RegisterMessage(HaltIncrementalMasteringResponse)

ResumeIncrementalMasteringRequest = _reflection.GeneratedProtocolMessageType(
    "ResumeIncrementalMasteringRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESUMEINCREMENTALMASTERINGREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResumeIncrementalMasteringRequest)
    },
)
_sym_db.RegisterMessage(ResumeIncrementalMasteringRequest)

ResumeIncrementalMasteringResponse = _reflection.GeneratedProtocolMessageType(
    "ResumeIncrementalMasteringResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESUMEINCREMENTALMASTERINGRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResumeIncrementalMasteringResponse)
    },
)
_sym_db.RegisterMessage(ResumeIncrementalMasteringResponse)

ResolveResourcePathRequest = _reflection.GeneratedProtocolMessageType(
    "ResolveResourcePathRequest",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourcePathRequest.ContextEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVERESOURCEPATHREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourcePathRequest)
    },
)
_sym_db.RegisterMessage(ResolveResourcePathRequest)
_sym_db.RegisterMessage(ResolveResourcePathRequest.ContextEntry)

ResolveResourcePathResponse = _reflection.GeneratedProtocolMessageType(
    "ResolveResourcePathResponse",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourcePathResponse.ContextEntry)
            },
        ),
        "DESCRIPTOR": _RESOLVERESOURCEPATHRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveResourcePathResponse)
    },
)
_sym_db.RegisterMessage(ResolveResourcePathResponse)
_sym_db.RegisterMessage(ResolveResourcePathResponse.ContextEntry)

PSRequest = _reflection.GeneratedProtocolMessageType(
    "PSRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PSREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PSRequest)
    },
)
_sym_db.RegisterMessage(PSRequest)

PSResponse = _reflection.GeneratedProtocolMessageType(
    "PSResponse",
    (_message.Message,),
    {
        "PublishSession": _reflection.GeneratedProtocolMessageType(
            "PublishSession",
            (_message.Message,),
            {
                "DESCRIPTOR": _PSRESPONSE_PUBLISHSESSION,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.PSResponse.PublishSession)
            },
        ),
        "DESCRIPTOR": _PSRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PSResponse)
    },
)
_sym_db.RegisterMessage(PSResponse)
_sym_db.RegisterMessage(PSResponse.PublishSession)

ListIngestionSessionArtifactsRequest = _reflection.GeneratedProtocolMessageType(
    "ListIngestionSessionArtifactsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINGESTIONSESSIONARTIFACTSREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListIngestionSessionArtifactsRequest)
    },
)
_sym_db.RegisterMessage(ListIngestionSessionArtifactsRequest)

ListIngestionSessionArtifactsResponse = _reflection.GeneratedProtocolMessageType(
    "ListIngestionSessionArtifactsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINGESTIONSESSIONARTIFACTSRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListIngestionSessionArtifactsResponse)
    },
)
_sym_db.RegisterMessage(ListIngestionSessionArtifactsResponse)

ListIngestionSessionsRequest = _reflection.GeneratedProtocolMessageType(
    "ListIngestionSessionsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINGESTIONSESSIONSREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListIngestionSessionsRequest)
    },
)
_sym_db.RegisterMessage(ListIngestionSessionsRequest)

IngestionSession = _reflection.GeneratedProtocolMessageType(
    "IngestionSession",
    (_message.Message,),
    {
        "ParametersEntry": _reflection.GeneratedProtocolMessageType(
            "ParametersEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _INGESTIONSESSION_PARAMETERSENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.IngestionSession.ParametersEntry)
            },
        ),
        "DESCRIPTOR": _INGESTIONSESSION,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.IngestionSession)
    },
)
_sym_db.RegisterMessage(IngestionSession)
_sym_db.RegisterMessage(IngestionSession.ParametersEntry)

ListIngestionSessionsResponse = _reflection.GeneratedProtocolMessageType(
    "ListIngestionSessionsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINGESTIONSESSIONSRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListIngestionSessionsResponse)
    },
)
_sym_db.RegisterMessage(ListIngestionSessionsResponse)

PublishingDetails = _reflection.GeneratedProtocolMessageType(
    "PublishingDetails",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHINGDETAILS,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishingDetails)
    },
)
_sym_db.RegisterMessage(PublishingDetails)

ApplyPerspectiveRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyPerspectiveRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYPERSPECTIVEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyPerspectiveRequest)
    },
)
_sym_db.RegisterMessage(ApplyPerspectiveRequest)

ApplyPerspectiveResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyPerspectiveResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYPERSPECTIVERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyPerspectiveResponse)
    },
)
_sym_db.RegisterMessage(ApplyPerspectiveResponse)

RetractPerspectiveRequest = _reflection.GeneratedProtocolMessageType(
    "RetractPerspectiveRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTPERSPECTIVEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractPerspectiveRequest)
    },
)
_sym_db.RegisterMessage(RetractPerspectiveRequest)

RetractPerspectiveResponse = _reflection.GeneratedProtocolMessageType(
    "RetractPerspectiveResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRACTPERSPECTIVERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.RetractPerspectiveResponse)
    },
)
_sym_db.RegisterMessage(RetractPerspectiveResponse)

ListPerspectiveRequest = _reflection.GeneratedProtocolMessageType(
    "ListPerspectiveRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPERSPECTIVEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListPerspectiveRequest)
    },
)
_sym_db.RegisterMessage(ListPerspectiveRequest)

ListPerspectiveResponse = _reflection.GeneratedProtocolMessageType(
    "ListPerspectiveResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPERSPECTIVERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListPerspectiveResponse)
    },
)
_sym_db.RegisterMessage(ListPerspectiveResponse)

EventMetadata = _reflection.GeneratedProtocolMessageType(
    "EventMetadata",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVENTMETADATA,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EventMetadata)
    },
)
_sym_db.RegisterMessage(EventMetadata)

PublishResourceFailedEvent = _reflection.GeneratedProtocolMessageType(
    "PublishResourceFailedEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHRESOURCEFAILEDEVENT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishResourceFailedEvent)
    },
)
_sym_db.RegisterMessage(PublishResourceFailedEvent)

PublishResourceCompleteEvent = _reflection.GeneratedProtocolMessageType(
    "PublishResourceCompleteEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHRESOURCECOMPLETEEVENT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.PublishResourceCompleteEvent)
    },
)
_sym_db.RegisterMessage(PublishResourceCompleteEvent)

ExecuteIngestionSessionCompleteEvent = _reflection.GeneratedProtocolMessageType(
    "ExecuteIngestionSessionCompleteEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTEINGESTIONSESSIONCOMPLETEEVENT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteIngestionSessionCompleteEvent)
    },
)
_sym_db.RegisterMessage(ExecuteIngestionSessionCompleteEvent)

ExecuteIngestionSessionFailedEvent = _reflection.GeneratedProtocolMessageType(
    "ExecuteIngestionSessionFailedEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTEINGESTIONSESSIONFAILEDEVENT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteIngestionSessionFailedEvent)
    },
)
_sym_db.RegisterMessage(ExecuteIngestionSessionFailedEvent)

IngestionSessionCreatedEvent = _reflection.GeneratedProtocolMessageType(
    "IngestionSessionCreatedEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _INGESTIONSESSIONCREATEDEVENT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.IngestionSessionCreatedEvent)
    },
)
_sym_db.RegisterMessage(IngestionSessionCreatedEvent)

ResolveUniverseRequest = _reflection.GeneratedProtocolMessageType(
    "ResolveUniverseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVEUNIVERSEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveUniverseRequest)
    },
)
_sym_db.RegisterMessage(ResolveUniverseRequest)

ResolveUniverseGroupEntry = _reflection.GeneratedProtocolMessageType(
    "ResolveUniverseGroupEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVEUNIVERSEGROUPENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveUniverseGroupEntry)
    },
)
_sym_db.RegisterMessage(ResolveUniverseGroupEntry)

ResolveUniverseEntry = _reflection.GeneratedProtocolMessageType(
    "ResolveUniverseEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVEUNIVERSEENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ResolveUniverseEntry)
    },
)
_sym_db.RegisterMessage(ResolveUniverseEntry)

ErrorEntry = _reflection.GeneratedProtocolMessageType(
    "ErrorEntry",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _ERRORENTRY_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.ErrorEntry.ContextEntry)
            },
        ),
        "DESCRIPTOR": _ERRORENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ErrorEntry)
    },
)
_sym_db.RegisterMessage(ErrorEntry)
_sym_db.RegisterMessage(ErrorEntry.ContextEntry)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType(
    "HealthCheckRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _HEALTHCHECKREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.HealthCheckRequest)
    },
)
_sym_db.RegisterMessage(HealthCheckRequest)

HealthCheckResponse = _reflection.GeneratedProtocolMessageType(
    "HealthCheckResponse",
    (_message.Message,),
    {
        "ServiceStatus": _reflection.GeneratedProtocolMessageType(
            "ServiceStatus",
            (_message.Message,),
            {
                "DESCRIPTOR": _HEALTHCHECKRESPONSE_SERVICESTATUS,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.HealthCheckResponse.ServiceStatus)
            },
        ),
        "Service": _reflection.GeneratedProtocolMessageType(
            "Service",
            (_message.Message,),
            {
                "DESCRIPTOR": _HEALTHCHECKRESPONSE_SERVICE,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.HealthCheckResponse.Service)
            },
        ),
        "DESCRIPTOR": _HEALTHCHECKRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.HealthCheckResponse)
    },
)
_sym_db.RegisterMessage(HealthCheckResponse)
_sym_db.RegisterMessage(HealthCheckResponse.ServiceStatus)
_sym_db.RegisterMessage(HealthCheckResponse.Service)

EntityCoverageRequest = _reflection.GeneratedProtocolMessageType(
    "EntityCoverageRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTITYCOVERAGEREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EntityCoverageRequest)
    },
)
_sym_db.RegisterMessage(EntityCoverageRequest)

EntityCoverageResponse = _reflection.GeneratedProtocolMessageType(
    "EntityCoverageResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTITYCOVERAGERESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EntityCoverageResponse)
    },
)
_sym_db.RegisterMessage(EntityCoverageResponse)

EntityCoverageResponseEntry = _reflection.GeneratedProtocolMessageType(
    "EntityCoverageResponseEntry",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTITYCOVERAGERESPONSEENTRY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EntityCoverageResponseEntry)
    },
)
_sym_db.RegisterMessage(EntityCoverageResponseEntry)

AppInput = _reflection.GeneratedProtocolMessageType(
    "AppInput",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPINPUT_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.AppInput.ContextEntry)
            },
        ),
        "DESCRIPTOR": _APPINPUT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AppInput)
    },
)
_sym_db.RegisterMessage(AppInput)
_sym_db.RegisterMessage(AppInput.ContextEntry)

AppOutput = _reflection.GeneratedProtocolMessageType(
    "AppOutput",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPOUTPUT_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.AppOutput.ContextEntry)
            },
        ),
        "DESCRIPTOR": _APPOUTPUT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AppOutput)
    },
)
_sym_db.RegisterMessage(AppOutput)
_sym_db.RegisterMessage(AppOutput.ContextEntry)

AppExecutionProfile = _reflection.GeneratedProtocolMessageType(
    "AppExecutionProfile",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPEXECUTIONPROFILE_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.AppExecutionProfile.ContextEntry)
            },
        ),
        "DESCRIPTOR": _APPEXECUTIONPROFILE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.AppExecutionProfile)
    },
)
_sym_db.RegisterMessage(AppExecutionProfile)
_sym_db.RegisterMessage(AppExecutionProfile.ContextEntry)

Dependency = _reflection.GeneratedProtocolMessageType(
    "Dependency",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _DEPENDENCY_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.Dependency.ContextEntry)
            },
        ),
        "DESCRIPTOR": _DEPENDENCY,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.Dependency)
    },
)
_sym_db.RegisterMessage(Dependency)
_sym_db.RegisterMessage(Dependency.ContextEntry)

App = _reflection.GeneratedProtocolMessageType(
    "App",
    (_message.Message,),
    {
        "DESCRIPTOR": _APP,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.App)
    },
)
_sym_db.RegisterMessage(App)

ApplyAppRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyAppRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYAPPREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyAppRequest)
    },
)
_sym_db.RegisterMessage(ApplyAppRequest)

ApplyAppResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyAppResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYAPPRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyAppResponse)
    },
)
_sym_db.RegisterMessage(ApplyAppResponse)

ExecuteAppRequest = _reflection.GeneratedProtocolMessageType(
    "ExecuteAppRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTEAPPREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteAppRequest)
    },
)
_sym_db.RegisterMessage(ExecuteAppRequest)

ExecuteAppRequestInput = _reflection.GeneratedProtocolMessageType(
    "ExecuteAppRequestInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTEAPPREQUESTINPUT,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteAppRequestInput)
    },
)
_sym_db.RegisterMessage(ExecuteAppRequestInput)

ExecuteAppResponse = _reflection.GeneratedProtocolMessageType(
    "ExecuteAppResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTEAPPRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ExecuteAppResponse)
    },
)
_sym_db.RegisterMessage(ExecuteAppResponse)

ApplyDependencyRequest = _reflection.GeneratedProtocolMessageType(
    "ApplyDependencyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYDEPENDENCYREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyDependencyRequest)
    },
)
_sym_db.RegisterMessage(ApplyDependencyRequest)

ApplyDependencyResponse = _reflection.GeneratedProtocolMessageType(
    "ApplyDependencyResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPLYDEPENDENCYRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ApplyDependencyResponse)
    },
)
_sym_db.RegisterMessage(ApplyDependencyResponse)

ListAppRequest = _reflection.GeneratedProtocolMessageType(
    "ListAppRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTAPPREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListAppRequest)
    },
)
_sym_db.RegisterMessage(ListAppRequest)

ListAppResponse = _reflection.GeneratedProtocolMessageType(
    "ListAppResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTAPPRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.ListAppResponse)
    },
)
_sym_db.RegisterMessage(ListAppResponse)

EmitEventRequest = _reflection.GeneratedProtocolMessageType(
    "EmitEventRequest",
    (_message.Message,),
    {
        "ContextEntry": _reflection.GeneratedProtocolMessageType(
            "ContextEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _EMITEVENTREQUEST_CONTEXTENTRY,
                "__module__": "bakplane.bakplane_pb2"
                # @@protoc_insertion_point(class_scope:io.openaristos.EmitEventRequest.ContextEntry)
            },
        ),
        "DESCRIPTOR": _EMITEVENTREQUEST,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EmitEventRequest)
    },
)
_sym_db.RegisterMessage(EmitEventRequest)
_sym_db.RegisterMessage(EmitEventRequest.ContextEntry)

EmitEventResponse = _reflection.GeneratedProtocolMessageType(
    "EmitEventResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EMITEVENTRESPONSE,
        "__module__": "bakplane.bakplane_pb2"
        # @@protoc_insertion_point(class_scope:io.openaristos.EmitEventResponse)
    },
)
_sym_db.RegisterMessage(EmitEventResponse)


DESCRIPTOR._options = None
_RESOLVERESOURCEREQUEST_POINTERSENTRY._options = None
_RESOLVEQUERYRESOURCEREQUEST_POINTERSENTRY._options = None
_RESOLVEQUERYRESOURCERESPONSE_CONTEXTENTRY._options = None
_RESOLVERESOURCEINTENTRESPONSE_CONTEXTENTRY._options = None
_APPLYADAPTERREQUEST_CUSTOMERMETADATAENTRY._options = None
_CREATEINGESTIONSESSIONREQUEST_PARAMETERSENTRY._options = None
_EXECUTEINGESTIONSESSIONREQUEST_PARAMETERSENTRY._options = None
_MASTERENTITY_DESCRIPTORSENTRY._options = None
_RESOLVERESOURCEPATHREQUEST_CONTEXTENTRY._options = None
_RESOLVERESOURCEPATHRESPONSE_CONTEXTENTRY._options = None
_INGESTIONSESSION_PARAMETERSENTRY._options = None
_ERRORENTRY_CONTEXTENTRY._options = None
_APPINPUT_CONTEXTENTRY._options = None
_APPOUTPUT_CONTEXTENTRY._options = None
_APPEXECUTIONPROFILE_CONTEXTENTRY._options = None
_DEPENDENCY_CONTEXTENTRY._options = None
_EMITEVENTREQUEST_CONTEXTENTRY._options = None

_BAKPLANE = _descriptor.ServiceDescriptor(
    name="Bakplane",
    full_name="io.openaristos.Bakplane",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=21593,
    serialized_end=28725,
    methods=[
        _descriptor.MethodDescriptor(
            name="ApplyAdapter",
            full_name="io.openaristos.Bakplane.ApplyAdapter",
            index=0,
            containing_service=None,
            input_type=_APPLYADAPTERREQUEST,
            output_type=_APPLYADAPTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractAdapter",
            full_name="io.openaristos.Bakplane.RetractAdapter",
            index=1,
            containing_service=None,
            input_type=_RETRACTADAPTERREQUEST,
            output_type=_RETRACTADAPTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListAdapter",
            full_name="io.openaristos.Bakplane.ListAdapter",
            index=2,
            containing_service=None,
            input_type=_LISTADAPTERREQUEST,
            output_type=_LISTADAPTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EnableAdapter",
            full_name="io.openaristos.Bakplane.EnableAdapter",
            index=3,
            containing_service=None,
            input_type=_ENABLEADAPTERREQUEST,
            output_type=_ENABLEADAPTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DisableAdapter",
            full_name="io.openaristos.Bakplane.DisableAdapter",
            index=4,
            containing_service=None,
            input_type=_DISABLEADAPTERREQUEST,
            output_type=_DISABLEADAPTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyResource",
            full_name="io.openaristos.Bakplane.ApplyResource",
            index=5,
            containing_service=None,
            input_type=_APPLYRESOURCEREQUEST,
            output_type=_APPLYRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractResource",
            full_name="io.openaristos.Bakplane.RetractResource",
            index=6,
            containing_service=None,
            input_type=_RETRACTRESOURCEREQUEST,
            output_type=_RETRACTRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListResources",
            full_name="io.openaristos.Bakplane.ListResources",
            index=7,
            containing_service=None,
            input_type=_LISTRESOURCEREQUEST,
            output_type=_LISTRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EnableResource",
            full_name="io.openaristos.Bakplane.EnableResource",
            index=8,
            containing_service=None,
            input_type=_ENABLERESOURCEREQUEST,
            output_type=_ENABLERESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="PreviewResource",
            full_name="io.openaristos.Bakplane.PreviewResource",
            index=9,
            containing_service=None,
            input_type=_PREVIEWRESOURCEREQUEST,
            output_type=_PREVIEWRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DisableResource",
            full_name="io.openaristos.Bakplane.DisableResource",
            index=10,
            containing_service=None,
            input_type=_DISABLERESOURCEREQUEST,
            output_type=_DISABLERESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="MigrateResource",
            full_name="io.openaristos.Bakplane.MigrateResource",
            index=11,
            containing_service=None,
            input_type=_MIGRATERESOURCEREQUEST,
            output_type=_MIGRATERESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="MigrateAllResources",
            full_name="io.openaristos.Bakplane.MigrateAllResources",
            index=12,
            containing_service=None,
            input_type=_MIGRATEALLRESOURCESREQUEST,
            output_type=_MIGRATEALLRESOURCESRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResourceMigrationStatus",
            full_name="io.openaristos.Bakplane.ResourceMigrationStatus",
            index=13,
            containing_service=None,
            input_type=_MIGRATIONSTATUSREQUEST,
            output_type=_MIGRATERESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResolveResource",
            full_name="io.openaristos.Bakplane.ResolveResource",
            index=14,
            containing_service=None,
            input_type=_RESOLVERESOURCEREQUEST,
            output_type=_RESOLVERESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResolveResourceIntent",
            full_name="io.openaristos.Bakplane.ResolveResourceIntent",
            index=15,
            containing_service=None,
            input_type=_RESOLVERESOURCEREQUEST,
            output_type=_RESOLVERESOURCEINTENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResolveQueryResource",
            full_name="io.openaristos.Bakplane.ResolveQueryResource",
            index=16,
            containing_service=None,
            input_type=_RESOLVEQUERYRESOURCEREQUEST,
            output_type=_RESOLVEQUERYRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResolveUniverse",
            full_name="io.openaristos.Bakplane.ResolveUniverse",
            index=17,
            containing_service=None,
            input_type=_RESOLVEUNIVERSEREQUEST,
            output_type=_RESOLVEUNIVERSEGROUPENTRY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyLandingZone",
            full_name="io.openaristos.Bakplane.ApplyLandingZone",
            index=18,
            containing_service=None,
            input_type=_APPLYLANDINGZONEREQUEST,
            output_type=_APPLYLANDINGZONERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractLandingZone",
            full_name="io.openaristos.Bakplane.RetractLandingZone",
            index=19,
            containing_service=None,
            input_type=_RETRACTLANDINGZONEREQUEST,
            output_type=_RETRACTLANDINGZONERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListLandingZone",
            full_name="io.openaristos.Bakplane.ListLandingZone",
            index=20,
            containing_service=None,
            input_type=_LISTLANDINGZONEREQUEST,
            output_type=_LISTLANDINGZONERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EnableLandingZone",
            full_name="io.openaristos.Bakplane.EnableLandingZone",
            index=21,
            containing_service=None,
            input_type=_ENABLELANDINGZONEREQUEST,
            output_type=_ENABLELANDINGZONERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DisableLandingZone",
            full_name="io.openaristos.Bakplane.DisableLandingZone",
            index=22,
            containing_service=None,
            input_type=_DISABLELANDINGZONEREQUEST,
            output_type=_DISABLELANDINGZONERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyOntology",
            full_name="io.openaristos.Bakplane.ApplyOntology",
            index=23,
            containing_service=None,
            input_type=_APPLYONTOLOGYREQUEST,
            output_type=_APPLYONTOLOGYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractOntology",
            full_name="io.openaristos.Bakplane.RetractOntology",
            index=24,
            containing_service=None,
            input_type=_RETRACTONTOLOGYREQUEST,
            output_type=_RETRACTONTOLOGYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListOntology",
            full_name="io.openaristos.Bakplane.ListOntology",
            index=25,
            containing_service=None,
            input_type=_LISTONTOLOGYREQUEST,
            output_type=_LISTONTOLOGYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyExecutionEngine",
            full_name="io.openaristos.Bakplane.ApplyExecutionEngine",
            index=26,
            containing_service=None,
            input_type=_APPLYEXECUTIONENGINEREQUEST,
            output_type=_APPLYEXECUTIONENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractExecutionEngine",
            full_name="io.openaristos.Bakplane.RetractExecutionEngine",
            index=27,
            containing_service=None,
            input_type=_RETRACTEXECUTIONENGINEREQUEST,
            output_type=_RETRACTEXECUTIONENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListExecutionEngine",
            full_name="io.openaristos.Bakplane.ListExecutionEngine",
            index=28,
            containing_service=None,
            input_type=_LISTEXECUTIONENGINEREQUEST,
            output_type=_LISTEXECUTIONENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EnableExecutionEngine",
            full_name="io.openaristos.Bakplane.EnableExecutionEngine",
            index=29,
            containing_service=None,
            input_type=_ENABLEEXECUTIONENGINEREQUEST,
            output_type=_ENABLEEXECUTIONENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DisableExecutionEngine",
            full_name="io.openaristos.Bakplane.DisableExecutionEngine",
            index=30,
            containing_service=None,
            input_type=_DISABLEEXECUTIONENGINEREQUEST,
            output_type=_DISABLEEXECUTIONENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyWarehouse",
            full_name="io.openaristos.Bakplane.ApplyWarehouse",
            index=31,
            containing_service=None,
            input_type=_APPLYWAREHOUSEREQUEST,
            output_type=_APPLYWAREHOUSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyValidator",
            full_name="io.openaristos.Bakplane.ApplyValidator",
            index=32,
            containing_service=None,
            input_type=_APPLYVALIDATORREQUEST,
            output_type=_APPLYVALIDATORRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractValidator",
            full_name="io.openaristos.Bakplane.RetractValidator",
            index=33,
            containing_service=None,
            input_type=_RETRACTVALIDATORREQUEST,
            output_type=_RETRACTVALIDATORRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListValidator",
            full_name="io.openaristos.Bakplane.ListValidator",
            index=34,
            containing_service=None,
            input_type=_LISTVALIDATORREQUEST,
            output_type=_LISTVALIDATORRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractWarehouse",
            full_name="io.openaristos.Bakplane.RetractWarehouse",
            index=35,
            containing_service=None,
            input_type=_RETRACTWAREHOUSEREQUEST,
            output_type=_RETRACTWAREHOUSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListWarehouse",
            full_name="io.openaristos.Bakplane.ListWarehouse",
            index=36,
            containing_service=None,
            input_type=_LISTWAREHOUSEREQUEST,
            output_type=_LISTWAREHOUSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EnableWarehouse",
            full_name="io.openaristos.Bakplane.EnableWarehouse",
            index=37,
            containing_service=None,
            input_type=_ENABLEWAREHOUSEREQUEST,
            output_type=_ENABLEWAREHOUSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DisableWarehouse",
            full_name="io.openaristos.Bakplane.DisableWarehouse",
            index=38,
            containing_service=None,
            input_type=_DISABLEWAREHOUSEREQUEST,
            output_type=_DISABLEWAREHOUSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyMasteringEngine",
            full_name="io.openaristos.Bakplane.ApplyMasteringEngine",
            index=39,
            containing_service=None,
            input_type=_APPLYMASTERINGENGINEREQUEST,
            output_type=_APPLYMASTERINGENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractMasteringEngine",
            full_name="io.openaristos.Bakplane.RetractMasteringEngine",
            index=40,
            containing_service=None,
            input_type=_RETRACTMASTERINGENGINEREQUEST,
            output_type=_RETRACTMASTERINGENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListMasteringEngine",
            full_name="io.openaristos.Bakplane.ListMasteringEngine",
            index=41,
            containing_service=None,
            input_type=_LISTMASTERINGENGINEREQUEST,
            output_type=_LISTMASTERINGENGINERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateIngestionSession",
            full_name="io.openaristos.Bakplane.CreateIngestionSession",
            index=42,
            containing_service=None,
            input_type=_CREATEINGESTIONSESSIONREQUEST,
            output_type=_CREATEINGESTIONSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExecuteIngestionSession",
            full_name="io.openaristos.Bakplane.ExecuteIngestionSession",
            index=43,
            containing_service=None,
            input_type=_EXECUTEINGESTIONSESSIONREQUEST,
            output_type=_INGESTIONSESSIONSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteIngestionSession",
            full_name="io.openaristos.Bakplane.DeleteIngestionSession",
            index=44,
            containing_service=None,
            input_type=_DELETEINGESTIONSESSIONREQUEST,
            output_type=_DELETEINGESTIONSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetIngestionSession",
            full_name="io.openaristos.Bakplane.GetIngestionSession",
            index=45,
            containing_service=None,
            input_type=_GETINGESTIONSESSIONREQUEST,
            output_type=_INGESTIONSESSIONSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="MasterIngestionSession",
            full_name="io.openaristos.Bakplane.MasterIngestionSession",
            index=46,
            containing_service=None,
            input_type=_MASTERINGESTIONSESSIONREQUEST,
            output_type=_MASTERINGESTIONSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="HaltIncrementalMastering",
            full_name="io.openaristos.Bakplane.HaltIncrementalMastering",
            index=47,
            containing_service=None,
            input_type=_HALTINCREMENTALMASTERINGREQUEST,
            output_type=_HALTINCREMENTALMASTERINGRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResumeIncrementalMastering",
            full_name="io.openaristos.Bakplane.ResumeIncrementalMastering",
            index=48,
            containing_service=None,
            input_type=_RESUMEINCREMENTALMASTERINGREQUEST,
            output_type=_RESUMEINCREMENTALMASTERINGRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="PublishIngestionSessionResource",
            full_name="io.openaristos.Bakplane.PublishIngestionSessionResource",
            index=49,
            containing_service=None,
            input_type=_PUBLISHINGESTIONSESSIONRESOURCEREQUEST,
            output_type=_PUBLISHINGESTIONSESSIONRESOURCERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="PublishIngestionSessionResourceStatus",
            full_name="io.openaristos.Bakplane.PublishIngestionSessionResourceStatus",
            index=50,
            containing_service=None,
            input_type=_PUBLISHINGESTIONSESSIONRESOURCESTATUSREQUEST,
            output_type=_PUBLISHINGESTIONSESSIONSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractPublishingSession",
            full_name="io.openaristos.Bakplane.RetractPublishingSession",
            index=51,
            containing_service=None,
            input_type=_RETRACTPUBLISHINGSESSIONREQUEST,
            output_type=_RETRACTPUBLISHINGSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractMasteringSession",
            full_name="io.openaristos.Bakplane.RetractMasteringSession",
            index=52,
            containing_service=None,
            input_type=_RETRACTMASTERINGSESSIONREQUEST,
            output_type=_RETRACTMASTERINGSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ResolveResourcePath",
            full_name="io.openaristos.Bakplane.ResolveResourcePath",
            index=53,
            containing_service=None,
            input_type=_RESOLVERESOURCEPATHREQUEST,
            output_type=_RESOLVERESOURCEPATHRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListIngestionSessionArtifacts",
            full_name="io.openaristos.Bakplane.ListIngestionSessionArtifacts",
            index=54,
            containing_service=None,
            input_type=_LISTINGESTIONSESSIONARTIFACTSREQUEST,
            output_type=_LISTINGESTIONSESSIONARTIFACTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListIngestionSessions",
            full_name="io.openaristos.Bakplane.ListIngestionSessions",
            index=55,
            containing_service=None,
            input_type=_LISTINGESTIONSESSIONSREQUEST,
            output_type=_LISTINGESTIONSESSIONSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SessionPS",
            full_name="io.openaristos.Bakplane.SessionPS",
            index=56,
            containing_service=None,
            input_type=_PSREQUEST,
            output_type=_PSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyPerspective",
            full_name="io.openaristos.Bakplane.ApplyPerspective",
            index=57,
            containing_service=None,
            input_type=_APPLYPERSPECTIVEREQUEST,
            output_type=_APPLYPERSPECTIVERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RetractPerspective",
            full_name="io.openaristos.Bakplane.RetractPerspective",
            index=58,
            containing_service=None,
            input_type=_RETRACTPERSPECTIVEREQUEST,
            output_type=_RETRACTPERSPECTIVERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListPerspective",
            full_name="io.openaristos.Bakplane.ListPerspective",
            index=59,
            containing_service=None,
            input_type=_LISTPERSPECTIVEREQUEST,
            output_type=_LISTPERSPECTIVERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="HealthCheck",
            full_name="io.openaristos.Bakplane.HealthCheck",
            index=60,
            containing_service=None,
            input_type=_HEALTHCHECKREQUEST,
            output_type=_HEALTHCHECKRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EntityCoverage",
            full_name="io.openaristos.Bakplane.EntityCoverage",
            index=61,
            containing_service=None,
            input_type=_ENTITYCOVERAGEREQUEST,
            output_type=_ENTITYCOVERAGERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyApp",
            full_name="io.openaristos.Bakplane.ApplyApp",
            index=62,
            containing_service=None,
            input_type=_APPLYAPPREQUEST,
            output_type=_APPLYAPPRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExecuteApp",
            full_name="io.openaristos.Bakplane.ExecuteApp",
            index=63,
            containing_service=None,
            input_type=_EXECUTEAPPREQUEST,
            output_type=_EXECUTEAPPRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplyDependency",
            full_name="io.openaristos.Bakplane.ApplyDependency",
            index=64,
            containing_service=None,
            input_type=_APPLYDEPENDENCYREQUEST,
            output_type=_APPLYDEPENDENCYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListApp",
            full_name="io.openaristos.Bakplane.ListApp",
            index=65,
            containing_service=None,
            input_type=_LISTAPPREQUEST,
            output_type=_LISTAPPRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EmitEvent",
            full_name="io.openaristos.Bakplane.EmitEvent",
            index=66,
            containing_service=None,
            input_type=_EMITEVENTREQUEST,
            output_type=_EMITEVENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_BAKPLANE)

DESCRIPTOR.services_by_name["Bakplane"] = _BAKPLANE

# @@protoc_insertion_point(module_scope)
